@@ -159,7 +159,7 @@ class MyThread(Thread):
         self.bot.set_weboob(self.weboob)
 
     def run(self):
-        for ev in self.bot.joined.itervalues():
+        for ev in self.bot.joined.values():
             ev.wait()
 
         self.weboob.repeat(5, self.check_tasks)
@@ -212,8 +212,7 @@ class MyThread(Thread):
 
     def check_board(self):
         def iter_messages(backend):
-            with backend.browser:
-                return backend.browser.iter_new_board_messages()
+            return backend.browser.iter_new_board_messages()
 
         for msg in self.weboob.do(iter_messages, backends=['dlfp']):
             word = self.find_keywords(msg.message)
