@@ -28,7 +28,7 @@ class AgendadulibreTest(BackendTest):
 
     def setUp(self):
         if not self.is_backend_configured():
-            self.backend.config['region'] = Value(value='http://www.agendadulibre.org')
+            self.backend.config['region'] = Value(value='https://www.agendadulibre.org')
 
     def test_agendadulibre(self):
         l = list(self.backend.list_events(datetime.now()))
