@@ -23,35 +23,36 @@ from weboob.capabilities.video import BaseVideo
 from weboob.capabilities.image import Thumbnail
 from weboob.capabilities.base import NotAvailable, NotLoaded, find_object
 from weboob.capabilities.cinema import Movie, Person
-from weboob.deprecated.browser import Browser
-from weboob.tools.json import json
+from weboob.browser.browsers import APIBrowser
+from weboob.browser.profiles import Android
+from weboob.tools.compat import urlencode
 import base64
 import hashlib
 from datetime import datetime, date, timedelta
 import time
-import urllib
 
 __all__ = ['AllocineBrowser']
 
 
-class AllocineBrowser(Browser):
-    DOMAIN = 'api.allocine.fr'
-    PROTOCOL = 'http'
-    ENCODING = 'utf-8'
-    USER_AGENT = 'Dalvik/1.6.0 (Linux; U; Android 4.2.2; Nexus 4 Build/JDQ39E)'
+class AllocineBrowser(APIBrowser):
+    PROFILE = Android()
 
     PARTNER_KEY = '100043982026'
     SECRET_KEY = '29d185d98c984a359e6e6f26a0474269'
 
     def __do_request(self, method, params):
-        params_encode = urllib.urlencode(params)
+        params["sed"] = time.strftime('%Y%m%d', time.localtime())
+        params["sig"] = base64.b64encode(
+            hashlib.sha1(
+                self.SECRET_KEY +
+                urlencode(params)
+            ).digest()
+        )
 
-        sed = time.strftime('%Y%m%d', time.localtime())
-        sig = base64.b64encode(hashlib.sha1(self.SECRET_KEY + params_encode + '&sed=' + sed).digest())
-
-        query_url = 'http://api.allocine.fr/rest/v3/' + method + '?' + params_encode + '&sed=' + sed + '&sig=' + sig
-
-        return self.readurl(query_url)
+        return self.request(
+            'http://api.allocine.fr/rest/v3/{}'.format(method),
+            params=params
+        )
 
     def iter_movies(self, pattern):
         params = [('partner', self.PARTNER_KEY),
@@ -59,10 +60,9 @@ class AllocineBrowser(Browser):
                   ('format', 'json'),
                   ('filter', 'movie')]
 
-        res = self.__do_request('search', params)
-        if res is None:
+        jres = self.__do_request('search', params)
+        if jres is None:
             return
-        jres = json.loads(res)
         if 'movie' not in jres['feed']:
             return
         for m in jres['feed']['movie']:
@@ -98,10 +98,9 @@ class AllocineBrowser(Browser):
                   ('format', 'json'),
                   ('filter', 'person')]
 
-        res = self.__do_request('search', params)
-        if res is None:
+        jres = self.__do_request('search', params)
+        if jres is None:
             return
-        jres = json.loads(res)
         if 'person' not in jres['feed']:
             return
         for p in jres['feed']['person']:
@@ -136,9 +135,8 @@ class AllocineBrowser(Browser):
                   ('striptags', 'synopsis,synopsisshort'),
                   ('format', 'json')]
 
-        res = self.__do_request('movie', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('movie', params)
+        if jres is not None:
             if 'movie' in jres:
                 jres = jres['movie']
             else:
@@ -218,9 +216,8 @@ class AllocineBrowser(Browser):
                   ('striptags', 'biography,biographyshort'),
                   ('format', 'json')]
 
-        res = self.__do_request('person', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('person', params)
+        if jres is not None:
             if 'person' in jres:
                 jres = jres['person']
             else:
@@ -306,9 +303,8 @@ class AllocineBrowser(Browser):
                   ('striptags', 'synopsis,synopsisshort'),
                   ('format', 'json')]
 
-        res = self.__do_request('movie', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('movie', params)
+        if jres is not None:
             if 'movie' in jres:
                 jres = jres['movie']
             else:
@@ -317,7 +313,8 @@ class AllocineBrowser(Browser):
             return
         if 'castMember' in jres:
             for cast in jres['castMember']:
-                if (role_filter is None or (role_filter is not None and cast['activity']['$'].lower().strip() == role_filter.lower().strip())):
+                if (role_filter is None or
+                   (role_filter is not None and cast['activity']['$'].lower().strip() == role_filter.lower().strip())):
                     id = cast['person']['code']
                     name = unicode(cast['person']['name'])
                     short_description = unicode(cast['activity']['$'])
@@ -346,9 +343,8 @@ class AllocineBrowser(Browser):
                   ('filter', 'movie'),
                   ('format', 'json')]
 
-        res = self.__do_request('filmography', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('filmography', params)
+        if jres is not None:
             if 'person' in jres:
                 jres = jres['person']
             else:
@@ -356,7 +352,8 @@ class AllocineBrowser(Browser):
         else:
             return
         for m in jres['participation']:
-            if (role_filter is None or (role_filter is not None and m['activity']['$'].lower().strip() == role_filter.lower().strip())):
+            if (role_filter is None or
+               (role_filter is not None and m['activity']['$'].lower().strip() == role_filter.lower().strip())):
                 prod_year = '????'
                 if 'productionYear' in m['movie']:
                     prod_year = m['movie']['productionYear']
@@ -383,9 +380,8 @@ class AllocineBrowser(Browser):
                   ('filter', 'movie'),
                   ('format', 'json')]
 
-        res = self.__do_request('filmography', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('filmography', params)
+        if jres is not None:
             if 'person' in jres:
                 jres = jres['person']
             else:
@@ -404,9 +400,8 @@ class AllocineBrowser(Browser):
                   ('striptags', 'synopsis,synopsisshort'),
                   ('format', 'json')]
 
-        res = self.__do_request('movie', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('movie', params)
+        if jres is not None:
             if 'movie' in jres:
                 jres = jres['movie']
             else:
@@ -418,7 +413,8 @@ class AllocineBrowser(Browser):
                 yield unicode(cast['person']['code'])
 
     def get_movie_releases(self, id, country):
-        return
+        if country == 'fr':
+            return self.get_movie(id).release_date
 
     def get_person_biography(self, id):
         params = [('partner', self.PARTNER_KEY),
@@ -429,9 +425,8 @@ class AllocineBrowser(Browser):
                   ('striptags', 'biography,biographyshort'),
                   ('format', 'json')]
 
-        res = self.__do_request('person', params)
-        if res is not None:
-            jres = json.loads(res)
+        jres = self.__do_request('person', params)
+        if jres is not None:
             if 'person' in jres:
                 jres = jres['person']
             else:
@@ -451,10 +446,9 @@ class AllocineBrowser(Browser):
                   ('mediafmt', 'mp4'),
                   ('filter', category)
                   ]
-        res = self.__do_request('movielist', params)
-        if res is None:
+        result = self.__do_request('movielist', params)
+        if result is None:
             return
-        result = json.loads(res)
         for movie in result['feed']['movie']:
             if 'trailer' not in movie or 'productionYear' not in movie:
                 continue
@@ -466,10 +460,9 @@ class AllocineBrowser(Browser):
                   ('mediafmt', 'mp4'),
                   ('filter', category)
                   ]
-        res = self.__do_request('videolist', params)
-        if res is None:
+        result = self.__do_request('videolist', params)
+        if result is None:
             return
-        result = json.loads(res)
         if 'feed' in result and 'media' in result['feed']:
             for episode in result['feed']['media']:
                 if 'title' in episode:
@@ -484,7 +477,9 @@ class AllocineBrowser(Browser):
             video.duration = timedelta(seconds=int(_video['runtime']))
         if 'description' in _video:
             video.description = unicode(_video['description'])
-        renditions = sorted(_video['rendition'], key=lambda x: 'bandwidth' in x and x['bandwidth']['code'], reverse=True)
+        renditions = sorted(_video['rendition'],
+                            key=lambda x: 'bandwidth' in x and x['bandwidth']['code'],
+                            reverse=True)
         video.url = unicode(max(renditions, key=lambda x: 'bandwidth' in x)['href'])
         return video
 
@@ -529,10 +524,9 @@ class AllocineBrowser(Browser):
                   ('filter', 'movie'),
                   ('code', _id),
                   ]
-        res = self.__do_request('movie', params)
-        if res is None:
+        result = self.__do_request('movie', params)
+        if result is None:
             return
-        result = json.loads(res)
         return self.parse_video(result['movie'])
 
     def get_video_from_id(self, _id, category):
@@ -545,11 +539,12 @@ class AllocineBrowser(Browser):
                   ('code', code),
                   ('profile', 'large'),
                   ]
-        res = self.__do_request('media', params)
-        if res is None:
+        result = self.__do_request('media', params)
+        if result is None:
             return
-        result = json.loads(res)
-        renditions = sorted(result['media']['rendition'], key=lambda x: 'bandwidth' in x and x['bandwidth']['code'], reverse=True)
+        renditions = sorted(result['media']['rendition'],
+                            key=lambda x: 'bandwidth' in x and x['bandwidth']['code'],
+                            reverse=True)
         return max(renditions, key=lambda x: 'bandwidth' in x)['href']
 
     def get_emissions(self, basename):
@@ -557,10 +552,9 @@ class AllocineBrowser(Browser):
                   ('format', 'json'),
                   ('filter', 'acshow'),
                   ]
-        res = self.__do_request('termlist', params)
-        if res is None:
+        result = self.__do_request('termlist', params)
+        if result is None:
             return
-        result = json.loads(res)
         for emission in result['feed']['term']:
             yield Collection([basename, unicode(emission['nameShort'])], unicode(emission['$']))
 
@@ -574,10 +568,9 @@ class AllocineBrowser(Browser):
             movie = self.iter_movies(query.summary).next()
             params.append(('movie', movie.id))
 
-        res = self.__do_request('showtimelist', params)
-        if res is None:
+        result = self.__do_request('showtimelist', params)
+        if result is None:
             return
-        result = json.loads(res)
 
         for event in self.create_event(result):
             if (not query.end_date or event.start_date <= query.end_date)\
@@ -593,10 +586,9 @@ class AllocineBrowser(Browser):
                   ('movie', split_id[2]),
                   ]
 
-        res = self.__do_request('showtimelist', params)
-        if res is None:
+        result = self.__do_request('showtimelist', params)
+        if result is None:
             return
-        result = json.loads(res)
 
         for event in self.create_event(result):
             if event.id.split('#')[-1] == split_id[-1]:
