@@ -18,7 +18,7 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from requests.exceptions import Timeout, ConnectionError
+from requests.exceptions import Timeout, ConnectionError, TooManyRedirects
 
 from weboob.browser import LoginBrowser, URL, need_login
 from weboob.browser.exceptions import ServerError, HTTPNotFound
@@ -57,7 +57,7 @@ class Amazon(LoginBrowser):
         return self.CURRENCY
 
     def get_order(self, id_):
-        order = self.to_order(id_).order()
+        order = self.to_order(id_)
         if order:
             return order
         else:
@@ -67,14 +67,14 @@ class Amazon(LoginBrowser):
         histRoot = self.to_history()
         for histYear in histRoot.iter_years():
             for order in histYear.iter_orders():
-                if order.order():
-                    yield order.order()
+                if order:
+                    yield order
 
     def iter_payments(self, order):
-        return self.to_order(order.id).payments()
+        return self.to_order_page(order.id).payments()
 
     def iter_items(self, order):
-        return self.to_order(order.id).items()
+        return self.to_order_page(order.id).items()
 
     @need_login
     def to_history(self):
@@ -83,7 +83,7 @@ class Amazon(LoginBrowser):
         return self.page
 
     @need_login
-    def to_order(self, order_id):
+    def to_order_page(self, order_id):
         """
         Amazon updates its website in stages: they reroute a random part of
         their users to new pages, and the rest to old ones.
@@ -96,7 +96,19 @@ class Amazon(LoginBrowser):
                 self.order_new.go(order_id=order_id)
             except HTTPNotFound:
                 self.order_old.go(order_id=order_id)
-        raise OrderNotFound()
+        self.logger.warning('Order %s not found' % order_id)
+
+    @need_login
+    def to_order(self, order_id):
+        """
+        Amazon updates its website in stages: they reroute a random part of
+        their users to new pages, and the rest to old ones.
+        """
+
+        try:
+            return self.to_order_page(order_id).order()
+        except AttributeError:
+            self.logger.warning('Order %s not found' % order_id)
 
     def do_login(self):
         self.session.cookies.clear()
@@ -107,15 +119,19 @@ class Amazon(LoginBrowser):
     def location(self, *args, **kwargs):
         """
         Amazon throws 500 HTTP status code for apparently valid requests
-        from time to time. Requests eventually succeed after retrying.
+        from time to time. Requests eventually succeed after login again and retrying.
         """
         for i in xrange(self.MAX_RETRIES):
             try:
                 return super(Amazon, self).location(*args, **kwargs)
-            except (ServerError, Timeout, ConnectionError) as e:
+            except (ServerError, Timeout, ConnectionError, TooManyRedirects) as e:
+                self.do_login()
+                self.logger.warning('Exception %s was caught, retry %d' % (type(e).__name__, i))
                 pass
         raise e
 
+
+
     @need_login
     def get_subscription_list(self):
         sub = Subscription()
