@@ -21,7 +21,7 @@
 from dateutil.relativedelta import relativedelta
 from decimal import Decimal, InvalidOperation
 import re
-from cStringIO import StringIO
+from io import BytesIO
 
 from weboob.capabilities import NotAvailable
 from weboob.capabilities.bank import Account
@@ -31,7 +31,7 @@ from weboob.browser.filters.standard import CleanText, Regexp, CleanDecimal, Env
 from weboob.browser.filters.html import Attr
 from weboob.tools.captcha.virtkeyboard import MappedVirtKeyboard, VirtKeyboardError
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
-from weboob.exceptions import ParseError
+from weboob.exceptions import BrowserIncorrectPassword
 
 
 class Transaction(FrenchTransaction):
@@ -56,7 +56,7 @@ class VirtKeyboard(MappedVirtKeyboard):
     def __init__(self, page):
         img = page.doc.find("//img[@usemap='#cv']")
         res = page.browser.open(img.attrib['src'])
-        MappedVirtKeyboard.__init__(self, StringIO(res.content), page.doc, img, self.color, 'href', convert='RGB')
+        MappedVirtKeyboard.__init__(self, BytesIO(res.content), page.doc, img, self.color, 'href', convert='RGB')
 
         self.check_symbols(self.symbols, page.browser.responses_dirname)
 
@@ -95,7 +95,8 @@ class LoginPage(HTMLPage):
 
         form = self.get_form('//form[@id="formulaire-login"]')
         code = vk.get_string_code(password)
-        assert len(code)==10, ParseError("Wrong number of character.")
+        if not len(code)==10:
+            BrowserIncorrectPassword()
         form['accordirect.identifiant'] = login
         form['accordirect.code'] = code
         form.submit()
@@ -104,7 +105,7 @@ class LoginPage(HTMLPage):
 class IndexPage(LoggedPage, HTMLPage):
     @method
     class get_list(ListElement):
-        item_xpath = '//li[@id="menu-n2-mesproduits"]//li//a'
+        item_xpath = '(//li[@id="menu-n2-mesproduits"])[1]//li//a'
 
         class item(ItemElement):
             klass = Account
