@@ -17,24 +17,34 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
 
+from binascii import hexlify
 import datetime
-from urlparse import urlsplit, parse_qsl
 from decimal import Decimal
 import re
-import urllib
+import sys
 
-from weboob.browser.filters.standard import CleanText, Regexp
+from weboob.browser.elements import method, DictElement, ItemElement
+from weboob.browser.filters.standard import CleanText, CleanDecimal, Regexp, Eval, DateTime, Date, Field
 from weboob.browser.filters.html import Attr, Link, AttributeNotFound
+from weboob.browser.filters.json import Dict
 from weboob.exceptions import BrowserUnavailable, BrowserIncorrectPassword
 
-from weboob.browser.pages import HTMLPage, LoggedPage, FormNotFound
+from weboob.browser.pages import HTMLPage, LoggedPage, FormNotFound, JsonPage, RawPage
 
 from weboob.capabilities.bank import Account, Investment
+from weboob.capabilities.contact import Advisor
 from weboob.capabilities import NotAvailable
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
+from weboob.tools.compat import urlsplit, parse_qsl
 from weboob.tools.json import json
 from weboob.tools.misc import to_unicode
+from weboob.tools.pdf import get_pdf_rows
+
+
+class LoggedOut(Exception):
+    pass
 
 
 class BrokenPageError(Exception):
@@ -43,26 +53,39 @@ class BrokenPageError(Exception):
 
 class WikipediaARC4(object):
     def __init__(self, key=None):
-        self.state = range(256)
+        assert isinstance(key, bytes)
+        self.state = list(range(256))
         self.x = self.y = 0
 
         if key is not None:
             self.init(key)
 
+    @staticmethod
+    def ord(i):
+        if sys.version_info.major < 3:
+            return ord(i)
+        return i
+
+    @staticmethod
+    def chr(i):
+        if sys.version_info.major < 3:
+            return chr(i)
+        return bytes([i])
+
     def init(self, key):
         for i in range(256):
-            self.x = (ord(key[i % len(key)]) + self.state[i] + self.x) & 0xFF
+            self.x = (self.ord(key[i % len(key)]) + self.state[i] + self.x) & 0xFF
             self.state[i], self.state[self.x] = self.state[self.x], self.state[i]
         self.x = 0
 
     def crypt(self, input):
         output = [None]*len(input)
-        for i in xrange(len(input)):
+        for i in range(len(input)):
             self.x = (self.x + 1) & 0xFF
             self.y = (self.state[self.x] + self.y) & 0xFF
             self.state[self.x], self.state[self.y] = self.state[self.y], self.state[self.x]
-            output[i] = chr((ord(input[i]) ^ self.state[(self.state[self.x] + self.state[self.y]) & 0xFF]))
-        return ''.join(output)
+            output[i] = self.chr((self.ord(input[i]) ^ self.state[(self.state[self.x] + self.state[self.y]) & 0xFF]))
+        return b''.join(output)
 
 
 class BasePage(object):
@@ -78,14 +101,17 @@ class BasePage(object):
         return token
 
     def on_load(self):
-        self.browser.token = self.get_token()
-        self.logger.debug('Update token to %s', self.browser.token)
+        token = self.get_token()
+        if token:
+            self.browser.token = token
+            self.logger.debug('Update token to %s', self.browser.token)
 
     def is_error(self):
         for script in self.doc.xpath('//script'):
             if script.text is not None and \
                (u"Le service est momentanément indisponible" in script.text or
-                u"Votre abonnement ne vous permet pas d'accéder à ces services" in script.text):
+                u"Votre abonnement ne vous permet pas d'accéder à ces services" in script.text or
+                u'Merci de bien vouloir nous en excuser' in script.text):
                 return True
 
         return False
@@ -177,8 +203,9 @@ class RedirectPage(LoggedPage, MyHTMLPage):
 
     def add_cookie(self, name, value):
         # httplib/cookielib don't seem to like unicode cookies...
-        name = to_unicode(name).encode('utf-8')
-        value = to_unicode(value).encode('utf-8')
+        if sys.version_info.major < 3:
+            name = to_unicode(name).encode('utf-8')
+            value = to_unicode(value).encode('utf-8')
         self.browser.logger.debug('adding cookie %r=%r', name, value)
         self.browser.session.cookies.set(name, value)
 
@@ -205,10 +232,11 @@ class RedirectPage(LoggedPage, MyHTMLPage):
 
                 m = re.match("^setCookie\('([^']+)', .*rc4EncryptStr\((\w+), \w+\)", line)
                 if m:
-                    self.add_cookie(m.group(1), RC4.crypt(args[m.group(2)]).encode('hex'))
+                    enc = RC4.crypt(args[m.group(2)].encode('ascii'))
+                    self.add_cookie(m.group(1), hexlify(enc).decode('ascii'))
 
                 if RC4 is None and 'i' in args:
-                    RC4 = WikipediaARC4(args['i'])
+                    RC4 = WikipediaARC4(args['i'].encode('ascii'))
 
         if redirect_url is not None:
             url = self.browser.absurl(redirect_url)
@@ -238,7 +266,11 @@ class ErrorPage(LoggedPage, MyHTMLPage):
 
 class UnavailablePage(LoggedPage, MyHTMLPage):
     def on_load(self):
-        a = Link('//a[@class="btn"][1]')(self.doc)
+        h1 = CleanText('//h1[1]')(self.doc)
+        if "est indisponible" in h1:
+            raise BrowserUnavailable(h1)
+
+        a = Link('//a[@class="btn"][1]', default=None)(self.doc)
         if not a:
             raise BrowserUnavailable()
         self.browser.location(a)
@@ -252,6 +284,9 @@ class LoginPage(MyHTMLPage):
             text = CleanText('//h4[1]')(self.doc) or h1
             raise BrowserUnavailable(text)
 
+        if not self.browser.no_login:
+            raise LoggedOut()
+
     def login(self, login, passwd):
         form = self.get_form(name='Login')
         form['IDToken1'] = login.encode(self.ENCODING)
@@ -267,24 +302,31 @@ class Login2Page(LoginPage):
         return 'https://www.icgauth.banquepopulaire.fr/dacswebssoissuer/api/v1u0/transaction/%s' % transactionID
 
     def on_load(self):
+        if not self.browser.no_login:
+            raise LoggedOut()
+
         r = self.browser.open(self.request_url)
-        doc = json.loads(r.content)
-        self.form_id = doc['step']['validationUnits'][0]['PASSWORD_LOOKUP'][0]['id']
+        doc = r.json()
+
+        self.form_id, = [(k, v[0]['id']) for k, v in doc['step']['validationUnits'][0].items() if v[0]['type'] == 'PASSWORD_LOOKUP']
 
     def login(self, login, password):
-        payload = {'validate': {'PASSWORD_LOOKUP': [{'id': self.form_id,
-                                                     'login': login.encode(self.ENCODING).upper(),
-                                                     'password': password.encode(self.ENCODING),
-                                                     'type': 'PASSWORD_LOOKUP'
-                                                    }]
-                               }
-                  }
+        payload = {
+            'validate': {
+                self.form_id[0]: [ {
+                    'id': self.form_id[1],
+                    'login': login.upper(),
+                    'password': password,
+                    'type': 'PASSWORD_LOOKUP',
+                } ]
+            }
+        }
 
         url = self.request_url + '/step'
         headers = {'Content-Type': 'application/json'}
         r = self.browser.open(url, data=json.dumps(payload), headers=headers)
 
-        doc = json.loads(r.content)
+        doc = r.json()
         self.logger.debug('doc = %s', doc)
         if 'phase' in doc and doc['phase']['state'] == 'TERMS_OF_USE':
             # Got:
@@ -296,7 +338,7 @@ class Login2Page(LoginPage):
             url = self.request_url + '/step'
             headers = {'Content-Type': 'application/json'}
             r = self.browser.open(url, data=json.dumps(payload), headers=headers)
-            doc = json.loads(r.content)
+            doc = r.json()
             self.logger.debug('doc = %s', doc)
 
         if ('phase' in doc and doc['phase']['previousResult'] == 'FAILED_AUTHENTICATION') or \
@@ -316,6 +358,12 @@ class IndexPage(LoggedPage, MyHTMLPage):
 
 
 class HomePage(LoggedPage, MyHTMLPage):
+    # Sometimes, the page is empty but nothing is scrapped on it.
+    def build_doc(self, data, *args, **kwargs):
+        if not data:
+            return None
+        return super(MyHTMLPage, self).build_doc(data, *args, **kwargs)
+
     def get_token(self):
         vary = None
         if self.params.get('vary', None) is not None:
@@ -330,9 +378,9 @@ class HomePage(LoggedPage, MyHTMLPage):
                     vary = m.group(1)
                     break
 
-        url = self.browser.absurl('/portailinternet/Transactionnel/Pages/CyberIntegrationPage.aspx?%s' % urllib.urlencode({'vary': vary}))
+        url = self.browser.absurl('/portailinternet/Transactionnel/Pages/CyberIntegrationPage.aspx')
         headers = {'Referer': self.url}
-        r = self.browser.open(url, data='taskId=aUniversMesComptes', headers=headers)
+        r = self.browser.open(url, data='taskId=aUniversMesComptes', params={'vary': vary}, headers=headers)
 
         if not int(r.headers.get('Content-Length', 0)):
             url = self.browser.absurl('/portailinternet/Transactionnel/Pages/CyberIntegrationPage.aspx')
@@ -360,19 +408,20 @@ class HomePage(LoggedPage, MyHTMLPage):
 
 
 class AccountsPage(LoggedPage, MyHTMLPage):
-    ACCOUNT_TYPES = {u'Mes comptes d\'épargne':        Account.TYPE_SAVINGS,
-                     u'Mon épargne':                   Account.TYPE_SAVINGS,
-                     u'Placements':                    Account.TYPE_SAVINGS,
-                     u'Liste complète de mon épargne': Account.TYPE_SAVINGS,
-                     u'Mes comptes':                   Account.TYPE_CHECKING,
-                     u'Comptes en euros':              Account.TYPE_CHECKING,
-                     u'Liste complète de mes comptes': Account.TYPE_CHECKING,
-                     u'Mes emprunts':                  Account.TYPE_LOAN,
-                     u'Liste complète de mes emprunts':Account.TYPE_LOAN,
-                     u'Financements':                  Account.TYPE_LOAN,
-                     u'Mes services':                  None,    # ignore this kind of accounts (no bank ones)
-                     u'Équipements':                   None,    # ignore this kind of accounts (no bank ones)
-                     u'Synthèse':                      None,    # ignore this title
+    ACCOUNT_TYPES = {u'Mes comptes d\'épargne':            Account.TYPE_SAVINGS,
+                     u'Mon épargne':                       Account.TYPE_SAVINGS,
+                     u'Placements':                        Account.TYPE_SAVINGS,
+                     u'Liste complète de mon épargne':     Account.TYPE_SAVINGS,
+                     u'Mes comptes':                       Account.TYPE_CHECKING,
+                     u'Comptes en euros':                  Account.TYPE_CHECKING,
+                     u'Liste complète de mes comptes':     Account.TYPE_CHECKING,
+                     u'Mes emprunts':                      Account.TYPE_LOAN,
+                     u'Liste complète de mes emprunts':    Account.TYPE_LOAN,
+                     u'Financements':                      Account.TYPE_LOAN,
+                     u'Liste complète de mes engagements': Account.TYPE_LOAN,
+                     u'Mes services':                      None,    # ignore this kind of accounts (no bank ones)
+                     u'Équipements':                       None,    # ignore this kind of accounts (no bank ones)
+                     u'Synthèse':                          None,    # ignore this title
                     }
 
     PATTERN = [(re.compile('.*Titres Pea.*'), Account.TYPE_PEA),
@@ -380,6 +429,8 @@ class AccountsPage(LoggedPage, MyHTMLPage):
                (re.compile('.*Titres.*'), Account.TYPE_MARKET),
                (re.compile('.*Selection Vie.*'),Account.TYPE_LIFE_INSURANCE),
                (re.compile('^Fructi Pulse.*'), Account.TYPE_MARKET),
+               (re.compile('^(Quintessa|Solevia).*'), Account.TYPE_MARKET),
+               (re.compile('^Plan Epargne Enfant Mul.*'), Account.TYPE_MARKET),
                ]
 
     def pop_up(self):
@@ -402,7 +453,7 @@ class AccountsPage(LoggedPage, MyHTMLPage):
         params = self.get_params()
         actions = self.get_button_actions()
 
-        for div in self.doc.getroot().cssselect('div.btit'):
+        for div in self.doc.xpath('//div[has-class("btit")]'):
             if div.text in (None, u'Synthèse'):
                 continue
             account_type = self.ACCOUNT_TYPES.get(div.text.strip(), Account.TYPE_UNKNOWN)
@@ -413,11 +464,10 @@ class AccountsPage(LoggedPage, MyHTMLPage):
                 continue
 
             # Go to the full list of this kind of account, if any.
-            btn = div.getparent().xpath('.//button/span[text()="Suite"]')
+            btn = div.getparent().xpath('.//button[span[text()="Suite"]]')
             if len(btn) > 0:
-                btn = btn[0].getparent()
                 _params = params.copy()
-                _params.update(actions[btn.attrib['id']])
+                _params.update(actions[btn[0].attrib['id']])
                 next_pages.append(_params)
                 continue
 
@@ -485,11 +535,10 @@ class AccountsPage(LoggedPage, MyHTMLPage):
                 yield account
 
         # Needed to preserve navigation.
-        btn = self.doc.xpath('.//button/span[text()="Retour"]')
+        btn = self.doc.xpath('.//button[span[text()="Retour"]]')
         if len(btn) > 0:
-            btn = btn[0].getparent()
             _params = params.copy()
-            _params.update(actions[btn.attrib['id']])
+            _params.update(actions[btn[0].attrib['id']])
             self.browser.open('/cyber/internet/ContinueTask.do', data=_params)
 
 
@@ -498,25 +547,32 @@ class AccountsFullPage(AccountsPage):
 
 
 class CardsPage(LoggedPage, MyHTMLPage):
-    COL_ID = 0
-    COL_TYPE = 1
-    COL_LABEL = 2
-    COL_DATE = 3
-    COL_AMOUNT = 4
+    COL_ID = 1
+    COL_TYPE = 2
+    COL_LABEL = 3
+    COL_DATE = 4
+    COL_AMOUNT = 5
 
     def iter_accounts(self, next_pages):
         params = self.get_params()
 
         account = None
         currency = None
-        for th in self.doc.xpath('//table[@id="TabCtes"]//thead//th'):
+        for th in self.doc.xpath('//table[@id="tbl1"]//thead//th'):
             m = re.match('.*\((\w+)\)$', th.text)
             if m and currency is None:
                 currency = Account.get_currency(m.group(1))
 
-        for tr in self.doc.xpath('//table[@id="TabCtes"]/tbody/tr'):
+        if currency is None:
+            currency = Account.get_currency(CleanText('//td[@id="tbl1_0_5_Cell"]/span')(self.doc))
+
+        for tr in self.doc.xpath('//table[@id="tbl1"]/tbody/tr'):
             cols = tr.xpath('./td')
 
+            if len(cols) == 1 and CleanText('.')(cols[0]) == 'pas de carte':
+                self.logger.debug('there are no cards on this page')
+                continue
+
             id = CleanText(None).filter(cols[self.COL_ID])
             if len(id) > 0:
                 if account is not None:
@@ -548,7 +604,7 @@ class CardsPage(LoggedPage, MyHTMLPage):
                 self.logger.warning('Unable to parse date %r' % date_col)
                 continue
 
-            date = datetime.date(*reversed(map(int, m.groups())))
+            date = datetime.date(*[int(c) for c in m.groups()][::-1])
             if date.year < 100:
                 date = date.replace(year=date.year+2000)
 
@@ -566,12 +622,11 @@ class CardsPage(LoggedPage, MyHTMLPage):
             yield account
 
         # Needed to preserve navigation.
-        btn = self.doc.xpath('.//button/span[text()="Retour"]')
+        btn = self.doc.xpath('.//button[span[text()="Retour"]]')
         if len(btn) > 0:
-            btn = btn[0].getparent()
             actions = self.get_button_actions()
             _params = params.copy()
-            _params.update(actions[btn.attrib['id']])
+            _params.update(actions[btn[0].attrib['id']])
             self.browser.open('/cyber/internet/ContinueTask.do', data=_params)
 
 
@@ -733,47 +788,25 @@ class TransactionsPage(LoggedPage, MyHTMLPage):
         return url, params if url and params else None
 
 
-class LineboursePage(LoggedPage, HTMLPage):
-    pass
-
-
-class InvestmentLineboursePage(LoggedPage, HTMLPage):
-    COL_LABEL = 0
-    COL_QUANTITY = 1
-    COL_UNITVALUE = 2
-    COL_VALUATION = 3
-    COL_UNITPRICE = 4
-    COL_PERF_PERCENT = 5
-    COL_PERF = 6
-
-    def get_investments(self):
-        for line in self.doc.xpath('//table[contains(@summary, "Contenu")]/tbody/tr[@class="color4"]'):
-            cols1 = line.findall('td')
-            cols2 = line.xpath('./following-sibling::tr')[0].findall('td')
-
-            cleaner = CleanText(None).filter
-
-            inv = Investment()
-            inv.label = cleaner(cols1[self.COL_LABEL].xpath('.//span')[0])
-            inv.code = cleaner(cols1[self.COL_LABEL].xpath('./a')[0]).split(' ')[-1]
-            inv.quantity = self.parse_decimal(cols2[self.COL_QUANTITY])
-            inv.unitprice = self.parse_decimal(cols2[self.COL_UNITPRICE])
-            inv.unitvalue = self.parse_decimal(cols2[self.COL_UNITVALUE])
-            inv.valuation = self.parse_decimal(cols2[self.COL_VALUATION])
-            inv.diff = self.parse_decimal(cols2[self.COL_PERF])
-
-            yield inv
-
-    def parse_decimal(self, string):
-        value = CleanText(None).filter(string)
-        if value == '':
-            return NotAvailable
-        return Decimal(Transaction.clean_amount(value))
+class NatixisChoicePage(LoggedPage, HTMLPage):
+    def on_load(self):
+        message = CleanText('//span[@class="rf-msgs-sum"]', default='')(self.doc)
+        if re.search(r"Le service de consultation de votre contrat \w+ est momentanément indisponible.", message):
+            raise BrowserUnavailable()
+        # TODO handle when there are multiple accounts on this page
+        account_tr, = self.doc.xpath('//tbody[@id="list:dataVie:tb"]/tr')
+        self.logger.info('opening automatically account %s', CleanText('./td[1]')(account_tr))
+        self.browser.location(Link('./td[1]/a')(account_tr))
 
 
 class NatixisPage(LoggedPage, HTMLPage):
     def submit_form(self):
         form = self.get_form(name="formRoutage")
+        form['javax.faces.source'] = 'formRoutageButton'
+        form['javax.faces.partial.execute'] = 'formRoutageButton @component'
+        form['javax.faces.partial.render'] = '@component'
+        form['AJAX:EVENTS_COUNT'] = '1'
+        form['javax.faces.partial.ajax'] = 'true'
         form.submit()
 
 
@@ -781,41 +814,6 @@ class NatixisErrorPage(LoggedPage, HTMLPage):
     pass
 
 
-class InvestmentNatixisPage(LoggedPage, HTMLPage):
-    COL_LABEL = 0
-    COL_QUANTITY = 2
-    COL_UNITVALUE = 3
-    COL_VALUATION = 4
-
-    def get_investments(self):
-        for line in self.doc.xpath('//div[@class="row-fluid table-contrat-supports"]/table/tbody[(@class)]/tr'):
-            cols = line.findall('td')
-
-            inv = Investment()
-            inv.label = CleanText(None).filter(cols[self.COL_LABEL]).replace('Cas sans risque ', '')
-            inv.quantity = self.parse_decimal(cols[self.COL_QUANTITY])
-            inv.unitvalue = self.parse_decimal(cols[self.COL_UNITVALUE])
-            inv.valuation = self.parse_decimal(cols[self.COL_VALUATION])
-
-            yield inv
-
-    def parse_decimal(self, string):
-        value = CleanText(None).filter(string).replace('Si famille fonds generaux, on affiche un tiret', '').replace('Cas sans risque', '').replace(' ', '')
-        if value == '-':
-            return NotAvailable
-        return Decimal(Transaction.clean_amount(value))
-
-
-class MessagePage(LoggedPage, HTMLPage):
-    def skip(self):
-        try:
-            form = self.get_form(name="leForm")
-        except FormNotFound:
-            pass
-        else:
-            form.submit()
-
-
 class IbanPage(LoggedPage, MyHTMLPage):
     def need_to_go(self):
         return len(self.doc.xpath('//div[@class="grid"]/div/span[contains(text(), "IBAN")]')) == 0
@@ -845,5 +843,155 @@ class IbanPage(LoggedPage, MyHTMLPage):
 
 
 class EtnaPage(LoggedPage, MyHTMLPage):
-    def on_load(self):
-        raise NotImplementedError()
+    pass
+
+
+def float_to_decimal(f):
+    # Decimal(float_value) gives horrible results, convert to str first
+    return Decimal(str(f))
+
+
+class NatixisInvestPage(LoggedPage, JsonPage):
+    @method
+    class get_investments(DictElement):
+        item_xpath = 'detailContratVie/valorisation/supports'
+
+        class item(ItemElement):
+            klass = Investment
+
+            obj_label = CleanText(Dict('nom'))
+            obj_code = CleanText(Dict('codeIsin'))
+
+            def obj_vdate(self):
+                dt = Dict('dateValeurUniteCompte', default=None)(self)
+                if dt is None:
+                    dt = self.page.doc['detailContratVie']['valorisation']['date']
+                return DateTime().filter(dt)
+
+            obj_valuation = Eval(float_to_decimal, Dict('montant'))
+            obj_quantity = Eval(float_to_decimal, Dict('nombreUnitesCompte'))
+            obj_unitvalue = Eval(float_to_decimal, Dict('valeurUniteCompte'))
+            obj_portfolio_share = Eval(lambda x: float_to_decimal(x) / 100, Dict('repartition'))
+
+
+class NatixisHistoryPage(LoggedPage, JsonPage):
+    @method
+    class get_history(DictElement):
+        item_xpath = None
+
+        class item(ItemElement):
+            klass = Transaction
+
+            obj_amount = Eval(float_to_decimal, Dict('montantNet'))
+            obj_raw = CleanText(Dict('libelle', default=''))
+            obj_vdate = DateTime(Dict('dateValeur', default=NotAvailable), default=NotAvailable)
+            obj_date = DateTime(Dict('dateEffet', default=NotAvailable), default=NotAvailable)
+            obj_investments = NotAvailable
+            obj_type = Transaction.TYPE_BANK
+
+            def validate(self, obj):
+                return bool(obj.raw) and bool(obj.date)
+
+
+def use_invest_date(tr):
+    dates = [invest.vdate for invest in tr.investments]
+    if not dates:
+        return
+
+    assert all(d == dates[0] for d in dates)
+    tr.date = dates[0]
+
+
+class NatixisDetailsPage(LoggedPage, RawPage):
+    def build_doc(self, data):
+        return list(get_pdf_rows(data))
+
+    COL_LABEL = 0
+    COL_DATE = 1
+    COL_TR_AMOUNT = 2
+    COL_VALUATION = 3
+    COL_UNITVALUE = 4
+    COL_QUANTITY = 5
+
+    # warning: tr amount is "brut", unlike invest amounts ("net")...
+
+    def get_history(self):
+        tr = None
+
+        for page in self.doc:
+            for n, row in enumerate(page):
+                if len(row) != 7:
+                    continue
+
+                label = ' '.join(row[self.COL_LABEL])
+
+                if row[self.COL_TR_AMOUNT]:
+                    if tr is not None:
+                        if n == 0 and label == tr.label:
+                            self.logger.debug('%r seems to continue on next page', tr)
+                            continue
+                        yield tr
+
+                        tr = None
+
+                    if not label:
+                        # this pdf is really cryptic...
+                        # we assume blue rows are a new transaction
+                        # but if no label, it doesn't appear in the website json
+                        continue
+
+                    tr = Transaction()
+                    tr.type = Transaction.TYPE_BANK
+                    tr.raw = tr.label = label
+                    tr.amount = CleanDecimal(replace_dots=True).filter(''.join(row[self.COL_TR_AMOUNT]))
+                elif not row[self.COL_DATE]:
+                    if not tr:
+                        # ignore transactions with the empty label, see above
+                        continue
+
+                    if label == 'Investissement':
+                        tr.amount = abs(tr.amount)
+                    elif label == 'Désinvestissement':
+                        tr.amount = -abs(tr.amount)
+                    else:
+                        assert False, 'unhandled line %s' % label
+                    assert not any(len(cell) for cell in row[self.COL_LABEL+1:]), 'there should be only the label'
+                else:
+                    if not tr:
+                        continue
+
+                    inv = Investment()
+                    inv.label = label
+                    inv.valuation = CleanDecimal(replace_dots=True).filter(row[self.COL_VALUATION])
+                    if tr.amount < 0:
+                        inv.valuation = -inv.valuation
+                    inv.vdate = Date(dayfirst=True).filter(''.join(row[self.COL_DATE]))
+                    tr.date = inv.vdate
+
+                    inv.quantity = CleanDecimal(replace_dots=True, default=NotAvailable).filter(''.join(row[self.COL_QUANTITY]))
+                    if inv.quantity and tr.amount < 0:
+                        inv.quantity = -inv.quantity
+                    inv.unitvalue = CleanDecimal(replace_dots=True, default=NotAvailable).filter(''.join(row[self.COL_UNITVALUE]))
+
+                    tr.investments.append(inv)
+
+        if tr:
+            yield tr
+
+
+class AdvisorPage(LoggedPage, MyHTMLPage):
+    @method
+    class get_advisor(ItemElement):
+        klass = Advisor
+
+        condition = lambda self: Field('name')(self)
+
+        obj_name = CleanText(u'//div[label[contains(text(), "Votre conseiller")]]/span')
+        obj_agency = CleanText(u'//div[label[contains(text(), "Votre agence")]]/span')
+        obj_email = obj_mobile = NotAvailable
+
+    @method
+    class update_agency(ItemElement):
+        obj_phone = CleanText(u'//div[label[contains(text(), "Téléphone")]]/span', replace=[('.', '')])
+        obj_fax = CleanText(u'//div[label[contains(text(), "Fax")]]/span', replace=[('.', '')])
+        obj_address = CleanText(u'//div[div[contains(text(), "Votre agence")]]/following-sibling::div[1]//div[not(label)]/span')
