@@ -21,7 +21,7 @@
 from weboob.tools.backend import Module, BackendConfig
 from weboob.capabilities.bank import CapBank, AccountNotFound
 from weboob.capabilities.base import find_object
-from weboob.tools.value import ValueBackendPassword, Value
+from weboob.tools.value import ValueBackendPassword, ValueDate
 from .browser import BforbankBrowser
 
 
@@ -34,19 +34,19 @@ class BforbankModule(Module, CapBank):
     MAINTAINER = u'Baptiste Delpey'
     EMAIL = 'b.delpey@hotmail.fr'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.2'
+    VERSION = '1.3'
     CONFIG = BackendConfig(ValueBackendPassword('login',    label='Identifiant', masked=False),
-                           ValueBackendPassword('password', label='Code personnel'),
-                           Value('birthdate', label='Date de naissance', regexp='^(\d{2}[/-]?\d{2}[/-]?\d{4}|)$')
+                           ValueBackendPassword('password', label='Code personnel', regexp=r'\d+$'),
+                           ValueDate('birthdate', label='Date de naissance', formats=('%d/%m/%Y',))
                            )
 
     BROWSER = BforbankBrowser
 
     def create_default_browser(self):
-        return self.create_browser(self.weboob,
-                                   self.config['birthdate'].get(),
+        return self.create_browser(self.config['birthdate'].get(),
                                    self.config['login'].get(),
-                                   self.config['password'].get())
+                                   self.config['password'].get(),
+                                   weboob=self.weboob)
 
     def get_account(self, _id):
         return find_object(self.browser.iter_accounts(), id=_id, error=AccountNotFound)
@@ -55,7 +55,7 @@ class BforbankModule(Module, CapBank):
         return self.browser.iter_accounts()
 
     def iter_coming(self, account):
-        raise NotImplementedError()
+        return self.browser.get_coming(account)
 
     def iter_history(self, account):
         return self.browser.get_history(account)
