@@ -17,17 +17,24 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+
+from collections import OrderedDict
 import re
-from StringIO import StringIO
+from io import BytesIO
+
 from PIL import Image
 
 from weboob.browser.pages import LoggedPage, HTMLPage, pagination, AbstractPage
-from weboob.browser.elements import method, ListElement, ItemElement
+from weboob.browser.elements import method, ListElement, ItemElement, TableElement
 from weboob.capabilities.bank import Account
 from weboob.browser.filters.html import Link, Attr
-from weboob.browser.filters.standard import CleanText, Regexp, Field, Map, \
-                                            CleanDecimal
+from weboob.browser.filters.standard import (
+    CleanText, Regexp, Field, Map, CleanDecimal, Date, TableCell,
+)
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
+from weboob.tools.compat import urlencode, urlparse, urlunparse, parse_qsl, urljoin
+import datetime
 
 
 class BfBKeyboard(object):
@@ -48,7 +55,7 @@ class BfBKeyboard(object):
         self.fingerprints = []
         for htmlimg in self.basepage.doc.xpath('.//div[@class="m-btn-pin"]//img'):
             url = htmlimg.attrib.get("src")
-            imgfile = StringIO(basepage.browser.open(url).content)
+            imgfile = BytesIO(basepage.browser.open(url).content)
             img = Image.open(imgfile)
             matrix = img.load()
             s = ""
@@ -112,7 +119,7 @@ class RibPage(LoggedPage, HTMLPage):
 
     def get_iban(self, accounts):
         for account in accounts:
-            if self.doc.xpath('//option[@selected and contains(@value, "%s")]' % account.id):
+            if self.doc.xpath('//option[@selected and contains(@value, $id)]', id=account.id):
                 account.iban = CleanText('//td[contains(text(), "IBAN")]/following-sibling::td[1]', replace=[(' ', '')])(self.doc)
 
 
@@ -132,9 +139,9 @@ class AccountsPage(LoggedPage, HTMLPage):
 
             TYPE = {'Livret':        Account.TYPE_SAVINGS,
                     'Compte':        Account.TYPE_CHECKING,
-                    'PEA':           Account.TYPE_MARKET,
+                    'PEA':           Account.TYPE_PEA,
+                    'PEA-PME':       Account.TYPE_PEA,
                     'Compte-titres': Account.TYPE_MARKET,
-                    'PEA-PME':       Account.TYPE_MARKET,
                     'Assurance-vie': Account.TYPE_LIFE_INSURANCE,
                    }
 
@@ -143,14 +150,21 @@ class AccountsPage(LoggedPage, HTMLPage):
             obj_balance = MyDecimal('./td//div[contains(@class, "-synthese-num")]', replace_dots=True)
             obj_currency = FrenchTransaction.Currency('./td//div[contains(@class, "-synthese-num")]')
             obj_type = Map(Regexp(Field('label'), r'^([^ ]*)'), TYPE, default=Account.TYPE_UNKNOWN)
-            obj__link = CleanText('./@data-href')
+
+            def obj_url(self):
+                return urljoin(self.page.url, CleanText('./@data-href')(self))
+
+            obj__card_balance = CleanDecimal('./td//div[@class="synthese-encours"][last()]/div[2]', default=None)
 
             def condition(self):
                 return not len(self.el.xpath('./td[@class="chart"]'))
 
+
 class Transaction(FrenchTransaction):
     PATTERNS = [(re.compile('^(?P<category>VIREMENT)'), FrenchTransaction.TYPE_TRANSFER),
                 (re.compile('^(?P<category>INTERETS)'), FrenchTransaction.TYPE_BANK),
+                (re.compile('^RETRAIT AU DISTRIBUTEUR'), FrenchTransaction.TYPE_WITHDRAWAL),
+                (re.compile(u'^Règlement cartes à débit différé du'), FrenchTransaction.TYPE_CARD_SUMMARY),
                ]
 
 
@@ -179,9 +193,9 @@ class HistoryPage(LoggedPage, HTMLPage):
             klass = Transaction
 
             def condition(self):
-                if 'tr-section' in self.el.attrib['class']:
+                if 'tr-section' in self.el.attrib.get('class', ''):
                     return False
-                elif 'tr-trigger' in self.el.attrib['class']:
+                elif 'tr-trigger' in self.el.attrib.get('class', ''):
                     return True
 
                 return False
@@ -193,6 +207,120 @@ class HistoryPage(LoggedPage, HTMLPage):
             obj_amount = MyDecimal('./td[2]', replace_dots=True)
 
 
+    @method
+    class get_today_operations(TableElement):
+        item_xpath = '//table[has-class("style-virements")]/tbody/tr[@class="tr-trigger"]'
+        head_xpath = '//table[has-class("style-virements")]/thead/tr/th'
+
+        col_amount = 'Montant'
+        col_raw = u'Libellé'
+
+        class item(ItemElement):
+            klass = Transaction
+
+            def obj_date(self):
+                return datetime.date.today()
+
+            obj_raw = Transaction.Raw(TableCell('raw'))
+            obj_amount = MyDecimal(TableCell('amount'), replace_dots=True)
+
+
+def add_qs(url, **kwargs):
+    parts = list(urlparse(url))
+    qs = OrderedDict(parse_qsl(parts[4]))
+    qs.update(kwargs)
+    parts[4] = urlencode(qs)
+    return urlunparse(parts)
+
+
+class CardHistoryPage(LoggedPage, HTMLPage):
+    def get_card_indexes(self):
+        for opt in self.doc.xpath('//select[@id="select-box-card"]/option'):
+            number = CleanText('.')(opt).replace(' ', '').replace('*', 'x')
+            number = re.search(r'\d{4}x+\d{4}', number).group(0)
+            yield number, opt.attrib['value']
+
+    def get_balance(self):
+        div, = self.doc.xpath('//div[@class="m-tabs-tab-meta"]')
+        for d in div.xpath('.//div[has-class("pull-left")]'):
+            if 'opération(s):' in CleanText('.')(d):
+                return MyDecimal('./span', replace_dots=True)(d)
+
+    def get_debit_date(self):
+        return Date(Regexp(CleanText('//div[@class="m-tabs-tab-meta"]'),
+                           r'Ces opérations (?:seront|ont été) débitées sur votre compte le (\d{2}/\d{2}/\d{4})'),
+                    dayfirst=True)(self.doc)
+
+    def create_summary(self):
+        tr = Transaction()
+        tr.type = Transaction.TYPE_CARD_SUMMARY
+        tr.amount = abs(self.get_balance())
+        tr.label = 'Règlement cartes à débit différé'
+        tr.date = tr.rdate = self.get_debit_date()
+        return tr
+
+    @pagination
+    @method
+    class get_operations(TableElement):
+        head_xpath = '//table[has-class("style-operations")]//th'
+        item_xpath = '//table[has-class("style-operations")]/tbody/tr[not(has-class("tr-category") or has-class("tr-more"))]'
+
+        def next_page(self):
+            page = Attr('//a[@id="next-page"]', 'data')(self)
+            return add_qs(self.page.url, page=page)
+
+        col_raw = u'Libellé'
+        col_vdate = u'Date opération'
+        col_amount = 'Montant'
+
+        class item(ItemElement):
+            klass = Transaction
+
+            def condition(self):
+                return CleanText('.')(self) != u'Aucune opération effectuée'
+
+            obj_type = Transaction.TYPE_DEFERRED_CARD
+
+            obj_raw = CleanText(TableCell('raw'))
+            obj_vdate = obj_rdate = Date(CleanText(TableCell('vdate')), dayfirst=True)
+            obj_amount = MyDecimal(TableCell('amount'), replace_dots=True)
+
+            def obj_date(self):
+                return self.page.get_debit_date()
+
+
+class CardPage(LoggedPage, HTMLPage):
+    def get_cards(self, account_id):
+        divs = self.doc.xpath('//div[@class="content-boxed"]')
+        assert len(divs)
+
+        msgs = re.compile(u'Vous avez fait opposition sur cette carte bancaire.|Votre carte bancaire a été envoyée.')
+        divs = [d for d in divs if not msgs.search(CleanText('.//div[has-class("alert")]', default='')(d))]
+        divs = [d.xpath('.//div[@class="m-card-infos"]')[0] for d in divs]
+        divs = [d for d in divs if not d.xpath('.//div[@class="m-card-infos-body-text"][text()="Débit immédiat"]')]
+
+        if not len(divs):
+            self.logger.warning('all cards are cancelled, acting as if there is no card')
+            return []
+
+        cards = []
+        for div in divs:
+            label = CleanText('.//div[@class="m-card-infos-body-title"]')(div)
+            number = CleanText('.//div[@class="m-card-infos-body-num"]', default='')(div)
+            number = re.sub('[^\d*]', '', number).replace('*', 'x')
+            debit = CleanText(u'.//div[@class="m-card-infos-body-text"][contains(text(),"Débit")]')(div)
+            assert debit == u'Débit différé', 'unrecognized card type %s: %s' % (number, debit)
+
+            card = Account()
+            card.id = '%s.%s' % (account_id, number)
+            card.label = label
+            card.number = number
+            card.type = Account.TYPE_CARD
+            cards.append(card)
+
+        return cards
+
+
 class LifeInsuranceList(LoggedPage, HTMLPage):
     @method
     class iter_accounts(ListElement):
@@ -202,7 +330,9 @@ class LifeInsuranceList(LoggedPage, HTMLPage):
             klass = Account
 
             obj_id = CleanText('./td/a')
-            obj__link = Link('./td/a')
+
+            def obj_url(self):
+                return urljoin(self.page.url, Link('./td/a')(self))
 
 
 class LifeInsuranceIframe(LoggedPage, HTMLPage):
