@@ -25,30 +25,23 @@ from requests.exceptions import ConnectionError
 
 from weboob.browser.browsers import LoginBrowser, URL, need_login
 from weboob.capabilities.base import find_object
-from weboob.capabilities.bank import AccountNotFound, Account, TransferError
+from weboob.capabilities.bank import AccountNotFound, Account, TransferError, AddRecipientStep
 from weboob.tools.decorators import retry
 from weboob.tools.json import json
 from weboob.browser.exceptions import ServerError
 from weboob.exceptions import BrowserIncorrectPassword
+from weboob.tools.value import Value
 
 from .pages import LoginPage, AccountsPage, AccountsIBANPage, HistoryPage, TransferInitPage, \
                    ConnectionThresholdPage, LifeInsurancesPage, LifeInsurancesHistoryPage, \
                    LifeInsurancesDetailPage, MarketListPage, MarketPage, MarketHistoryPage, \
                    MarketSynPage, RecipientsPage, ValidateTransferPage, RegisterTransferPage, \
-                   AdvisorPage
+                   AdvisorPage, AddRecipPage, ActivateRecipPage
 
 
 __all__ = ['BNPPartPro', 'HelloBank']
 
 
-class CompatMixin(object):
-    def __enter__(self):
-        return self
-
-    def __exit__(self, type, value, tb):
-        pass
-
-
 def JSON(data):
     return ('json', data)
 
@@ -67,7 +60,8 @@ class JsonBrowserMixin(object):
 
         return super(JsonBrowserMixin, self).open(*args, **kwargs)
 
-class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
+
+class BNPParibasBrowser(JsonBrowserMixin, LoginBrowser):
     TIMEOUT = 30.0
 
     login = URL(r'identification-wspl-pres/identification\?acceptRedirection=true&timestamp=(?P<timestamp>\d+)',
@@ -97,6 +91,8 @@ class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
     market_history = URL('/pe-war/rpc/turnOverHistory/get', MarketHistoryPage)
 
     recipients = URL('/virement-wspl/rest/listerBeneficiaire', RecipientsPage)
+    add_recip = URL('/virement-wspl/rest/ajouterBeneficiaire', AddRecipPage)
+    activate_recip = URL('/virement-wspl/rest/activerBeneficiaire', ActivateRecipPage)
     validate_transfer = URL('/virement-wspl/rest/validationVirement', ValidateTransferPage)
     register_transfer = URL('/virement-wspl/rest/enregistrerVirement', RegisterTransferPage)
 
@@ -120,7 +116,9 @@ class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
     def get_accounts_list(self):
         if self.accounts_list is None:
             self.accounts_list = []
-            ibans = self.ibans.go().get_ibans_dict()
+            # In case of password renewal, we need to go on ibans twice.
+            self.ibans.go()
+            ibans = self.page.get_ibans_dict() if self.ibans.is_here() else self.ibans.go().get_ibans_dict()
             # This page might be unavailable.
             try:
                 ibans.update(self.transfer_init.go(data=JSON({'modeBeneficiaire': '0'})).get_ibans_dict('Crediteur'))
@@ -131,7 +129,9 @@ class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
             self.market_syn.go(data=JSON({}))
             for account in accounts:
                 for market_acc in self.page.get_list():
-                    if account.number[-4:] == market_acc['securityAccountNumber'][-4:] and account.type == Account.TYPE_MARKET:
+                    if account.number[-4:] == market_acc['securityAccountNumber'][-4:] and \
+                        account.type in (Account.TYPE_MARKET, Account.TYPE_PEA) and not account.iban:
+                        account.balance = market_acc.get('valorisation', account.balance)
                         account.valuation_diff = market_acc['profitLoss']
                         break
                 self.accounts_list.append(account)
@@ -145,7 +145,7 @@ class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
     def iter_history(self, account, coming=False):
         if account.type == account.TYPE_LIFE_INSURANCE:
             return self.iter_lifeinsurance_history(account, coming)
-        elif account.type == account.TYPE_MARKET and not coming:
+        elif account.type in (account.TYPE_MARKET, Account.TYPE_PEA) and not coming:
             try:
                 self.market_list.go(data=JSON({}))
             except ServerError:
@@ -191,19 +191,19 @@ class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
 
     @need_login
     def iter_investment(self, account):
-        if account.type == account.TYPE_LIFE_INSURANCE:
+        if account.type in (account.TYPE_LIFE_INSURANCE, account.TYPE_PERP):
             self.lifeinsurances.go(data=JSON({
                 "ibanCrypte": account.id,
             }))
             return self.page.iter_investments()
-        elif account.type == account.TYPE_MARKET:
+        elif account.type in (account.TYPE_MARKET, account.TYPE_PEA):
             try:
                 self.market_list.go(data=JSON({}))
             except ServerError:
                 self.logger.warning("An Internal Server Error occured")
                 return iter([])
             for market_acc in self.page.get_list():
-                if account.number[-4:] == market_acc['securityAccountNumber'][-4:]:
+                if account.number[-4:] == market_acc['securityAccountNumber'][-4:] and not account.iban:
                     # Sometimes generate an Internal Server Error ...
                     try:
                         self.market.go(data=JSON({
@@ -231,6 +231,7 @@ class BNPParibasBrowser(CompatMixin, JsonBrowserMixin, LoginBrowser):
     def get_thread(self, thread):
         raise NotImplementedError()
 
+
 class BNPPartPro(BNPParibasBrowser):
     BASEURL_TEMPLATE = r'https://%s.bnpparibas/'
     BASEURL = BASEURL_TEMPLATE % 'mabanque'
@@ -283,9 +284,39 @@ class BNPPartPro(BNPParibasBrowser):
         self.register_transfer.go(data=JSON({'referenceVirement': transfer.id}))
         return self.page.handle_response(transfer)
 
+    @need_login
+    def send_code(self, recipient, **params):
+        # depending on whether recipient is a weboob or a budgea backend object.
+        _id = recipient.webid if hasattr(recipient, 'webid') else recipient.id
+        data = {}
+        data['idBeneficiaire'] = _id
+        data['typeActivation'] = 1
+        data['codeActivation'] = params['code']
+        return self.activate_recip.go(data=json.dumps(data), headers={'Content-Type': 'application/json'}).get_recipient(recipient)
+
+    @need_login
+    def new_recipient(self, recipient, **params):
+        if 'code' in params:
+            return self.send_code(recipient, **params)
+        # needed to get the phone number, enabling the possibility to send sms.
+        self.recipients.go(data=JSON({'type': 'TOUS'}))
+        # post recipient data sending sms with same request
+        data = {}
+        data['adresseBeneficiaire'] = ''
+        data['iban'] = recipient.iban
+        data['libelleBeneficiaire'] = recipient.label
+        data['notification'] = True
+        data['typeBeneficiaire'] = ''
+        data['typeEnvoi'] = 'SMS'
+        recipient = self.add_recip.go(data=json.dumps(data), headers={'Content-Type': 'application/json'}).get_recipient(recipient)
+        raise AddRecipientStep(recipient, Value('code', label='Saississez le code.'))
+
     @need_login
     def get_advisor(self):
-        return self.advisor.stay_or_go().get_advisor()
+        self.advisor.stay_or_go()
+        if self.page.has_error():
+            return None
+        return self.page.get_advisor()
 
 
 class HelloBank(BNPParibasBrowser):
