@@ -17,21 +17,21 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-
+from collections import Counter
 import re
-from cStringIO import StringIO
+from io import BytesIO
 from random import randint
 from decimal import Decimal
-from datetime import datetime
+from datetime import datetime, timedelta
 
 from weboob.browser.elements import DictElement, ListElement, ItemElement, method
 from weboob.browser.filters.json import Dict
 from weboob.browser.filters.standard import Format, Regexp, CleanText
 from weboob.browser.pages import JsonPage, LoggedPage, HTMLPage
 from weboob.capabilities import NotAvailable
-from weboob.capabilities.bank import Account, Investment, Recipient, Transfer, TransferError
+from weboob.capabilities.bank import Account, Investment, Recipient, Transfer, TransferError, TransferBankError, AddRecipientError
 from weboob.capabilities.contact import Advisor
-from weboob.exceptions import BrowserIncorrectPassword, BrowserUnavailable
+from weboob.exceptions import BrowserIncorrectPassword, BrowserUnavailable, BrowserPasswordExpired, ActionNeeded
 from weboob.tools.capabilities.bank.iban import rib2iban, rebuild_rib, is_iban_valid
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 from weboob.tools.captcha.virtkeyboard import GridVirtKeyboard
@@ -51,13 +51,71 @@ class ConnectionThresholdPage(HTMLPage):
         data['confirmNouveauPassword'] = vk.get_string_code(newpass)
         data['nouveauPassword'] = vk.get_string_code(newpass)
         data['passwordActuel'] = vk.get_string_code(oldpass)
-        self.browser.location('/mcs-wspl/rpc/modifiercodesecret', data=data)
+        response = self.browser.location('/mcs-wspl/rpc/modifiercodesecret', data=data)
+        if response.json().get('messageIden').lower() == 'nouveau mot de passe invalide':
+            return False
+        return True
+
+    def make_date(self, yy, m, d):
+        current = datetime.now().year
+        if yy > current - 2000:
+            yyyy = 1900 + yy
+        else:
+            yyyy = 2000 + yy
+        return datetime(yyyy, m, d)
+
+    def looks_legit(self, password):
+        # the site says:
+        # no more than 2 repeats
+        for v in Counter(password).values():
+            if v > 2:
+                return False
+
+        # not the birthdate (but we don't know it)
+        first, mm, end = map(int, (password[0:2], password[2:4], password[4:6]))
+        now = datetime.now()
+        try:
+            delta = now - self.make_date(first, mm, end)
+        except ValueError:
+            pass
+        else:
+            if 10 < delta.days / 365 < 70:
+                return False
+
+        try:
+            delta = now - self.make_date(end, mm, first)
+        except ValueError:
+            pass
+        else:
+            if 10 < delta.days / 365 < 70:
+                return False
+
+        # no sequence (more than 4 digits?)
+        password = list(map(int, password))
+        up = 0
+        down = 0
+        for a, b in zip(password[:-1], password[1:]):
+            up += int(a + 1 == b)
+            down += int(a - 1 == b)
+        if up >= 4 or down >= 4:
+            return False
+
+        return True
 
     def on_load(self):
+        if not self.looks_legit(self.browser.password):
+            # we may not be able to restore the password, so reject it
+            raise BrowserPasswordExpired()
+
         new_pass = ''.join([str((int(l) + 1) % 10) for l in self.browser.password])
         self.logger.warning('Password expired. Renewing it. Temporary password is %s', new_pass)
-        self.change_pass(self.browser.password, new_pass)
-        self.change_pass(new_pass, self.browser.password)
+        if not self.change_pass(self.browser.password, new_pass):
+            self.logger.warning('New temp password is rejected, giving up')
+            raise BrowserPasswordExpired()
+
+        if not self.change_pass(new_pass, self.browser.password):
+            self.logger.error('Could not restore old password!')
+
 
 def cast(x, typ, default=None):
     try:
@@ -83,7 +141,7 @@ class BNPKeyboard(GridVirtKeyboard):
     def __init__(self, page, image):
         symbols = list('%02d' % x for x in range(1, 11))
 
-        super(BNPKeyboard, self).__init__(symbols, 5, 2, StringIO(image.content), self.color, convert='RGB')
+        super(BNPKeyboard, self).__init__(symbols, 5, 2, BytesIO(image.content), self.color, convert='RGB')
         self.check_symbols(self.symbols, page.browser.responses_dirname)
 
 
@@ -111,6 +169,10 @@ class LoginPage(JsonPage):
         if self.url.startswith('https://mabanqueprivee.'):
             self.browser.switch('mabanqueprivee')
 
+        # Some kind of internal server error instead of normal wrongpass errorCode.
+        if self.get('errorCode') == 'INTO_FACADE ERROR: JDF_GENERIC_EXCEPTION':
+            raise BrowserIncorrectPassword()
+
         error = cast(self.get('errorCode'), int, 0)
 
         if error:
@@ -119,7 +181,12 @@ class LoginPage(JsonPage):
             if error in codes:
                 raise BrowserIncorrectPassword(msg)
             elif error == 1001:
-                raise BrowserUnavailable(msg)
+                # json says "Erreur lors de l'authentification Code retour : 1001 Code retour : 1001"
+                # but js message from "getErrorMessage" says "veuillez contacter votre conseiller"...
+                raise BrowserIncorrectPassword()
+            elif error == 21501: # "Rendez-vous sur le site de BNP Paribas pour gérer vos comptes"
+                raise ActionNeeded(msg)
+
             self.logger.debug('Unexpected error at login: "%s" (code=%s)' % (msg, error))
 
     def login(self, username, password):
@@ -174,7 +241,10 @@ class AccountsPage(BNPPage):
     }
 
     LABEL_TO_TYPE = {
-        u'PEA Espèces':    Account.TYPE_SAVINGS,
+        u'PEA Espèces':                       Account.TYPE_PEA,
+        u'PEA Titres':                        Account.TYPE_PEA,
+        u'PEL':                               Account.TYPE_SAVINGS,
+        u'Plan Epargne Retraite Particulier': Account.TYPE_PERP,
     }
 
     def iter_accounts(self, ibans):
@@ -188,7 +258,8 @@ class AccountsPage(BNPPage):
                     'id': a.get('key'),
                     'label': a.get('libellePersoProduit') or a.get('libelleProduit'),
                     'currency': a.get('devise'),
-                    'type': self.LABEL_TO_TYPE.get(a.get('libelleProduit')) or self.FAMILY_TO_TYPE.get(f.get('idFamilleCompte')) or Account.TYPE_UNKNOWN,
+                    'type': self.LABEL_TO_TYPE.get(' '.join(a.get('libelleProduit').split())) or \
+                            self.FAMILY_TO_TYPE.get(f.get('idFamilleCompte')) or Account.TYPE_UNKNOWN,
                     'balance': a.get('soldeDispo'),
                     'coming': a.get('soldeAVenir'),
                     'iban': iban,
@@ -203,14 +274,13 @@ class AccountsIBANPage(BNPPage):
 class MyRecipient(ItemElement):
     klass = Recipient
 
-    obj_currency = Dict('devise')
-
-    def obj_enabled_at(self):
-        return datetime.now().replace(microsecond=0)
+    def obj_currency(self):
+        return Dict('devise')(self) or NotAvailable
 
     def validate(self, el):
-        assert is_iban_valid(el.iban)
-        return True
+        # For the moment, we skip this kind of recipient:
+        # {"nomBeneficiaire":"Aircraft Guaranty Holdings LLC","idBeneficiaire":"00002##00002##FRSTUS44XXX##130018430","ibanNumCompte":"130018430","typeIban":"0","bic":"FRSTUS44XXX","statut":"1","numListe":"00002","typeBeneficiaire":"INTER","devise":"USD","tauxConversion":"1.047764","nbDecimale":"2","typeFrais":"","adresseBeneficiaire":"","nomBanque":"Frost National Bank","adresseBanque":"100 West Houston Street San Antonio, Texas 78205 USA ","canalActivation":"1","libelleStatut":"Activé"}
+        return is_iban_valid(el.iban)
 
 class TransferInitPage(BNPPage):
     def on_load(self):
@@ -239,6 +309,9 @@ class TransferInitPage(BNPPage):
             def obj_bank_name(self):
                 return u'BNP PARIBAS'
 
+            def obj_enabled_at(self):
+                return datetime.now().replace(microsecond=0)
+
 
 class RecipientsPage(BNPPage):
     @method
@@ -247,7 +320,7 @@ class RecipientsPage(BNPPage):
 
         class item(MyRecipient):
             # For the moment, only yield ready to transfer on recipients.
-            condition = lambda self: Dict('libelleStatut')(self.el) == u'Activé'
+            condition = lambda self: Dict('libelleStatut')(self.el) in [u'Activé', u'Temporisé']
 
             obj_id = Dict('idBeneficiaire')
             obj_label = Dict('nomBeneficiaire')
@@ -257,11 +330,14 @@ class RecipientsPage(BNPPage):
             def obj_bank_name(self):
                 return Dict('nomBanque')(self) or NotAvailable
 
+            def obj_enabled_at(self):
+                return datetime.now().replace(microsecond=0) if Dict('libelleStatut')(self) == u'Activé' else (datetime.now() + timedelta(days=5)).replace(microsecond=0)
+
 
 class ValidateTransferPage(BNPPage):
     def check_errors(self):
         if not 'data' in self.doc:
-            raise TransferError(self.doc['message'])
+            raise TransferBankError(message=self.doc['message'])
 
     def abort_if_unknown(self, transfer_data):
         try:
@@ -317,7 +393,8 @@ class RegisterTransferPage(ValidateTransferPage):
         transfer.id = transfer_data['reference']
         assert transfer.exec_date == Date(self.doc['data']['enregistrementVirement']['dateExecution']).date()
         # Timestamp at which the bank registered the transfer
-        transfer._register_date = Date(self.doc['data']['enregistrementVirement']['dateEnregistrement'])
+        register_date = re.sub(' 24:', ' 00:', self.doc['data']['enregistrementVirement']['dateEnregistrement'])
+        transfer._register_date = Date(register_date)
 
         return transfer
 
@@ -438,6 +515,9 @@ class LifeInsurancesHistoryPage(BNPPage):
                 'amount': op.get('montantNet'),
                 })
 
+            if op.get('statut') == 'Sans suite':
+                continue
+
             tr.parse(date=Date(op.get('dateSaisie')),
                      vdate=Date(op.get('dateEffet')),
                      raw='%s %s' % (op.get('libelleMouvement'), op.get('canalSaisie') or ''))
@@ -500,6 +580,9 @@ class MarketHistoryPage(BNPPage):
 
 
 class AdvisorPage(BNPPage):
+    def has_error(self):
+        return (self.doc.get('message') == 'Erreur technique')
+
     @method
     class get_advisor(ListElement):
         class item(ItemElement):
@@ -512,3 +595,33 @@ class AdvisorPage(BNPPage):
             obj_fax = CleanText(Dict('data/fax'), replace=[(' ', '')])
             obj_agency = Dict('data/agence')
             obj_address = Format('%s %s %s', Dict('data/adresseAgence'), Dict('data/codePostalAgence'), Dict('data/villeAgence'))
+
+
+class AddRecipPage(BNPPage):
+    def on_load(self):
+        code = cast(self.get('codeRetour'), int)
+        if code:
+            raise AddRecipientError(self.get('message'))
+
+    def get_recipient(self, recipient):
+        r = Recipient()
+        r.iban = recipient.iban
+        r.id = self.get('data.gestionBeneficiaire.identifiantBeneficiaire')
+        r.label = recipient.label
+        r.category = u'Externe'
+        r.enabled_at = datetime.now().replace(microsecond=0) + timedelta(days=5)
+        r.currency = u'EUR'
+        r.bank_name = NotAvailable
+        return r
+
+class ActivateRecipPage(AddRecipPage):
+    def get_recipient(self, recipient):
+        r = Recipient()
+        r.iban = recipient.iban
+        r.id = recipient.webid if hasattr(recipient, 'webid') else recipient.id
+        r.label = recipient.label
+        r.category = u'Externe'
+        r.enabled_at = datetime.now().replace(microsecond=0) + timedelta(days=5)
+        r.currency = u'EUR'
+        r.bank_name = self.get('data.activationBeneficiaire.nomBanque')
+        return r
