@@ -24,12 +24,11 @@ from weboob.capabilities.messages import CantSendMessage
 from weboob.capabilities.bill import Bill, Subscription
 from weboob.browser.pages import HTMLPage, JsonPage, LoggedPage
 from weboob.browser.filters.json import Dict
-from weboob.browser.filters.standard import CleanDecimal, CleanText, Env, Format, Regexp
+from weboob.browser.filters.standard import CleanDecimal, CleanText, Env, Format, Regexp, Field
 from weboob.browser.filters.html import Link
 from weboob.browser.elements import DictElement, ItemElement, ListElement, method
 from weboob.tools.date import parse_french_date
 
-
 class LoginPage(HTMLPage):
     def login(self, login, password):
         form = self.get_form('//form[@id="log_data"]')
@@ -52,15 +51,20 @@ class ProfilePage(JsonPage, LoggedPage):
         class item(ItemElement):
             klass = Subscription
 
-            obj_id = CleanText(Dict('num_ligne'))
             obj__type = CleanText(Dict('type'))
             obj_label = Env('label')
             obj_subscriber = Format("%s %s %s", CleanText(Dict('civilite')),
                                     CleanText(Dict('prenom')), CleanText(Dict('nom')))
 
+            def obj_id(self):
+                if Dict('date-activation')(self) is not None:
+                    return Format('%s-%s', Dict('num_ligne'), Dict('date-activation'))(self)
+                else:
+                    return Format('%s', Dict('num_ligne'))(self)
+
             def parse(self, el):
                 # add spaces
-                number = iter(self.obj_id(el))
+                number = iter(Field('id')(self).split('-')[0])
                 self.env['label'] = ' '.join(a+b for a, b in zip(number, number))
 
 
@@ -89,11 +93,13 @@ class DocumentsPage(HTMLPage):
         options = self.doc.xpath('//select[@id="factureMois"]/option[position() > 1]/@value')
 
         for option in options:
-            ref = self.doc.xpath('//span[contains(text(), "%s")]/ \
-                ancestor::div[has-class("etape-content")]//a[@id="btnAnciennesFactures"]' % label)
-            if ref:
-                # Get ref and return it
-                return re.search('reference=([\d]+)', Link().filter(ref)).group(1)
+            for ctr in self.doc.xpath('//div[has-class("eccoetape")]'):
+                if ctr.xpath('.//span[contains(text(), $label)]', label=label):
+                    ref = ctr.xpath('.//a[@id="btnAnciennesFactures"]')
+                    if ref:
+                        return re.search('reference=([\d]+)', Link().filter(ref)).group(1)
+
+            self.logger.debug("couldn't find ref this month, retrying with %s", option)
             self.doc = self.browser.open('%s?mois=%s' % (self.browser.url, option)).page.doc
         return None
 
@@ -120,3 +126,7 @@ class DocumentsPage(HTMLPage):
             def condition(self):
                 # XXX ugly fix to avoid duplicate bills
                 return CleanText('./@facture-id')(self.el) != CleanText('./following-sibling::div[1]/@facture-id')(self.el)
+
+
+class UselessPage(HTMLPage):
+    pass
