@@ -21,9 +21,10 @@
 from .login import LoginPage, Initident, CheckPassword,repositionnerCheminCourant, BadLoginPage, AccountDesactivate, UnavailablePage
 from .accountlist import AccountList, AccountRIB, Advisor
 from .accounthistory import AccountHistory, CardsList
-from .transfer import TransferChooseAccounts, CompleteTransfer, TransferConfirm, TransferSummary
+from .transfer import TransferChooseAccounts, CompleteTransfer, TransferConfirm, TransferSummary, CreateRecipient, ValidateRecipient,\
+                      ValidateCountry, ConfirmPage, RcptSummary
 
 
-__all__ = ['LoginPage','Initident', 'CheckPassword', 'repositionnerCheminCourant', "AccountList", 'AccountHistory', 'BadLoginPage',
+__all__ = ['LoginPage', 'Initident', 'CheckPassword', 'repositionnerCheminCourant', "AccountList", 'AccountHistory', 'BadLoginPage',
            'AccountDesactivate', 'TransferChooseAccounts', 'CompleteTransfer', 'TransferConfirm', 'TransferSummary', 'UnavailablePage',
-           'CardsList', 'AccountRIB', 'Advisor']
+           'CardsList', 'AccountRIB', 'Advisor', 'CreateRecipient', 'ValidateRecipient', 'ValidateCountry', 'ConfirmPage', 'RcptSummary']
