@@ -18,13 +18,14 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 import re
-import datetime
-from dateutil.relativedelta import relativedelta
 from decimal import Decimal
 
-from weboob.browser.filters.standard import CleanText
-from weboob.browser.pages import LoggedPage, CsvPage
+from weboob.browser.elements import ListElement, ItemElement, method
+from weboob.browser.filters.standard import CleanText, CleanDecimal, Date
+from weboob.browser.filters.html import Link
+from weboob.browser.pages import LoggedPage, pagination
 from weboob.capabilities.bank import Account
+from weboob.tools.compat import urljoin, unicode
 
 from .accounthistory import Transaction
 from .base import MyHTMLPage
@@ -36,16 +37,18 @@ class RedirectPage(LoggedPage, MyHTMLPage):
 
 
 class ProAccountsList(LoggedPage, MyHTMLPage):
-    ACCOUNT_TYPES = {u'Comptes titres': Account.TYPE_MARKET,
-                     u'Comptes Ã©pargne':    Account.TYPE_SAVINGS,
-                     u'Comptes courants':    Account.TYPE_CHECKING,
+    ACCOUNT_TYPES = {u'comptes titres': Account.TYPE_MARKET,
+                     u'comptes Ã©pargne':    Account.TYPE_SAVINGS,
+                     # wtf? ^
+                     u'comptes épargne':     Account.TYPE_SAVINGS,
+                     u'comptes courants':    Account.TYPE_CHECKING,
                     }
     def get_accounts_list(self):
         for table in self.doc.xpath('//div[@class="comptestabl"]/table'):
             try:
-                account_type = self.ACCOUNT_TYPES[table.get('summary')]
+                account_type = self.ACCOUNT_TYPES[table.get('summary').lower()]
                 if not account_type:
-                    account_type = self.ACCOUNT_TYPES[table.xpath('./caption/text()')[0].strip()]
+                    account_type = self.ACCOUNT_TYPES[table.xpath('./caption/text()')[0].strip().lower()]
             except (IndexError,KeyError):
                 account_type = Account.TYPE_UNKNOWN
             for tr in table.xpath('./tbody/tr'):
@@ -64,46 +67,24 @@ class ProAccountsList(LoggedPage, MyHTMLPage):
                 if not a.currency:
                     a.currency = u'EUR'
                 a.balance = Decimal(Transaction.clean_amount(tmp_balance))
-                a._card_links = []
-                a._link_id = link.attrib['href']
+                a._has_cards = False
+                a.url = urljoin(self.url, link.attrib['href'])
                 yield a
 
 
 class ProAccountHistory(LoggedPage, MyHTMLPage):
-    def on_load(self):
-        MyHTMLPage.on_load(self)
-        link = self.doc.xpath('//a[contains(@href, "telechargercomptes.ea")]/@href')[0]
-        self.browser.location(link)
+    @pagination
+    @method
+    class iter_history(ListElement):
+        item_xpath = u'//div[@id="tabReleve"]//tbody/tr'
+        next_page = Link('//div[@class="pagination"]//li[@class="pagin-on-right"]/a')
 
+        class item(ItemElement):
+            klass = Transaction
 
-class ProAccountHistoryDownload(LoggedPage, MyHTMLPage):
-    def on_load(self):
-        MyHTMLPage.on_load(self)
-        form = self.get_form(name='telechargement')
-        form['dateDebutPeriode'] = (datetime.date.today() - relativedelta(months=11)).strftime('%d/%m/%Y')
-        form.submit()
-
-
-class ProAccountHistoryCSV(LoggedPage, CsvPage):
-    FMTPARAMS = {'delimiter': ';'}
-
-    def get_next_link(self):
-        return False
-
-    def get_history(self, deferred=False):
-        operations = []
-        for line in self.doc:
-            if len(line) < 4 or line[0] == 'Date':
-                continue
-            t = Transaction()
-            t.parse(raw=line[1], date=line[0])
-            t.set_amount(line[2])
-            t._coming = False
-            operations.append(t)
-        operations = sorted(operations,
-                      lambda a, b: cmp(a.date, b.date), reverse=True)
-        for op in operations:
-            yield op
+            obj_date = Date(CleanText('.//td[@headers="date"]'), dayfirst=True)
+            obj_raw = Transaction.Raw('.//td[@headers="libelle"]')
+            obj_amount = CleanDecimal('.//td[@headers="debit" or @headers="credit"]', replace_dots=True)
 
 
 class DownloadRib(LoggedPage, MyHTMLPage):
