@@ -20,11 +20,13 @@
 
 from datetime import datetime
 
-from weboob.capabilities.bank import TransferError, Recipient, NotAvailable, Transfer, TransferStep, AccountNotFound
+from weboob.capabilities.bank import (
+    TransferError, TransferBankError, Transfer, TransferStep, NotAvailable, Recipient, AccountNotFound, AddRecipientError
+)
 from weboob.capabilities.base import find_object
 from weboob.browser.pages import LoggedPage
 from weboob.browser.filters.standard import CleanText, Env, Regexp, Date, CleanDecimal
-from weboob.browser.filters.html import Attr
+from weboob.browser.filters.html import Attr, Link
 from weboob.browser.elements import ListElement, ItemElement, method, SkipItem
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 from weboob.tools.capabilities.bank.iban import is_iban_valid
@@ -36,8 +38,9 @@ class CheckTransferError(MyHTMLPage):
     def on_load(self):
         MyHTMLPage.on_load(self)
         error = CleanText(u'//span[@class="app_erreur"] | //p[@class="warning"] | //p[contains(text(), "Votre virement n\'a pas pu être enregistré")]')(self.doc)
-        if error:
-            raise TransferError(error)
+        if error and not u'Votre demande de virement a été enregistrée le' in error:
+            raise TransferBankError(message=error)
+
 
 class TransferChooseAccounts(LoggedPage, MyHTMLPage):
     def is_inner(self, text):
@@ -95,15 +98,19 @@ class TransferChooseAccounts(LoggedPage, MyHTMLPage):
                         self.env['id'] = Regexp(CleanText('.'), '- (.*?) -')(el).replace(' ', '')
                         self.env['iban'] = NotAvailable
                         label = CleanText('.')(el).split('-')
-                        self.env['label'] = '%s %s' % (label[0].strip(), label[-1].strip())
+                        holder = label[-1] if not any(string in label[-1] for string in ['Avoir disponible', 'Solde']) else label[-2]
+                        self.env['label'] = '%s %s' % (label[0].strip(), holder.strip())
                     self.env['bank_name'] = u'La Banque Postale'
 
                 else:
                     self.env['id'] = self.env['iban'] = Regexp(CleanText('.'), '- (.*?) -')(el).replace(' ', '')
-                    self.env['label'] = CleanText('.')(el).split('-')[-1].strip()
+                    self.env['label'] = Regexp(CleanText('.'), '- (.*?) - (.*)', template='\\2')(el).strip()
                     first_part = CleanText('.')(el).split('-')[0].strip()
                     self.env['bank_name'] = u'La Banque Postale' if first_part in ['CCP', 'PEL'] else NotAvailable
 
+                if self.env['id'] in self.parent.objects: # user add two recipients with same iban...
+                    raise SkipItem()
+
     def init_transfer(self, account_id, recipient_value):
         matched_values = [Attr('.', 'value')(option) for option in self.doc.xpath('//select[@id="donneesSaisie.idxCompteEmetteur"]/option') \
                           if account_id in CleanText('.')(option)]
@@ -115,11 +122,12 @@ class TransferChooseAccounts(LoggedPage, MyHTMLPage):
 
 
 class CompleteTransfer(LoggedPage, CheckTransferError):
-    def complete_transfer(self, amount, label):
+    def complete_transfer(self, amount, transfer):
         form = self.get_form(xpath='//form[@method]')
         form['montant'] = amount
-        if 'commentaire' in form and label:
-            form['commentaire'] = label
+        if 'commentaire' in form and transfer.label:
+            form['commentaire'] = transfer.label
+        form['dateVirement'] = transfer.exec_date.strftime('%d/%m/%Y')
         form.submit()
 
 
@@ -140,8 +148,8 @@ class TransferConfirm(LoggedPage, CheckTransferError):
         account_txt = CleanText('//form//dl/dt[span[contains(text(), "biter")]]/following::dd[1]', replace=[(' ', '')])(self.doc)
         recipient_txt = CleanText('//form//dl/dt[span[contains(text(), "diter")]]/following::dd[1]', replace=[(' ', '')])(self.doc)
         try:
-            assert account.id in account_txt
-            assert recipient.id in recipient_txt
+            assert account.id in account_txt or ''.join(account.label.split()) == account_txt
+            assert recipient.id in recipient_txt or ''.join(recipient.label.split()) == recipient_txt
         except AssertionError:
             raise TransferError('Something went wrong')
         r_amount =  CleanDecimal('//form//dl/dt[span[contains(text(), "Montant")]]/following::dd[1]', replace_dots=True)(self.doc)
@@ -165,5 +173,56 @@ class TransferConfirm(LoggedPage, CheckTransferError):
 
 class TransferSummary(LoggedPage, CheckTransferError):
     def handle_response(self, transfer):
-        transfer.id = Regexp(CleanText('//div[@class="bloc Tmargin"]'), 'Votre virement N.+ (\d+) ')(self.doc)
+        # NotAvailable in case of future exec_date not on a working day.
+        transfer.id = Regexp(CleanText('//div[@class="bloc Tmargin"]'), 'virement N.+ (\d+) ', default=NotAvailable)(self.doc)
+        if not transfer.id:
+            transfer.exec_date = Date(Regexp(CleanText('//div[@class="bloc Tmargin"]'), 'suivant \(([\d\/]+)\)'), dayfirst=True)(self.doc)
         return transfer
+
+
+class CreateRecipient(LoggedPage, MyHTMLPage):
+    def choose_country(self, recipient, is_bp_account):
+        # if this is present, we can't add recipient currently
+        more_security_needed = self.doc.xpath(u'//iframe[@title="Sécurité renforcée non adhérents"]')
+        if more_security_needed:
+            raise AddRecipientError(u"Pour activer le service Certicode, nous vous invitons à vous rapprocher de votre Conseiller en Bureau de Poste.")
+
+        form = self.get_form(name='SaisiePaysBeneficiaireVirement')
+        form['compteLBP'] = str(is_bp_account).lower()
+        form['beneficiaireBean.paysDestination'] = recipient.iban[:2]
+        form.submit()
+
+
+class ValidateCountry(LoggedPage, MyHTMLPage):
+    def populate(self, recipient):
+        form = self.get_form(name='CaracteristiquesBeneficiaireVirement')
+        form['beneficiaireBean.nom'] = recipient.label
+        form['beneficiaireBean.ibans[1].valeur'] = recipient.iban[2:4]
+        form['beneficiaireBean.ibans[2].valeur'] = recipient.iban[4:8]
+        form['beneficiaireBean.ibans[3].valeur'] = recipient.iban[8:12]
+        form['beneficiaireBean.ibans[4].valeur'] = recipient.iban[12:16]
+        form['beneficiaireBean.ibans[5].valeur'] = recipient.iban[16:20]
+        form['beneficiaireBean.ibans[6].valeur'] = recipient.iban[20:24]
+        form['beneficiaireBean.ibans[7].valeur'] = recipient.iban[24:]
+        form['beneficiaireBean.intituleCompte'] = recipient.label
+        form.submit()
+
+
+class ValidateRecipient(LoggedPage, MyHTMLPage):
+    def is_bp_account(self):
+        msg = CleanText('//span[has-class("app_erreur")]')(self.doc)
+        return msg == u'Le n° de compte que vous avez saisi appartient à La Banque Postale, veuillez vérifier votre saisie.'
+
+    def get_confirm_link(self):
+        return Link('//a[@title="confirmer la creation"]')(self.doc)
+
+
+class ConfirmPage(LoggedPage, MyHTMLPage):
+    def set_browser_form(self):
+        form = self.get_form(name='SaisieOTP')
+        self.browser.recipient_form = dict((k, v) for k, v in form.items() if v)
+        self.browser.recipient_form['url'] = form.url
+
+
+class RcptSummary(LoggedPage, MyHTMLPage):
+    pass
