@@ -24,8 +24,8 @@ from decimal import Decimal
 
 from weboob.capabilities.base import NotAvailable
 from weboob.capabilities.bank import Account
-from weboob.tools.capabilities.bank.transactions import FrenchTransaction
-from weboob.exceptions import BrowserIncorrectPassword, BrowserHTTPError, BrowserUnavailable, ParseError
+from weboob.tools.capabilities.bank.transactions import FrenchTransaction, sorted_transactions
+from weboob.exceptions import BrowserIncorrectPassword, BrowserHTTPError, BrowserUnavailable, ActionNeeded, ParseError
 from weboob.browser import DomainBrowser
 
 
@@ -71,6 +71,8 @@ class BredBrowser(DomainBrowser):
             raise BrowserIncorrectPassword('Your account is disabled')
         if '/pages-gestion-des-erreurs/erreur-technique' in r.url:
             raise BrowserUnavailable('A technical error occured')
+        if '/pages-gestion-des-erreurs/message-tiers-oppose' in r.url:
+            raise ActionNeeded('Cannot connect to account because 2-factor authentication is enabled')
 
     ACCOUNT_TYPES = {'000': Account.TYPE_CHECKING,
                      '999': Account.TYPE_MARKET,
@@ -124,11 +126,27 @@ class BredBrowser(DomainBrowser):
             if univers != self.current_univers:
                 self.move_to_univers(univers)
             accounts.extend(self.get_list())
+            accounts.extend(self.get_loans_list())
         return accounts
 
+    def get_loans_list(self):
+        r = self.api_open('/transactionnel/services/applications/prets/liste')
+
+        if 'content' in r.json():
+            for content in r.json()['content']:
+                a = Account()
+                a.id = "%s.%s" % (content['comptePrets'].strip(), content['numeroDossier'].strip())
+                a.type = Account.TYPE_LOAN
+                a.label = ' '.join([content['intitule'].strip(), content['libellePrets'].strip()])
+                a.balance = -Decimal(str(content['montantCapitalDu']['valeur']))
+                a.currency = content['montantCapitalDu']['monnaie']['code'].strip()
+                yield a
+
     def get_list(self):
         r = self.api_open('/transactionnel/services/rest/Account/accounts')
 
+        seen = set()
+
         for content in r.json()['content']:
             if self.accnum != '00000000000' and content['numero'] != self.accnum:
                 continue
@@ -139,6 +157,14 @@ class BredBrowser(DomainBrowser):
                 a._consultable = poste['consultable']
                 a._univers = self.current_univers
                 a.id = '%s.%s' % (a._number, a._nature)
+
+                if a.id in seen:
+                    # some accounts like "compte à terme fidélis" have the same _number and _nature
+                    # but in fact are kind of closed, so worthless...
+                    self.logger.warning('ignored account id %r (%r) because it is already used', a.id, poste.get('numeroDossier'))
+                    continue
+                seen.add(a.id)
+
                 a.type = self.ACCOUNT_TYPES.get(poste['codeNature'], Account.TYPE_UNKNOWN)
                 if a.type == Account.TYPE_CHECKING:
                     iban_response = self.api_open('/transactionnel/services/rest/Account/account/%s/iban' % a._number).json()
@@ -169,15 +195,16 @@ class BredBrowser(DomainBrowser):
                     a.id += str(poste['monnaie']['codeSwift'])
                 yield a
 
-    def get_history(self, account):
-        if not account._consultable:
+    def get_history(self, account, coming=False):
+        if account.type is Account.TYPE_LOAN or not account._consultable:
             raise NotImplementedError()
 
         if account._univers != self.current_univers:
             self.move_to_univers(account._univers)
+
+        seen = set()
         offset = 0
         next_page = True
-        seen = set()
         while next_page:
             r = self.api_open('/transactionnel/services/applications/operations/get/%(number)s/%(nature)s/00/%(currency)s/%(startDate)s/%(endDate)s/%(offset)s/%(limit)s' %
                           {'number': account._number,
@@ -188,27 +215,42 @@ class BredBrowser(DomainBrowser):
                            'offset': offset,
                            'limit': 50
                           })
-            next_page = False
-            offset += 50
             transactions = []
             for op in reversed(r.json()['content']['operations']):
-                next_page = True
                 t = Transaction()
+                t.id = op['id']
                 if op['id'] in seen:
                     raise ParseError('There are several transactions with the same ID, probably an infinite loop')
-                t.id = op['id']
+
                 seen.add(t.id)
                 d = date.fromtimestamp(op.get('dateDebit', op.get('dateOperation'))/1000)
-                raw = ' '.join([op['libelle']] + op['details'])
+                op['details'] = [re.sub('\s+', ' ', i).replace('\x00', '') for i in op['details'] if i] # sometimes they put "null" elements...
+                label = re.sub('\s+', ' ', op['libelle']).replace('\x00', '')
+                raw = ' '.join([label] + op['details'])
                 vdate = date.fromtimestamp(op.get('dateValeur', op.get('dateDebit', op.get('dateOperation')))/1000)
                 t.parse(d, raw, vdate=vdate)
                 t.amount = Decimal(str(op['montant']))
                 t.rdate = date.fromtimestamp(op.get('dateOperation', op.get('dateDebit'))/1000)
                 if 'categorie' in op:
                     t.category = op['categorie']
-                t.label = op['libelle']
+                t.label = label
+                t._coming = op['intraday']
+                if t._coming:
+                    # coming transactions have a random uuid id (inconsistent between requests)
+                    t.id = ''
                 transactions.append(t)
 
             # Transactions are unsorted
-            for t in sorted(transactions, key=lambda t: t.rdate, reverse=True):
-                yield t
+            for t in sorted_transactions(transactions):
+                if coming == t._coming:
+                    yield t
+                elif coming and not t._coming:
+                    # coming transactions are at the top of history
+                    self.logger.debug('stopping coming after %s', t)
+                    return
+
+            next_page = bool(transactions)
+            offset += 50
+
+            assert offset < 10000, 'the site may be doing an infinite loop'
+
