@@ -20,7 +20,7 @@
 from datetime import datetime
 import re
 
-from weboob.deprecated.browser import Page
+from weboob.browser.pages import XMLPage
 from weboob.capabilities.collection import Collection
 from weboob.capabilities.base import NotAvailable, NotLoaded
 from weboob.capabilities.image import Thumbnail
@@ -28,13 +28,15 @@ from weboob.capabilities.image import Thumbnail
 from .video import CanalplusVideo
 
 
-class ChannelsPage(Page):
+class ChannelsPage(XMLPage):
+    ENCODING = 'utf-8'
+
     def get_channels(self):
         """
         Extract all possible channels (paths) from the page
         """
         channels = list()
-        for elem in self.document[2].getchildren():
+        for elem in self.doc[2].getchildren():
             for e in elem.getchildren():
                 if e.tag == "NOM":
                     fid, name = self._clean_name(e.text)
@@ -48,14 +50,16 @@ class ChannelsPage(Page):
         return channels
 
     def _clean_name(self, name):
-        name = unicode(name.strip())
+        name = name.strip()
         if name == name.upper():
             name = name.capitalize()
-        friendly_id = re.sub(ur"['/_ \(\)\-\+]+", u'-', name).strip(u'-').lower()
+        friendly_id = re.sub(r"['/_ \(\)\-\+]+", u'-', name).strip(u'-').lower()
         return friendly_id, name
 
 
-class VideoPage(Page):
+class VideoPage(XMLPage):
+    ENCODING = 'utf-8'
+
     def parse_video(self, el, video=None):
         _id = el.find('ID').text
         if _id == '-1':
@@ -73,7 +77,7 @@ class VideoPage(Page):
             if len(video.title) > 0:
                 video.title += u' — '
             video.title += part.text.strip()
-        video.description = unicode(infos.find('DESCRIPTION').text)
+        video.description = infos.find('DESCRIPTION').text
 
         media = el.find('MEDIA')
         url = media.find('IMAGES').find('PETIT').text
@@ -88,7 +92,7 @@ class VideoPage(Page):
 
             if format.tag == 'HLS':
                 video.ext = u'm3u8'
-                video.url = unicode(format.text)
+                video.url = format.text
                 break
 
         day, month, year = map(int, infos.find('PUBLICATION').find('DATE').text.split('/'))
@@ -98,13 +102,13 @@ class VideoPage(Page):
         return video
 
     def iter_results(self):
-        for vid in self.document.getchildren():
+        for vid in self.doc.iter(tag='VIDEO'):
             video = self.parse_video(vid)
             video.url = NotLoaded
             yield video
 
     def iter_channel(self):
-        for vid in self.document.getchildren():
+        for vid in self.doc.iter(tag='VIDEO'):
             yield self.parse_video_channel(vid)
 
     def parse_video_channel(self, el):
@@ -115,8 +119,8 @@ class VideoPage(Page):
         return video
 
     def get_video(self, video):
-        _id = self.group_dict['id']
-        for vid in self.document.getchildren():
+        _id = self.params.get('id')
+        for vid in self.doc.iter(tag='VIDEO'):
             if _id not in vid.find('ID').text:
                 continue
             return self.parse_video(vid, video)
