@@ -8,9 +8,9 @@
 # To Public License, Version 2, as published by Sam Hocevar. See
 # http://sam.zoy.org/wtfpl/COPYING for more details.
 
-
-import urllib
+from collections import OrderedDict
 import datetime
+
 from weboob.capabilities.base import NotAvailable
 from weboob.tools.misc import to_unicode
 from weboob.deprecated.browser import Page
@@ -19,7 +19,7 @@ from weboob.deprecated.browser import Browser
 from weboob.deprecated.browser.decorators import id2url
 from weboob.capabilities.image import Thumbnail
 from weboob.capabilities.video import BaseVideo
-from weboob.tools.ordereddict import OrderedDict
+from weboob.tools.compat import quote_plus
 
 
 __all__ = ['CappedBrowser']
@@ -124,7 +124,7 @@ class CappedBrowser(Browser):
         return self.page.get_video(video)
 
     def search_videos(self, pattern):
-        self.location('/search?s=%s' % (urllib.quote_plus(pattern.encode('utf-8'))))
+        self.location('/search?s=%s' % (quote_plus(pattern.encode('utf-8'))))
         assert self.is_on_page(IndexPage)
         return self.page.iter_videos()
 
