@@ -19,20 +19,23 @@
 
 
 import re
+import ast
 
-from urllib import quote
 from decimal import Decimal
 from io import BytesIO
 from datetime import date as da
 from lxml import html
 
 from weboob.browser.pages import HTMLPage, LoggedPage
+from weboob.browser.elements import method, ItemElement
 from weboob.browser.filters.standard import CleanText, Date, CleanDecimal, Regexp
 from weboob.exceptions import ActionNeeded, BrowserIncorrectPassword, BrowserUnavailable
 from weboob.capabilities.bank import Account, Investment
+from weboob.capabilities.profile import Profile
 from weboob.capabilities import NotAvailable
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 from weboob.tools.captcha.virtkeyboard import GridVirtKeyboard
+from weboob.tools.compat import quote, unicode, basestring
 from weboob.tools.json import json
 
 
@@ -102,7 +105,7 @@ class LoginPage(HTMLPage):
             self.classic_login(username,password)
 
     def vk_login(self, username, password):
-        res = self.browser.open('/sec/vk/gen_crypto?estSession=0').content
+        res = self.browser.open('/sec/vk/gen_crypto?estSession=0').text
         crypto = re.search(r"'crypto': '([^']+)'", res).group(1)
         grid = re.search(r"'grid': \[([^\]]+)]", res).group(1).split(',')
 
@@ -138,11 +141,10 @@ class LoginPage(HTMLPage):
 
 
 class CDNBasePage(HTMLPage):
-    def get_from_js(self, pattern, end, is_list=False):
+    def get_from_js(self, pattern, end_pattern, is_list=False):
         """
         find a pattern in any javascript text
         """
-        value = None
         for script in self.doc.xpath('//script'):
             txt = script.text
             if txt is None:
@@ -152,22 +154,17 @@ class CDNBasePage(HTMLPage):
             if start < 0:
                 continue
 
-            while True:
-                if value is None:
-                    value = ''
-                else:
-                    value += ','
-                value += txt[start+len(pattern):start+txt[start+len(pattern):].find(end)+len(pattern)]
+            values = []
+            while start >= 0:
+                start += len(pattern)
+                end = txt.find(end_pattern, start)
+                values.append(txt[start:end])
 
                 if not is_list:
                     break
 
-                txt = txt[start+len(pattern)+txt[start+len(pattern):].find(end):]
-
-                start = txt.find(pattern)
-                if start < 0:
-                    break
-            return value
+                start = txt.find(pattern, end)
+            return ','.join(values)
 
     def get_execution(self):
         return self.get_from_js("name: 'execution', value: '", "'")
@@ -185,11 +182,14 @@ class AccountsPage(LoggedPage, CDNBasePage):
 
     TYPES = {u'CARTE':               Account.TYPE_CARD,
              u'COMPTE COURANT':      Account.TYPE_CHECKING,
+             u'CPT COURANT':         Account.TYPE_CHECKING,
+             u'COMPTE ÉPARGNE':      Account.TYPE_SAVINGS,
              u'COMPTE EPARGNE':      Account.TYPE_SAVINGS,
              u'COMPTE SUR LIVRET':   Account.TYPE_SAVINGS,
              u'LIVRET':              Account.TYPE_SAVINGS,
-             u'P.E.A.':              Account.TYPE_MARKET,
-             u'PEA':                 Account.TYPE_MARKET,
+             u'PLAN ÉPARGNE':        Account.TYPE_SAVINGS,
+             u'PEA':                 Account.TYPE_PEA,
+             u'P.E.A.':              Account.TYPE_PEA,
              u'TITRES':              Account.TYPE_MARKET,
              u'ÉTOILE AVANCE':       Account.TYPE_LOAN,
              u'PRÊT':                Account.TYPE_LOAN,
@@ -198,7 +198,7 @@ class AccountsPage(LoggedPage, CDNBasePage):
             }
 
     def get_account_type(self, label):
-        for pattern, actype in self.TYPES.iteritems():
+        for pattern, actype in sorted(self.TYPES.items()):
             if label.startswith(pattern) or label.endswith(pattern):
                 return actype
 
@@ -213,6 +213,11 @@ class AccountsPage(LoggedPage, CDNBasePage):
     def get_list(self):
         accounts = []
 
+        noaccounts = self.get_from_js('_js_noMvts =', ';')
+        if noaccounts is not None:
+            assert 'avez aucun compte' in noaccounts
+            return []
+
         txt = self.get_from_js('_data = new Array(', ');', is_list=True)
 
         if txt is None:
@@ -223,6 +228,10 @@ class AccountsPage(LoggedPage, CDNBasePage):
         for line in data:
             a = Account()
             a.id = line[self.COL_ID].replace(' ', '')
+
+            if re.match(r'Classement=(.*?):::Banque=(.*?):::Agence=(.*?):::SScompte=(.*?):::Serie=(.*)', a.id):
+                a.id = str(CleanDecimal().filter(a.id))
+
             a._acc_nb = a.id.split('_')[0] if len(a.id.split('_')) > 1 else None
             a.label = MyStrip(line[self.COL_LABEL], xpath='.//div[@class="libelleCompteTDB"]')
             # This account can be multiple life insurance accounts
@@ -263,6 +272,12 @@ class AccountsPage(LoggedPage, CDNBasePage):
         form['_ipc_eventValue'] = 'bouchon=bouchon'
         form.submit()
 
+    @method
+    class get_profile(ItemElement):
+        klass = Profile
+
+        obj_name = CleanText('//p[@class="nom"]')
+
 
 class AVPage(LoggedPage, CDNBasePage):
     COL_LABEL = 0
@@ -277,7 +292,7 @@ class AVPage(LoggedPage, CDNBasePage):
         for sub in re.findall("'([^']*)'", text):
             l.append(sub)
         for i, key in enumerate(self.ARGS):
-            args[key] = unicode(l[self.ARGS.index(key)]).encode(self.browser.ENCODING)
+            args[key] = l[self.ARGS.index(key)]
 
         return url, args
 
@@ -332,7 +347,7 @@ class ProAccountsPage(AccountsPage):
         if no_accounts_message:
             raise ActionNeeded(no_accounts_message[0])
 
-        for tr in self.doc.xpath('//table[@class="datas"]//tr'):
+        for tr in self.doc.xpath('//table[has-class("datas")]//tr'):
             if tr.attrib.get('class', '') == 'entete':
                 continue
 
@@ -370,6 +385,15 @@ class ProAccountsPage(AccountsPage):
     def iban_page(self):
         self.browser.location(self.doc.xpath('.//a[contains(text(), "Impression IBAN")]')[0].attrib['href'])
 
+    def has_iban(self):
+        return not bool(CleanText('//*[contains(., "pas de compte vous permettant l\'impression de RIB")]')(self.doc))
+
+    @method
+    class get_profile(ItemElement):
+        klass = Profile
+
+        obj_name = CleanText('//p[@class="nom"]')
+
 
 class IbanPage(LoggedPage, HTMLPage):
     def get_iban(self):
@@ -450,7 +474,7 @@ class TransactionsPage(LoggedPage, CDNBasePage):
                 # No history on this account
                 return
 
-        data = json.loads('[%s]' % txt.replace('"', '\\"').replace("'", '"'))
+        data = ast.literal_eval('[%s]' % txt.replace('"', '\\"'))
 
         for line in data:
             t = Transaction()
@@ -458,7 +482,9 @@ class TransactionsPage(LoggedPage, CDNBasePage):
             if acc_type is Account.TYPE_CARD and MyStrip(line[self.COL_DEBIT_DATE]):
                 date = vdate = Date(dayfirst=True).filter(MyStrip(line[self.COL_DEBIT_DATE]))
             else:
-                date = Date(dayfirst=True).filter(MyStrip(line[self.COL_DATE]))
+                date = Date(dayfirst=True, default=NotAvailable).filter(MyStrip(line[self.COL_DATE]))
+                if not date:
+                    continue
                 vdate = MyStrip(line[self.COL_DEBIT_DATE])
                 if vdate != '':
                     vdate = Date(dayfirst=True).filter(vdate)
@@ -515,7 +541,11 @@ class TransactionsPage(LoggedPage, CDNBasePage):
             inv.quantity = MyDecimal('.')(cols[COL_QUANTITY])
             inv.unitvalue = MyDecimal().filter(CleanText('.')(cols[COL_UNITVALUE]).split()[0])
             if inv.unitvalue is not NotAvailable:
-                inv.vdate = Date(dayfirst=True).filter(Regexp(CleanText('.'), '(\d{2})/(\d{2})/(\d{4})', '\\3-\\2-\\1')(cols[COL_UNITVALUE]))
+                inv.vdate = Date(dayfirst=True, default=NotAvailable)\
+                   .filter(Regexp(CleanText('.'), '(\d{2})/(\d{2})/(\d{4})', '\\3-\\2-\\1', default=NotAvailable)(cols[COL_UNITVALUE])) or \
+                   Date(dayfirst=True, default=NotAvailable)\
+                   .filter(Regexp(CleanText('//tr[td[span[b[contains(text(), "Estimation du contrat")]]]]/td[2]'),
+                                  '(\d{2})/(\d{2})/(\d{4})', '\\3-\\2-\\1', default=NotAvailable)(cols[COL_UNITVALUE]))
             inv.valuation = MyDecimal('.')(cols[COL_VALUATION])
 
             yield inv
@@ -548,7 +578,7 @@ class ProTransactionsPage(TransactionsPage):
                     transactions[i] = {}
                 transactions[i][key] = value.strip()
 
-        return transactions.iteritems()
+        return sorted(transactions.items())
 
     def get_history(self, acc_type):
         for i, tr in self.parse_transactions():
