@@ -18,38 +18,38 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-try:
-    from urlparse import urlparse
-except ImportError:
-    from urllib.parse import urlparse
 
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
 from itertools import groupby
 
 from weboob.tools.compat import basestring
-from weboob.tools.capabilities.bank.transactions import FrenchTransaction
-from weboob.browser.browsers import LoginBrowser, need_login
+from weboob.tools.value import Value
+from weboob.tools.capabilities.bank.transactions import FrenchTransaction, sorted_transactions
+from weboob.browser.browsers import LoginBrowser, need_login, StatesMixin
 from weboob.browser.profiles import Wget
 from weboob.browser.url import URL
 from weboob.browser.pages import FormNotFound
 from weboob.exceptions import BrowserIncorrectPassword
-from weboob.capabilities.bank import Account
+from weboob.capabilities.bank import Account, AddRecipientStep, AddRecipientError, Recipient
+from weboob.capabilities import NotAvailable
+from weboob.tools.compat import urlparse
 
 from .pages import LoginPage, LoginErrorPage, AccountsPage, UserSpacePage, \
-                   OperationsPage, CardPage, ComingPage, NoOperationsPage, \
+                   OperationsPage, CardPage, ComingPage, RecipientsListPage, \
                    ChangePasswordPage, VerifCodePage, EmptyPage, PorPage, \
                    IbanPage, NewHomePage, AdvisorPage, RedirectPage, \
                    LIAccountsPage, CardsActivityPage, CardsListPage,       \
                    CardsOpePage, NewAccountsPage, InternalTransferPage, \
-                   ExternalTransferPage
+                   ExternalTransferPage, RevolvingLoanDetails, RevolvingLoansList
 
 
 __all__ = ['CreditMutuelBrowser']
 
 
-class CreditMutuelBrowser(LoginBrowser):
+class CreditMutuelBrowser(LoginBrowser, StatesMixin):
     PROFILE = Wget()
+    STATE_DURATION = 15
     TIMEOUT = 30
     BASEURL = 'https://www.creditmutuel.fr'
 
@@ -62,6 +62,8 @@ class CreditMutuelBrowser(LoginBrowser):
     accounts =    URL('/(?P<subbank>.*)fr/banque/situation_financiere.cgi',
                       '/(?P<subbank>.*)fr/banque/situation_financiere.html',
                       AccountsPage)
+    revolving_loan_list = URL(r'/(?P<subbank>.*)fr/banque/CR/arrivee.asp\?fam=CR.*', RevolvingLoansList)
+    revolving_loan_details = URL(r'/(?P<subbank>.*)fr/banque/CR/cam9_vis_lstcpt.asp.*', RevolvingLoanDetails)
     user_space =  URL('/(?P<subbank>.*)fr/banque/espace_personnel.aspx',
                       '/(?P<subbank>.*)fr/banque/accueil.cgi',
                       '/(?P<subbank>.*)fr/banque/DELG_Gestion',
@@ -74,9 +76,9 @@ class CreditMutuelBrowser(LoginBrowser):
     operations =  URL('/(?P<subbank>.*)fr/banque/mouvements.cgi.*',
                       '/(?P<subbank>.*)fr/banque/mouvements.html.*',
                       '/(?P<subbank>.*)fr/banque/nr/nr_devbooster.aspx.*',
+                      r'(?P<subbank>.*)fr/banque/CRP8_GESTPMONT.aspx\?webid=.*&trnref=.*&contract=\d+&cardid=.*&cardmonth=\d+',
                       OperationsPage)
     coming =      URL('/(?P<subbank>.*)fr/banque/mvts_instance.cgi.*',      ComingPage)
-    noop =        URL('/(?P<subbank>.*)fr/banque/CR/arrivee.asp.*',         NoOperationsPage)
     info =        URL('/(?P<subbank>.*)fr/banque/BAD.*',                    EmptyPage)
     change_pass = URL('/(?P<subbank>.*)fr/validation/change_password.cgi',
                       '/fr/services/change_password.html', ChangePasswordPage)
@@ -85,26 +87,28 @@ class CreditMutuelBrowser(LoginBrowser):
                       '/(?P<subbank>.*)banque/welcome_pack.html', NewHomePage)
     empty =       URL('/(?P<subbank>.*)fr/banques/index.html',
                       '/(?P<subbank>.*)fr/banque/paci_beware_of_phishing.*',
-                      '/(?P<subbank>.*)fr/validation/(?!change_password|verif_code).*',
+                      '/(?P<subbank>.*)fr/validation/(?!change_password|verif_code|image_case).*',
                       EmptyPage)
     por =         URL('/(?P<subbank>.*)fr/banque/POR_ValoToute.aspx',
                       '/(?P<subbank>.*)fr/banque/POR_SyntheseLst.aspx',
                       PorPage)
     li =          URL('/(?P<subbank>.*)fr/assurances/profilass.aspx\?domaine=epargne',
-                      '/(?P<subbank>.*)fr/assurances/(consultation/)?WI_ASSAVI', LIAccountsPage)
+                      '/(?P<subbank>.*)fr/assurances/(consultations?/)?WI_ASS.*',
+                      '/(?P<subbank>.*)fr/assurances/WI_ASS',
+                      '/fr/assurances/', LIAccountsPage)
     iban =        URL('/(?P<subbank>.*)fr/banque/rib.cgi', IbanPage)
 
     new_accounts = URL('/(?P<subbank>.*)fr/banque/comptes-et-contrats.html', NewAccountsPage)
     new_operations = URL('/(?P<subbank>.*)fr/banque/mouvements.cgi',
                          '/fr/banque/nr/nr_devbooster.aspx.*',
                          '/(?P<subbank>.*)fr/banque/RE/aiguille.asp',
-                         '/fr/banque/mouvements.html', OperationsPage)
-    new_por = URL('/(?P<subbank>.*)fr/banque/POR_ValoToute.aspx',
-                  '/(?P<subbank>.*)fr/banque/POR_SyntheseLst.aspx', PorPage)
-    new_iban = URL('/(?P<subbank>.*)fr/banque/rib.cgi', IbanPage)
+                         '/fr/banque/mouvements.html',
+                         '/(?P<subbank>.*)fr/banque/consultation/operations', OperationsPage)
 
     advisor = URL('/(?P<subbank>.*)fr/banques/contact/trouver-une-agence/(?P<page>.*)',
-                  '/(?P<subbank>.*)fr/infoclient/', AdvisorPage)
+                  '/(?P<subbank>.*)fr/infoclient/',
+                  r'/(?P<subbank>.*)fr/banques/accueil/menu-droite/Details.aspx\?banque=.*',
+                  AdvisorPage)
 
     redirect = URL('/(?P<subbank>.*)fr/banque/paci_engine/static_content_manager.aspx', RedirectPage)
 
@@ -115,11 +119,14 @@ class CreditMutuelBrowser(LoginBrowser):
 
     internal_transfer = URL('/(?P<subbank>.*)fr/banque/virements/vplw_vi.html', InternalTransferPage)
     external_transfer = URL('/(?P<subbank>.*)fr/banque/virements/vplw_vee.html', ExternalTransferPage)
+    recipients_list =   URL('/(?P<subbank>.*)fr/banque/virements/vplw_bl.html', RecipientsListPage)
 
     currentSubBank = None
     is_new_website = False
+    form = None
+    logged = None
 
-    __states__ = ['currentSubBank']
+    __states__ = ['currentSubBank', 'form', 'logged']
 
     accounts_list = None
 
@@ -160,12 +167,15 @@ class CreditMutuelBrowser(LoginBrowser):
             else:
                 for a in self.new_accounts.stay_or_go(subbank=self.currentSubBank).iter_accounts():
                     self.accounts_list.append(a)
-                self.new_iban.go(subbank=self.currentSubBank).fill_iban(self.accounts_list)
-                self.new_por.go(subbank=self.currentSubBank).add_por_accounts(self.accounts_list)
+                self.iban.go(subbank=self.currentSubBank).fill_iban(self.accounts_list)
+                self.por.go(subbank=self.currentSubBank).add_por_accounts(self.accounts_list)
 
             for acc in self.li.go(subbank=self.currentSubBank).iter_li_accounts():
                 self.accounts_list.append(acc)
 
+            for acc in self.revolving_loan_list.stay_or_go(subbank=self.currentSubBank).iter_accounts():
+                self.accounts_list.append(acc)
+
         return self.accounts_list
 
     def get_account(self, id):
@@ -232,13 +242,15 @@ class CreditMutuelBrowser(LoginBrowser):
             tr.date = tr.rdate = tr.vdate = group[0].date
             tr.type = FrenchTransaction.TYPE_CARD_SUMMARY
             tr._is_coming = False
+            tr._is_manualsum = True
             trs.append(tr)
         return trs
 
+    @need_login
     def get_history(self, account):
         transactions = []
         if not account._link_id:
-            return iter([])
+            raise NotImplementedError()
 
         # need to refresh the months select
         if account._link_id.startswith('ENC_liste_oper'):
@@ -254,7 +266,7 @@ class CreditMutuelBrowser(LoginBrowser):
                 transactions.append(tr)
 
         differed_date = None
-        cards = [page.select_card(account.id) for page in account._card_pages] if hasattr(account, '_card_pages') else \
+        cards = [page.select_card(account._card_number) for page in account._card_pages] if hasattr(account, '_card_pages') else \
                 account._card_links if hasattr(account, '_card_links') else []
         for card in cards:
             card_trs = []
@@ -272,18 +284,18 @@ class CreditMutuelBrowser(LoginBrowser):
         if differed_date is not None:
             # set deleted for card_summary
             for tr in transactions:
-                tr.deleted = tr.type == FrenchTransaction.TYPE_CARD_SUMMARY and differed_date.month <= tr.date.month
+                tr.deleted = tr.type == FrenchTransaction.TYPE_CARD_SUMMARY and \
+                             differed_date.month <= tr.date.month and \
+                             not hasattr(tr, '_is_manualsum')
 
-        transactions.sort(key=lambda tr: tr.rdate, reverse=True)
+        transactions = sorted_transactions(transactions)
         return transactions
 
+    @need_login
     def get_investment(self, account):
         if account._is_inv:
-            if account.type == Account.TYPE_MARKET:
-                if not self.is_new_website:
-                    self.por.go(subbank=self.currentSubBank)
-                else:
-                    self.new_por.go(subbank=self.currentSubBank)
+            if account.type in (Account.TYPE_MARKET, Account.TYPE_PEA):
+                self.por.go(subbank=self.currentSubBank)
                 self.page.send_form(account)
             elif account.type == Account.TYPE_LIFE_INSURANCE:
                 if not account._link_inv:
@@ -292,6 +304,7 @@ class CreditMutuelBrowser(LoginBrowser):
             return self.page.iter_investment()
         return iter([])
 
+    @need_login
     def iter_recipients(self, origin_account):
         # access the transfer page
         self.internal_transfer.go(subbank=self.currentSubBank)
@@ -311,6 +324,7 @@ class CreditMutuelBrowser(LoginBrowser):
                 for recipient in self.page.iter_recipients(origin_account=origin_account):
                     yield recipient
 
+    @need_login
     def init_transfer(self, account, to, amount, reason=None):
         if to.category != u'Interne':
             self.external_transfer.go(subbank=self.currentSubBank)
@@ -327,6 +341,7 @@ class CreditMutuelBrowser(LoginBrowser):
         self.page.prepare_transfer(account, to, amount, reason)
         return self.page.handle_response(account, to, amount, reason)
 
+    @need_login
     def execute_transfer(self, transfer, **params):
         form = self.page.get_form(id='P:F', submit='//input[@type="submit" and contains(@value, "Confirmer")]')
         # For the moment, don't ask the user if he confirms the duplicate.
@@ -344,6 +359,85 @@ class CreditMutuelBrowser(LoginBrowser):
                 self.location(self.page.get_advisor_link()).page.update_advisor(advisor)
         else:
             advisor = self.new_accounts.stay_or_go(subbank=self.currentSubBank).get_advisor()
-            if self.page.has_agency():
-                self.advisor.go(subbank=self.currentSubBank, page="contact.html").update_advisor(advisor)
+            link = self.page.get_agency()
+            if link:
+                link = link.replace(':443/', '/')
+                self.location(link)
+                self.page.update_advisor(advisor)
         return iter([advisor]) if advisor else iter([])
+
+    @need_login
+    def get_profile(self):
+        if not self.is_new_website:
+            profile = self.accounts.stay_or_go(subbank=self.currentSubBank).get_profile()
+        else:
+            profile = self.new_accounts.stay_or_go(subbank=self.currentSubBank).get_profile()
+        return profile
+
+    def get_recipient_object(self, recipient):
+        r = Recipient()
+        r.iban = recipient.iban
+        r.id = recipient.iban
+        r.label = recipient.label
+        r.category = recipient.category
+        # On credit mutuel recipients are immediatly available.
+        r.enabled_at = datetime.now().replace(microsecond=0)
+        r.currency = u'EUR'
+        r.bank_name = NotAvailable
+        return r
+
+    def continue_new_recipient(self, recipient, **params):
+        if u'Clé' in params:
+            self.page.post_code(params[u'Clé'])
+        self.page.add_recipient(recipient)
+        if self.page.bic_needed():
+            self.page.ask_bic(self.get_recipient_object(recipient))
+        self.page.ask_sms(self.get_recipient_object(recipient))
+
+    def send_sms(self, sms):
+        data = {}
+        for k, v in self.form.iteritems():
+            if k != 'url':
+                data[k] = v
+        data['otp_password'] = sms
+        data['_FID_DoConfirm.x'] = '1'
+        data['_FID_DoConfirm.y'] = '1'
+        data['global_backup_hidden_key'] = ''
+        self.location(self.form['url'], data=data)
+
+    def end_new_recipient(self, recipient, **params):
+        self.send_sms(params['code'])
+        self.form = None
+        self.page = None
+        self.logged = 0
+        return self.get_recipient_object(recipient)
+
+    def post_with_bic(self, recipient, **params):
+        data = {}
+        for k, v in self.form.iteritems():
+            if k != 'url':
+                data[k] = v
+        data['[t:dbt%3astring;x(11)]data_input_BIC'] = params[u'Bic']
+        self.location(self.form['url'], data=data)
+        self.page.ask_sms(self.get_recipient_object(recipient))
+
+    @need_login
+    def new_recipient(self, recipient, **params):
+        if self.currentSubBank is None:
+            self.getCurrentSubBank()
+        if 'Bic' in params:
+            return self.post_with_bic(recipient, **params)
+        if 'code' in params:
+            return self.end_new_recipient(recipient, **params)
+        if u'Clé' in params:
+            return self.continue_new_recipient(recipient, **params)
+        self.recipients_list.go(subbank=self.currentSubBank)
+        if self.page.has_list():
+            if recipient.category not in self.page.get_recipients_list():
+                raise AddRecipientError('Recipient category is not on the website available list.')
+            self.page.go_list(recipient.category)
+        self.page.go_to_add()
+        if self.verify_pass.is_here():
+            raise AddRecipientStep(self.get_recipient_object(recipient), Value(u'Clé', label=self.page.get_question()))
+        else:
+            return self.continue_new_recipient(recipient, **params)
