@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-from urllib import urlencode
+from __future__ import unicode_literals
+
 import re
 from time import sleep
 from datetime import date
@@ -25,9 +26,10 @@ from datetime import date
 from dateutil.relativedelta import relativedelta
 from lxml.html import etree
 
-from weboob.browser.filters.standard import CleanText, CleanDecimal
+from weboob.browser.filters.html import Link, Attr
+from weboob.browser.filters.standard import CleanText, CleanDecimal, RawText, Regexp, Date
 from weboob.capabilities import NotAvailable
-from weboob.capabilities.bank import Account, Investment
+from weboob.capabilities.bank import Account, Investment, Loan
 from weboob.browser.pages import HTMLPage, LoggedPage, FormNotFound
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 from weboob.tools.json import json
@@ -62,7 +64,12 @@ class PeaHistoryPage(LoggedPage, HTMLPage):
     COL_VALUATION = 5
     COL_PERF = 6
     COL_WEIGHT = 7
-    def get_investments(self):
+
+    def get_investments(self, account):
+        if account is not None:
+            # the balance is highly dynamic, fetch it along with the investments to grab a snapshot
+            account.balance = CleanDecimal(None, replace_dots=True).filter(self.get_balance(account.type))
+
         for line in self.doc.xpath('//table[@id="t_intraday"]/tbody/tr'):
             if line.find_class('categorie') or line.find_class('detail') or line.find_class('detail02'):
                 continue
@@ -72,7 +79,7 @@ class PeaHistoryPage(LoggedPage, HTMLPage):
             inv = Investment()
             inv.label = CleanText(None).filter(cols[self.COL_LABEL])
             link = cols[self.COL_LABEL].xpath('./a[contains(@href, "cdReferentiel")]')[0]
-            inv.id = unicode(re.search('cdReferentiel=(.*)', link.attrib['href']).group(1))
+            inv.id = re.search('cdReferentiel=(.*)', link.attrib['href']).group(1)
             inv.code = re.match('^[A-Z]+[0-9]+(.*)$', inv.id).group(1)
             inv.quantity = self.parse_decimal(cols[self.COL_QUANTITY], True)
             inv.unitprice = self.parse_decimal(cols[self.COL_UNITPRICE], True)
@@ -85,6 +92,12 @@ class PeaHistoryPage(LoggedPage, HTMLPage):
                 inv.diff = CleanDecimal(None, replace_dots=True).filter(diff)
 
             yield inv
+        if not account.type == account.TYPE_MARKET:
+            inv = Investment()
+            inv.code = "XX-liquidity"
+            inv.label = "Liquidités"
+            inv.valuation = CleanDecimal(None, True).filter(self.doc.xpath('//*[@id="valorisation_compte"]/table/tr[3]/td[2]'))
+            yield inv
 
     def parse_decimal(self, string, replace_dots):
         string = CleanText(None).filter(string)
@@ -93,10 +106,46 @@ class PeaHistoryPage(LoggedPage, HTMLPage):
         return CleanDecimal(None, replace_dots=replace_dots, default=NotAvailable).filter(string)
 
     def select_period(self):
+        try:
+            form = self.browser.page.get_form(name='form_historique_titres')
+        except FormNotFound:
+            return False
+        form['dateDebut'] = (date.today() - relativedelta(years=2)).strftime('%d/%m/%Y')
+        form['nbResultats'] = '100'
+        form.submit()
         return True
 
-    def get_operations(self, account):
-        return iter([])
+    def get_operations(self):
+        for tr in self.doc.xpath('//table[@id="tabHistoriqueOperations"]/tbody/tr'):
+            tds = tr.findall('td')
+            if len(CleanText(None).filter(tds[-1])) == 0:
+                continue
+            t = Transaction()
+            t.type = Transaction.TYPE_BANK
+            t.parse(date=CleanText(None).filter(tds[3]),
+                    raw=CleanText(None).filter(tds[1]))
+            t.amount = CleanDecimal(None, replace_dots=True, default=0).filter(tds[-2])
+            t.commission = CleanDecimal(None, replace_dots=True, default=0).filter(tds[-3])
+            investment = Investment()
+            investment.label = CleanText(None).filter(tds[0])
+            investment.quantity = CleanDecimal(None, replace_dots=True, default=0).filter(tds[4])
+            investment.unitvalue = CleanDecimal(None, replace_dots=True, default=0).filter(tds[5])
+            t.investments = [investment]
+            yield t
+
+    def get_balance(self, account_type):
+        raw_balance = None
+        for tr in self.doc.xpath('//div[@id="valorisation_compte"]//table/tr'):
+            if account_type == Account.TYPE_MARKET:
+                if u'Évaluation Titres' in CleanText('.')(tr):
+                    raw_balance = RawText('./td[2]')(tr)
+                    break
+            elif 'Valorisation totale' in CleanText('.')(tr):
+                raw_balance = RawText('./td[2]')(tr)
+        return raw_balance
+
+    def get_currency(self):
+        return Account.get_currency(CleanText('//div[@id="valorisation_compte"]//td[contains(text(), "Solde")]')(self.doc))
 
 
 class InvestmentHistoryPage(LoggedPage, HTMLPage):
@@ -110,12 +159,12 @@ class InvestmentHistoryPage(LoggedPage, HTMLPage):
     COL_PERF = 7
     COL_PERF_PERCENT = 8
 
-    def get_investments(self):
+    def get_investments(self, account):
         for line in self.doc.xpath('//table[@id="tableau_support"]/tbody/tr'):
             cols = line.findall('td')
 
             inv = Investment()
-            inv.id = unicode(re.search('cdReferentiel=(.*)', cols[self.COL_LABEL].find('a').attrib['href']).group(1))
+            inv.id = re.search('cdReferentiel=(.*)', cols[self.COL_LABEL].find('a').attrib['href']).group(1)
             inv.code = re.match('^[A-Z]+[0-9]+(.*)$', inv.id).group(1)
             inv.label = CleanText(None).filter(cols[self.COL_LABEL])
             inv.quantity = self.parse_decimal(cols[self.COL_QUANTITY])
@@ -133,42 +182,79 @@ class InvestmentHistoryPage(LoggedPage, HTMLPage):
         return CleanDecimal(None, replace_dots=True).filter(string)
 
     def select_period(self):
-        self.browser.location(self.url.replace('portefeuille-assurance-vie.jsp', 'operations/assurance-vie-operations.jsp'))
         assert isinstance(self.browser.page, type(self))
 
         try:
             form = self.browser.page.get_form(name='OperationsForm')
         except FormNotFound:
             return False
-        form['dateDebut'] = (date.today() - relativedelta(years=1)).strftime('%d/%m/%Y')
+
+        form['dateDebut'] = (date.today() - relativedelta(years=2)).strftime('%d/%m/%Y')
         form['nbrEltsParPage'] = '100'
         form.submit()
         return True
 
-    def get_operations(self, account):
-        for tr in self.doc.xpath('//table[@id="tableau_histo_opes"]/tbody/tr'):
-            tds = tr.findall('td')
+    def get_operations(self):
+        # skip on investments details
+        if self.doc.xpath('//table/thead/tr/th[contains(text(), "ISIN")]'):
+            return
 
+        for tr in self.doc.xpath('//table[@id="tableau_histo_opes"]/tbody/tr | //form[@name="DetailOperationForm"]//table/tbody/tr[not(@id)][td[3]]'):
+            tds = tr.findall('td')
+            if len(CleanText(None).filter(tds[-1])) == 0:
+                continue
             t = Transaction()
+            t.type = Transaction.TYPE_BANK
             t.parse(date=CleanText(None).filter(tds[1]),
                     raw=CleanText(None).filter(tds[2]))
             t.amount = CleanDecimal(None, replace_dots=True, default=0).filter(tds[-1])
+            # we check if transactions as sub transactions
+            details_link = Regexp(Attr('./a', 'onclick', default=''), r"afficherDetailOperation\('([^']+)", default='')(tds[0])
+            if details_link:
+                has_trs = False
+                for tr in self.browser.location(details_link).page.get_operations():
+                    has_trs = True
+                    yield tr
+                # skipping main transaction with sub transactions
+                if has_trs:
+                    continue
             yield t
 
+    def get_balance(self, account_type):
+        for div in self.doc.xpath('//div[@class="block synthese_vie"]/div/div/div'):
+            if 'Valorisation' in CleanText('.')(div):
+                return RawText('./p/strong')(div)
+
 
 class AccountHistoryPage(LoggedPage, HTMLPage):
-    def get_investments(self):
+    def build_doc(self, content):
+        content = re.sub(br'\*<E040032TC MSBILL.INFO', b'*', content)
+        return super(AccountHistoryPage, self).build_doc(content)
+
+    def get_balance(self):
+        for tr in self.doc.xpath('//table[@id="tableauConsultationHisto"]/tbody/tr'):
+            if 'Solde' in CleanText('./td')(tr):
+                return CleanText('./td/strong')(tr)
+
+    def get_investments(self, account):
         return iter([])
 
     def select_period(self):
-        form = self.get_form(name='ConsultationHistoriqueOperationsForm')
-        form['dateRechercheDebut'] = (date.today() - relativedelta(years=1)).strftime('%d/%m/%Y')
+        # form = self.get_form(name='ConsultationHistoriqueOperationsForm')
+        try:
+            form = self.get_form(xpath='//form[@name="ConsultationHistoriqueOperationsForm" '
+                                       ' or @name="form_historique_titres" '
+                                       ' or @name="OperationsForm"]')
+        except FormNotFound:
+            return False
+
+        form['dateRechercheDebut'] = (date.today() - relativedelta(years=2)).strftime('%d/%m/%Y')
         form['nbrEltsParPage'] = '100'
         form.submit()
 
         return True
 
-    def get_operations(self, account):
+    def get_operations(self):
         """history, see http://docs.weboob.org/api/capabilities/bank.html?highlight=transaction#weboob.capabilities.bank.Transaction"""
 
         # TODO need to rewrite that with FrenchTransaction class http://tinyurl.com/6lq4r9t
@@ -201,13 +287,13 @@ class AccountHistoryPage(LoggedPage, HTMLPage):
 
 
 class CardHistoryPage(LoggedPage, HTMLPage):
-    def get_investments(self):
+    def get_investments(self, account):
         return iter([])
 
     def select_period(self):
         return True
 
-    def get_operations(self, account):
+    def get_operations(self):
         cleaner = CleanText(None).filter
         for op in self.doc.xpath('//table[@id="tableauEncours"]/tbody/tr'):
             rdate =  cleaner(op.xpath('./td[1]')[0])
@@ -229,15 +315,14 @@ class CardHistoryPage(LoggedPage, HTMLPage):
 
 class AccountsList(LoggedPage, HTMLPage):
     def on_load(self):
-        warn = self.doc.xpath('//div[@id="message_renouvellement_mot_passe"] | \
+        warn = self.doc.xpath(u'//div[@id="message_renouvellement_mot_passe"] | \
                                //span[contains(text(), "Votre identifiant change")] | \
                                //span[contains(text(), "Nouveau mot de passe")] | \
-                               //span[contains(text(), "Renouvellement de votre mot de passe")]')
+                               //span[contains(text(), "Renouvellement de votre mot de passe")] |\
+                               //span[contains(text(), "Mieux vous connaître")]')
         if len(warn) > 0:
             raise ActionNeeded(warn[0].text)
 
-        self.load_async(0)
-
     def load_async(self, time):
         total = 0
         restart = True
@@ -253,7 +338,7 @@ class AccountsList(LoggedPage, HTMLPage):
                     params['div%s' % i] = input.attrib['value']
                 params['time'] = time
 
-                r = self.browser.open('/AsynchAjax?%s' % urlencode(params))
+                r = self.browser.open('/AsynchAjax', params=params)
                 data = json.loads(r.content)
 
                 for i, d in enumerate(data['data']):
@@ -281,48 +366,90 @@ class AccountsList(LoggedPage, HTMLPage):
         return len(self.doc.xpath('//div[@id="aidesecuforte"]'))
 
     ACCOUNT_TYPES = {'mes-comptes/compte-courant/consulter-situation': Account.TYPE_CHECKING,
+                     'mes-comptes/compte-especes':                     Account.TYPE_CHECKING,
                      'mes-comptes/compte-courant/carte-bancaire':      Account.TYPE_CARD,
                      'mes-comptes/assurance-vie':                      Account.TYPE_LIFE_INSURANCE,
                      'mes-comptes/livret':                             Account.TYPE_SAVINGS,
-                     'mes-comptes/pea':                                Account.TYPE_MARKET,
-                     'mes-comptes/compte-titres':                      Account.TYPE_MARKET,
+                     'mes-comptes/pea':                                Account.TYPE_PEA,
+                     'mes-comptes/ppe':                                Account.TYPE_PEA,
+                     'mes-comptes/compte-titres-pea':                  Account.TYPE_MARKET
                     }
+
     def get_list(self):
         accounts = []
-        account = None
 
-        for cpt in self.doc.xpath('//a[@class="synthese_id_compte" or @class="synthese_carte_differe"]'):
-            url_to_parse = cpt.xpath('@href')[0].replace("\n", "")  # link
-            # account._link_id = lien vers historique d'un compte (courant ou livret)
-            if '/mes-comptes/livret/' in url_to_parse:
-                compte_id_re = re.compile(r'.*\?(.*)$')
-                link_id = '/fr/prive/mes-comptes/livret/consulter-situation/consulter-solde.jsp?%s' % \
-                    (compte_id_re.search(url_to_parse).groups()[0])
-            else:
-                link_id = url_to_parse
+        for cpt in self.doc.xpath('//div[contains(@class, " compte") and not(contains(@class, "compte_selected"))]'):
 
-            number = cpt.xpath('./span[@class="synthese_numero_compte"]')
-            if len(number) == 0:
-                account._card_links.append(link_id)
+            # ignore auto assurance accounts
+            if 'aut' in cpt.get('class'):
                 continue
 
             account = Account()
-            account.id = CleanText(None).filter(number[0]).replace(u'N°', '')
+            account._history_link = Link('./ul/li/a[contains(@id, "consulter_solde") '
+                                         'or contains(@id, "historique") '
+                                         'or contains(@id, "contrat") '
+                                         'or contains(@id, "assurance_vie_operations")]')(cpt)
 
-            try:
-                balance = CleanText(None).filter(cpt.xpath('./span[contains(@class, "synthese_solde")]')[0])
-            except IndexError:
-                continue
+            # this is to test if access to the accounts info is blocked for different reasons
+            page = self.browser.open(account._history_link).page
+            if isinstance(page, LoanPage):
+                account = Loan()
+
+            account._history_link = Link('./ul/li/a[contains(@id, "consulter_solde") '
+                                         'or contains(@id, "historique") '
+                                         'or contains(@id, "contrat") '
+                                         'or contains(@id, "assurance_vie_operations")]')(cpt)
+            if isinstance(page, LoanPage):
+                account.id = CleanText('(//p[@id="c_montantEmprunte"]//span[@class="valStatic"]//strong)[1]')(cpt)
+                account.label = CleanText('(//p[@id="c_montantEmprunte"]//span[@class="valStatic"]//strong)[1]')(cpt)
+                account.type = Account.TYPE_LOAN
+                account.total_amount = self.browser.open(account._history_link).page.get_total_amount()
+                account.next_payment_amount = self.browser.open(account._history_link).page.get_next_payment_amount()
+                account.account_label = self.browser.open(account._history_link).page.get_account_label()
+                account.subscription_date = self.browser.open(account._history_link).page.get_subscription_date()
+                account.maturity_date = self.browser.open(account._history_link).page.get_maturity_date()
+
+            if len(accounts) == 0:
+                global_error_message = page.doc.xpath('//div[@id="as_renouvellementMIFID.do_"]/div[contains(text(), "Bonjour")] '
+                                                      '| //div[@id="as_afficherMessageBloquantMigration.do_"]//div[@class="content_message"] '
+                                                      '| //p[contains(text(), "Et si vous faisiez de Fortuneo votre banque principale")] '
+                                                      '| //div[@id="as_renouvellementMotDePasse.do_"]//p[contains(text(), "votre mot de passe")]'
+                                                      '| //div[@id="as_afficherSecuriteForteOTPIdentification.do_"]//span[contains(text(), "Pour valider ")]')
+                if global_error_message:
+                    raise ActionNeeded(CleanText('.')(global_error_message[0]))
+            local_error_message = page.doc.xpath('//div[@id="error"]/p[@class="erreur_texte1"]')
+            if local_error_message:
+                raise BrowserUnavailable(CleanText('.')(local_error_message[0]))
+
+            number = RawText('./a[contains(@class, "numero_compte")]')(cpt).replace(u'N° ', '')
+
+            account.id = CleanText(None).filter(number).replace(u'N°', '')
 
-            account.balance = CleanDecimal(None, replace_dots=True).filter(balance)
-            account.currency = account.get_currency(balance)
-            account._link_id = link_id
             account._card_links = []
-            account.label = (' '.join([CleanText.clean(part) for part in cpt.xpath('./text()')])).strip(' - ').strip()
+            card_link = Link('./ul/li/a[contains(text(), "Carte bancaire")]', default='')(cpt)
+            if len(card_link) > 0:
+                account._card_links.append(card_link)
 
-            for pattern, type in self.ACCOUNT_TYPES.iteritems():
-                if pattern in account._link_id:
+            account.label = CleanText('./a[contains(@class, "numero_compte")]/@title')(cpt)
+
+            for pattern, type in self.ACCOUNT_TYPES.items():
+                if pattern in account._history_link:
                     account.type = type
+                    break
+
+            if account.type in {Account.TYPE_PEA, Account.TYPE_MARKET, Account.TYPE_LIFE_INSURANCE}:
+                account._investment_link = Link('./ul/li/a[contains(@id, "portefeuille")]')(cpt)
+                balance = self.browser.open(account._investment_link).page.get_balance(account.type)
+                if account.type in {Account.TYPE_PEA, Account.TYPE_MARKET}:
+                    self.browser.investments[account.id] = list(self.browser.open(account._investment_link).page.get_investments(account))
+            else:
+                balance = self.browser.open(account._history_link).page.get_balance()
+
+            if account.type in {Account.TYPE_PEA, Account.TYPE_MARKET}:
+                account.currency = self.browser.open(account._investment_link).page.get_currency()
+            else:
+                account.currency = account.get_currency(balance)
+            account.balance = CleanDecimal(None, replace_dots=True).filter(balance)
 
             if account.type in (Account.TYPE_CHECKING, Account.TYPE_SAVINGS):
                 # Need a token sent by SMS to customers
@@ -330,9 +457,28 @@ class AccountsList(LoggedPage, HTMLPage):
 
             if (account.label, account.id, account.balance) not in [(a.label, a.id, a.balance) for a in accounts]:
                 accounts.append(account)
-
-        return iter(accounts)
+        return accounts
 
 
 class GlobalAccountsList(LoggedPage, HTMLPage):
     pass
+
+
+class LoanPage(LoggedPage, HTMLPage):
+    def get_balance(self):
+        return CleanText(u'//p[@id="c_montantRestant"]//strong')(self.doc)
+
+    def get_total_amount(self):
+        return CleanDecimal(u'(//p[@id="c_montantEmprunte"]//strong)[2]', replace_dots=True)(self.doc)
+
+    def get_next_payment_amount(self):
+        return CleanDecimal(Regexp(CleanText(u'//p[@id="c_prochaineEcheance"]//strong'), u'(.*) le'), replace_dots=True)(self.doc)
+
+    def get_account_label(self):
+        return CleanText(u'//p[@id="c_comptePrelevementl"]//strong')(self.doc)
+
+    def get_subscription_date(self):
+        return Date(CleanText(u'//p[@id="c_dateDebut"]//strong'), dayfirst=True)(self.doc)
+
+    def get_maturity_date(self):
+        return Date(CleanText(u'//p[@id="c_dateFin"]//strong'), dayfirst=True)(self.doc)
