@@ -18,8 +18,6 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
-#from logging import error
-
 from weboob.browser.pages import HTMLPage
 from weboob.browser.filters.standard import CleanText
 from weboob.exceptions import BrowserUnavailable
@@ -33,9 +31,14 @@ class LoginPage(HTMLPage):
             raise BrowserUnavailable(msg)
 
         form = self.get_form(name="acces_identification")
-        form['login'] = login.encode('utf-8')
-        form['passwd'] = passwd.encode('utf-8')
+        form['login'] = login
+        form['passwd'] = passwd
         form.submit()
 
 
+class UnavailablePage(HTMLPage):
+    def on_load(self):
+        raise BrowserUnavailable(CleanText('//h2[@class="titre"]')(self.doc))
+
+
 # vim:ts=4:sw=4
