@@ -67,7 +67,8 @@ class FacebookBrowser(DomainBrowser):
         self.info = self.request('/me')
 
     def request(self, url, *args, **kwargs):
-        url += '?access_token=' + self.access_token
+        url += '&' if ('?' in url) else '?'
+        url += 'access_token=' + self.access_token
         r = self.location(self.absurl(url, base=True), *args, **kwargs)
         return json.loads(r.content)
 
@@ -97,6 +98,21 @@ class HappnBrowser(DomainBrowser):
         self.my_id = r['user_id']
         self.refresh_token = r['refresh_token']
 
+        self.request('/api/auth/proof', data={'facebook_access_token': facebook.access_token})
+
+        r = self.request('/api/users/%s/devices/' % self.my_id,
+                     data={"adid": "78462200ada313bb943b01800819a1d5",
+                           "android_id": "fe26ca3be49bbbf6",
+                           "app_build": "20.14.0",
+                           "country_id": "FR",
+                           "idfa": "2265540e-7a5f-4308-9c69-3afd2f608a2e",
+                           "language_id": "fr",
+                           "os_build": 23,
+                           "token": "",
+                           "type": "android"
+                          })
+        self.device_id = r['data']['id']
+
         me = self.request('/api/users/me')
         self.my_name = me['data']['name']
 
@@ -104,8 +120,21 @@ class HappnBrowser(DomainBrowser):
         r = self.location(*args, **kwargs)
         return r.json()
 
+    def get_facebook(self, facebook_id):
+        data = self.facebook.request('https://graph.facebook.com/%s' % facebook_id)
+        if not 'link' in data:
+            data['link'] = ('https://www.facebook.com/%s' % data['username']) if 'username' in data else ''
+        likes = self.facebook.request('https://graph.facebook.com/%s/likes?limit=10000' % facebook_id)
+        data['likes'] = [like['name'] for like in likes['data']]
+        data['infos'] = self.facebook.request('https://graph.facebook.com/v2.3/%s?fields=about,address,age_range,bio,birthday,devices,education,email,favorite_athletes,favorite_teams,hometown,inspirational_people,install_type,interested_in,is_verified,languages,location,meeting_for,political,relationship_status,religion,significant_other,sports,quotes,timezone,updated_time,verified,website,work' % facebook_id)
+
+        return data
+
     def get_contact(self, contact_id):
-        return self.request('/api/users/%s?fields=birth_date,first_name,last_name,display_name,login,credits,referal,matching_preferences,notification_settings,unread_conversations,about,is_accepted,age,job,workplace,school,modification_date,profiles.mode(0).width(1000).height(1000).fields(url,width,height,mode),last_meet_position,my_relation,is_charmed,distance,gender' % contact_id)['data']
+        data = self.request('/api/users/%s?fields=birth_date,first_name,fb_id,last_name,display_name,login,credits,referal,matching_preferences,notification_settings,unread_conversations,about,is_accepted,age,job,workplace,school,modification_date,profiles.mode(0).width(1000).height(1000).fields(url,width,height,mode),last_meet_position,my_relation,is_charmed,distance,gender' % contact_id)['data']
+        if data['fb_id'] is not None:
+            data['fb'] = self.get_facebook(data['fb_id'])
+        return data
 
     def get_threads(self):
         return self.request('/api/users/me/conversations')['data']
@@ -124,4 +153,7 @@ class HappnBrowser(DomainBrowser):
         self.request('/api/users/me/accepted/%s' % id, method='POST')
 
     def set_position(self, lat, lng):
-        self.request('/api/users/me/position', data={'latitude': lat, 'longitude': lng, 'altitude': 0.0})
+        r = self.request('/api/users/%s/devices/%s' % (self.my_id, self.device_id), method='PUT',
+                         data={'latitude': lat, 'longitude': lng, 'altitude': 0.0})
+
+        return r['data']['position']
