@@ -17,12 +17,15 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-
+from collections import OrderedDict
 import datetime
+from random import randint, random
+
 from dateutil.parser import parse as parse_date
 from dateutil.relativedelta import relativedelta
 from dateutil.tz import tzlocal
-from random import randint
+import geopy
+import geopy.distance
 
 from weboob.capabilities.base import NotAvailable
 from weboob.capabilities.messages import CapMessages, CapMessagesPost, Thread, Message
@@ -31,7 +34,6 @@ from weboob.capabilities.contact import CapContact, Contact, ProfileNode
 from weboob.exceptions import BrowserHTTPError
 from weboob.tools.backend import Module, BackendConfig
 from weboob.tools.value import Value, ValueBackendPassword
-from weboob.tools.ordereddict import OrderedDict
 from weboob.tools.log import getLogger
 
 from .browser import HappnBrowser, FacebookBrowser
@@ -41,7 +43,7 @@ __all__ = ['HappnModule']
 
 
 class ProfilesWalker(Optimization):
-    def __init__(self, sched, storage, browser):
+    def __init__(self, sched, storage, browser, location, distance):
         super(ProfilesWalker, self).__init__()
         self._sched = sched
         self._storage = storage
@@ -51,6 +53,9 @@ class ProfilesWalker(Optimization):
 
         self._view_cron = None
 
+        self._location = geopy.Point(map(float, location.split(',')))
+        self._max_distance = int(distance)
+
     def start(self):
         self._view_cron = self._sched.schedule(1, self.view_profile)
         return True
@@ -66,8 +71,6 @@ class ProfilesWalker(Optimization):
     def is_running(self):
         return self._view_cron is not None
 
-    INTERVALS = [(48896403, 2303976),
-                 (48820992, 2414698)]
     def view_profile(self):
         try:
             n = 0
@@ -76,27 +79,28 @@ class ProfilesWalker(Optimization):
                     continue
 
                 self._browser.accept(user['notifier']['id'])
-                self._logger.info('Liked %s %s (%s at %s): https://www.facebook.com/profile.php?id=%s&fref=ufi&pnref=story',
-                                  user['notifier']['first_name'],
-                                  user['notifier']['last_name'],
+                fb = self._browser.get_facebook(user['notifier']['fb_id'])
+                self._logger.info('Liked %s (%s at %s): %s',
+                                  fb['name'],
                                   user['notifier']['job'],
                                   user['notifier']['workplace'],
-                                  user['notifier']['fb_id'])
+                                  fb['link'])
                 n += 1
                 if n > 10:
                     break
 
             if n == 0 and (self._last_position_update is None or self._last_position_update + datetime.timedelta(minutes=20) < datetime.datetime.now()):
                 self._logger.info('No more new profiles, updating position...')
-                lat = randint(self.INTERVALS[1][0], self.INTERVALS[0][0])/1000000.0
-                lng = randint(self.INTERVALS[0][1], self.INTERVALS[1][1])/1000000.0
+
+                d = geopy.distance.VincentyDistance(kilometers=random()*self._max_distance)
+                pos = d.destination(point=self._location, bearing=randint(0,360))
                 try:
-                    self._browser.set_position(lat, lng)
+                    pos = self._browser.set_position(pos.latitude, pos.longitude)
                 except BrowserHTTPError:
                     self._logger.warning('Unable to update position for now, it will be retried later.')
                     self._logger.warning('NB: don\'t be afraid, happn only allows to update position every 20 minutes.')
                 else:
-                    self._logger.info('You are now here: https://www.google.com/maps/place//@%s,%s,17z', lat, lng)
+                    self._logger.info('You are now here: https://www.google.com/maps/place//@%s,%s,17z', pos['latitude'], pos['longitude'])
                     self._last_position_update = datetime.datetime.now()
 
             for thread in self._browser.get_threads():
@@ -144,9 +148,15 @@ class HappnContact(Contact):
         self.profile = OrderedDict()
 
         self.set_profile('info', 'id', info['id'])
-        self.set_profile('info', 'full_name', ' '.join([info['first_name'] or '', info['last_name'] or '']).strip())
-        if info['fb_id'] is not None:
-            self.set_profile('info', 'facebook', 'https://www.facebook.com/profile.php?id=%s&fref=ufi&pnref=story' % info['fb_id'])
+        try:
+            self.set_profile('info', 'full_name', info['fb']['name'])
+        except KeyError:
+            self.set_profile('info', 'full_name', ' '.join([info['first_name'] or '', info['last_name'] or '']).strip())
+        if 'fb' in info:
+            self.set_profile('info', 'facebook', info['fb']['link'])
+            self.set_profile('facebook', 'likes', 'interests', ', '.join(info['fb']['likes']))
+            for name, content in info['fb']['infos'].iteritems():
+                self.set_profile('facebook', 'infos', name, content)
         if info['twitter_id'] is not None:
             self.set_profile('info', 'twitter', info['twitter_id'])
         self.set_profile('stats', 'accepted', info['is_accepted'])
@@ -179,9 +189,11 @@ class HappnModule(Module, CapMessages, CapMessagesPost, CapDating, CapContact):
     MAINTAINER = u'Roger Philibert'
     EMAIL = 'roger.philibert@gmail.com'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.2'
+    VERSION = '1.3'
     CONFIG = BackendConfig(Value('username',                label='Facebook email'),
-                           ValueBackendPassword('password', label='Facebook password'))
+                           ValueBackendPassword('password', label='Facebook password'),
+                           Value('location',                label='Location (example: 49.6008457,6.129709)'),
+                           Value('distance',                label='Distance (in km) around your location you\'re walking'))
 
     BROWSER = HappnBrowser
     STORAGE = {'contacts': {},
@@ -196,7 +208,9 @@ class HappnModule(Module, CapMessages, CapMessagesPost, CapDating, CapContact):
     # ---- CapDating methods -----------------------
 
     def init_optimizations(self):
-        self.add_optimization('PROFILE_WALKER', ProfilesWalker(self.weboob.scheduler, self.storage, self.browser))
+        self.add_optimization('PROFILE_WALKER', ProfilesWalker(self.weboob.scheduler, self.storage, self.browser,
+                                                               self.config['location'].get(),
+                                                               self.config['distance'].get()))
 
     # ---- CapMessages methods ---------------------
 
@@ -220,6 +234,8 @@ class HappnModule(Module, CapMessages, CapMessagesPost, CapDating, CapContact):
 
         info = self.browser.get_thread(thread.id)
         for user in info['participants']:
+            if user['user']['fb_id'] is not None:
+                user['user']['fb'] = self.browser.get_facebook(user['user']['fb_id'])
             if user['user']['id'] == self.browser.my_id:
                 me = HappnContact(user['user'])
             else:
