@@ -25,6 +25,7 @@ from weboob.browser.elements import ListElement, ItemElement, TableElement, meth
 from weboob.browser.filters.standard import CleanText, Date, CleanDecimal, Env, TableCell
 from weboob.browser.filters.html import Link
 from weboob.capabilities.bank import Account
+from weboob.capabilities.profile import Profile
 from weboob.capabilities.base import NotAvailable
 from weboob.exceptions import BrowserPasswordExpired
 
@@ -60,25 +61,39 @@ class MovementsPage(LoggedPage, HTMLPage):
     @method
     class iter_accounts(ListElement):
         def parse(self, el):
-            multi_xpath = '//form[contains(@action, "changeCompte")]//ul[@class="listeEnfants"]/li/a'
-            self.page.multi = True if self.page.doc.xpath(multi_xpath) else False
-            self.item_xpath = multi_xpath if self.page.multi else '//*[@id="perimetreMandatEnfantLib"]'
+            # multi accounts separated in multiple companies
+            self.item_xpath = '//form[contains(@action, "changeCompte")]//ul[@class="listeEnfants"]/li/a'
+            self.env['multi'] = bool(self.page.doc.xpath(self.item_xpath))
+            if self.env['multi']:
+                return
+
+            # simple multi accounts
+            self.item_xpath = '//form[contains(@action, "changeCompte")]//ul[@class="layerEnfants"]/li/a'
+            self.env['multi'] = bool(self.page.doc.xpath(self.item_xpath))
+            if self.env['multi']:
+                return
+
+            # single account
+            self.item_xpath = '//*[@id="perimetreMandatEnfantLib"]'
 
         class item(ItemElement):
             klass = Account
 
-            obj_id = Env('accid')
-            obj_label = Env('label')
+            def obj_id(self):
+                return CleanText('.')(self).strip().replace(' ', '').split('-')[0]
+
+            def obj_label(self):
+                return CleanText('.')(self).split("-")[-1].strip()
+
             obj_type = Account.TYPE_CHECKING
+
             obj_balance = Env('balance')
             obj_currency = Env('currency')
             obj__url = Env('url')
             obj__data = Env('data')
 
             def parse(self, el):
-                page, url, data = self.page.get_changecompte(Link('.')(self)) if self.page.multi else (self.page, None, None)
-                self.env['accid'] = CleanText('.')(self).strip().replace(' ', '').split('-')[0]
-                self.env['label'] = CleanText('.')(self).split("-")[-1].strip()
+                page, url, data = self.page.get_changecompte(Link('.')(self)) if self.env['multi'] else (self.page, None, None)
                 balance_xpath = '//div[contains(text(),"Solde")]/strong'
                 self.env['balance'] = MyDecimal().filter(page.doc.xpath(balance_xpath))
                 self.env['currency'] = Account.get_currency(CleanText().filter(page.doc.xpath(balance_xpath)))
@@ -115,6 +130,16 @@ class MovementsPage(LoggedPage, HTMLPage):
                 return credit if credit else -debit
 
 
+class ProfilePage(LoggedPage, HTMLPage):
+    @method
+    class get_profile(ItemElement):
+        klass = Profile
+
+        obj_name = CleanText('//div[@class="headerInfos"][not(@id)]/span')
+        obj_phone = CleanText('//div[label[@id="tel_fix_label"]]/following-sibling::div[1]')
+        obj_email = CleanText('//div[label[@id="email_label"]]/following-sibling::div[1]')
+
+
 class PassExpiredPage(HTMLPage):
     def on_load(self):
         raise BrowserPasswordExpired("Renouvellement de mot de passe requis.")
