@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2011  Romain Bignon, Pierre Mazière
 #
 # This file is part of weboob.
@@ -17,35 +16,47 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
-import re, requests, base64, math, random
+from __future__ import unicode_literals, division
+
+import re
+import requests
+import base64
+import math
+import random
 from decimal import Decimal
-from cStringIO import StringIO
-from urllib import urlencode
+from io import BytesIO
 from datetime import datetime, timedelta, date
 
 from weboob.capabilities import NotAvailable
-from weboob.capabilities.base import find_object
-from weboob.capabilities.bank import Account, Investment, Recipient, TransferError, Transfer
+from weboob.capabilities.base import find_object, Currency
+from weboob.capabilities.bank import Account, Investment, Recipient, TransferError, TransferBankError, Transfer, AddRecipientError
+from weboob.capabilities.bill import Document, Subscription
 from weboob.capabilities.contact import Advisor
 from weboob.browser.elements import method, ListElement, TableElement, ItemElement, SkipItem
 from weboob.exceptions import ParseError
+from weboob.browser.exceptions import ServerError
 from weboob.browser.pages import LoggedPage, HTMLPage, FormNotFound, pagination
 from weboob.browser.filters.html import Attr, Link
 from weboob.browser.filters.standard import CleanText, Field, Regexp, Format, Date, \
                                             CleanDecimal, Map, AsyncLoad, Async, Env, \
-                                            TableCell, Eval
+                                            TableCell, Eval, Slugify
 from weboob.exceptions import BrowserUnavailable, BrowserIncorrectPassword
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
 from weboob.tools.captcha.virtkeyboard import MappedVirtKeyboard, VirtKeyboardError
+from weboob.tools.compat import unicode
+from weboob.tools.compat import urlparse, parse_qs
+from weboob.tools.html import html2text
+from weboob.tools.date import parse_french_date
 
 
 def MyDecimal(*args, **kwargs):
     kwargs.update(replace_dots=True, default=Decimal(0))
     return CleanDecimal(*args, **kwargs)
 
+
 def myXOR(value,seed):
     s = ''
-    for i in xrange(len(value)):
+    for i in range(len(value)):
         s += chr(seed^ord(value[i]))
     return s
 
@@ -103,8 +114,8 @@ class LCLVirtKeyboard(MappedVirtKeyboard):
     def __init__(self, basepage):
         img=basepage.doc.find("//img[@id='idImageClavier']")
         random.seed()
-        self.url += "%s"%str(long(math.floor(long(random.random()*1000000000000000000000))))
-        super(LCLVirtKeyboard, self).__init__(StringIO(basepage.browser.open(self.url).content), basepage.doc,img,self.color, "id")
+        self.url += "%s"%str(int(math.floor(int(random.random()*1000000000000000000000))))
+        super(LCLVirtKeyboard, self).__init__(BytesIO(basepage.browser.open(self.url).content), basepage.doc,img,self.color, "id")
         self.check_symbols(self.symbols,basepage.browser.responses_dirname)
 
     def get_symbol_code(self, md5sum):
@@ -150,7 +161,9 @@ class LoginPage(HTMLPage):
 
         form = self.get_form('//form[@id="formAuthenticate"]')
         form['identifiant'] = login
-        form['postClavierXor'] = base64.b64encode(myXOR(password,seed))
+        form['postClavierXor'] = base64.b64encode(
+            myXOR(password, seed).encode("utf-8")
+        )
         try:
             form['identifiantRouting'] = self.browser.IDENTIFIANT_ROUTING
         except AttributeError:
@@ -174,17 +187,28 @@ class ContractsPage(LoginPage):
             raise BrowserIncorrectPassword()
         self.select_contract()
 
-    def select_contract(self):
-        # XXX We select automatically the default contract in list. We should let user
-        # ask what contract he wants to see, or display accounts for all contracts.
+    def select_contract(self, id_contract=None):
         link = self.doc.xpath('//a[contains(text(), "Votre situation globale")]')
-        if len(link):
+        if not id_contract and len(link):
             self.browser.location(link[0].attrib['href'])
         else:
             form = self.get_form(nr=0)
+            if 'contratId' in form:
+                if id_contract:
+                    form['contratId'] = id_contract
+                self.browser.current_contract = form['contratId']
             form.submit()
 
 
+class ContractsChoicePage(ContractsPage):
+    def on_load(self):
+        if self.is_error():
+            raise BrowserIncorrectPassword()
+        self.browser.contracts = [unicode(x) for x in self.doc.xpath('//input[@name="contratId"]/@value')]
+        if not self.logged and not self.browser.current_contract:
+            self.select_contract()
+
+
 class AccountsPage(LoggedPage, HTMLPage):
     def on_load(self):
         warn = self.doc.xpath('//div[@id="attTxt"]')
@@ -221,7 +245,7 @@ class AccountsPage(LoggedPage, HTMLPage):
                            '046': Account.TYPE_SAVINGS,
                            '047': Account.TYPE_SAVINGS,
                            '049': Account.TYPE_SAVINGS,
-                           '068': Account.TYPE_MARKET,
+                           '068': Account.TYPE_PEA,
                            '069': Account.TYPE_SAVINGS,
                           }
 
@@ -259,7 +283,7 @@ class AccountsPage(LoggedPage, HTMLPage):
 
         obj_name = CleanText('//div[@id="contacterMaBqMenu"]//p[@id="itemNomContactMaBq"]/span')
         obj_email = obj_mobile = obj_fax = NotAvailable
-        obj_phone = Regexp(CleanText('//div[@id="sousContentAgence"]//p[contains(text(), "Tel")]', replace=[(' ', '')]), '([\s\d]+)')
+        obj_phone = Regexp(CleanText('//div[@id="contacterMaBqMenu"]//p[contains(text(), "Tel")]', replace=[(' ', '')]), '([\s\d]+)', default=NotAvailable)
         obj_agency = CleanText('//div[@id="sousContentAgence"]//p[@class="itemSousTitreMenuMaBq"][1]')
 
         def obj_address(self):
@@ -293,7 +317,39 @@ class LoansPage(LoggedPage, HTMLPage):
 
             def parse(self, el):
                 label = Field('label')(self)
-                trs = self.xpath('//td[contains(text(), "%s")]/ancestor::tr[1] | ./ancestor::table[1]/tbody/tr' % label)
+                trs = self.xpath('//td[contains(text(), $label)]/ancestor::tr[1] | ./ancestor::table[1]/tbody/tr', label=label)
+                i = [i for i in range(len(trs)) if el == trs[i]]
+                i = i[0] if i else 0
+                label = label.replace(' ', '')
+                self.env['id'] = "%s%s%s" % (Regexp(CleanText(TableCell('id')), r'(\w+)\s-\s(\w+)', r'\1\2')(self), label.replace(' ', ''), i)
+
+
+class LoansProPage(LoggedPage, HTMLPage):
+    @method
+    class get_list(TableElement):
+        item_xpath = '//table[.//th[contains(text(), "Emprunteur")]]/tbody/tr[td[3]]'
+        head_xpath = '//table[.//th[contains(text(), "Emprunteur")]]/thead/tr/th'
+        flush_at_end = True
+
+        col_id = re.compile('Emprunteur')
+        col_balance = [u'Capital restant dû', re.compile('Sommes totales restant dues')]
+
+        class account(ItemElement):
+            klass = Account
+
+            obj_balance = CleanDecimal(TableCell('balance'), replace_dots=True, sign=lambda x: -1)
+            obj_currency = FrenchTransaction.Currency(TableCell('balance'))
+            obj_type = Account.TYPE_LOAN
+            obj_id = Env('id')
+            obj__transfer_id = None
+
+            def obj_label(self):
+                has_type = CleanText('./ancestor::table[.//th[contains(text(), "Nature libell")]]', default=None)(self)
+                return CleanText('./td[3]')(self) if has_type else CleanText('./ancestor::table/preceding-sibling::div[1]')(self).split(' - ')[0]
+
+            def parse(self, el):
+                label = Field('label')(self)
+                trs = self.xpath('//td[contains(text(), $label)]/ancestor::tr[1] | ./ancestor::table[1]/tbody/tr', label=label)
                 i = [i for i in range(len(trs)) if el == trs[i]]
                 i = i[0] if i else 0
                 label = label.replace(' ', '')
@@ -384,13 +440,17 @@ class AccountHistoryPage(LoggedPage, HTMLPage):
                     else:
                         obj.label = '%s %s' % (obj.raw, raw)
                         obj.raw = '%s %s' % (obj.raw, raw)
+                elif not obj.raw:
+                    # Empty transaction label
+                    obj.raw = obj.label = Async('details', CleanText(u'//td[contains(text(), "Nature de l\'opération")]/following-sibling::*[1]'))(self)
                 if not obj.date:
                     obj.date = Async('details', Date(CleanText(u'//td[contains(text(), "Date de l\'opération")]/following-sibling::*[1]', default=u''), default=NotAvailable))(self)
                     obj.rdate = obj.date
                     obj.vdate = Async('details', Date(CleanText(u'//td[contains(text(), "Date de valeur")]/following-sibling::*[1]', default=u''), default=NotAvailable))(self)
                     obj.amount = Async('details', CleanDecimal(u'//td[contains(text(), "Montant")]/following-sibling::*[1]', replace_dots=True, default=NotAvailable))(self)
                 # ugly hack to fix broken html
-                if not obj.amount:
+                # sometimes transactions have really an amount of 0...
+                if not obj.amount and CleanDecimal(TableCell('credit'), default=None)(self) is None:
                     obj.amount = Async('details', CleanDecimal(u'//td[contains(text(), "Montant")]/following-sibling::*[1]', replace_dots=True, default=NotAvailable))(self)
                 return True
 
@@ -402,7 +462,10 @@ class AccountHistoryPage(LoggedPage, HTMLPage):
 class CBHistoryPage(AccountHistoryPage):
     def get_operations(self):
         for tr in self._get_operations(self)():
-            tr.type = tr.TYPE_CARD
+            tr.type = tr.TYPE_DEFERRED_CARD
+            deferred_date = Regexp(CleanText('//div[@class="date"][contains(text(), "Carte")]'), r'le ([^:]+)', default=None)(self.doc)
+            if deferred_date:
+                tr.date = parse_french_date(deferred_date)
             yield tr
 
 
@@ -419,8 +482,15 @@ class CBListPage(CBHistoryPage):
 class BoursePage(LoggedPage, HTMLPage):
     ENCODING='latin-1'
 
+    TYPES = {u'plan épargne en actions': Account.TYPE_PEA
+            }
+
+    def password_required(self):
+        return CleanText(u'//b[contains(text(), "Afin de sécuriser vos transactions, nous vous invitons à créer un mot de passe trading")]')(self.doc)
+
     def get_next(self):
-        return re.search('"(.*?)"', self.doc.xpath('.//body')[0].attrib['onload']).group(1)
+        if 'onload' in self.doc.xpath('.//body')[0].attrib:
+            return re.search('"(.*?)"', self.doc.xpath('.//body')[0].attrib['onload']).group(1)
 
     def get_fullhistory(self):
         form = self.get_form(id="historyFilter")
@@ -435,30 +505,40 @@ class BoursePage(LoggedPage, HTMLPage):
         head_xpath = '//table[has-class("tableau_comptes_details")]/thead/tr/th'
 
         col_label = u'Comptes'
-        col_balance = re.compile('Valorisation')
+        col_titres = re.compile('Valorisation')
+        col_especes = u'Solde espèces'
 
         class item(ItemElement):
             klass = Account
 
             load_details = Field('_market_link') & AsyncLoad
 
-            obj_type = Account.TYPE_MARKET
-            obj_balance = CleanDecimal(TableCell('balance'), replace_dots=True)
+            obj__especes = CleanDecimal(TableCell('especes'), replace_dots=True)
+            obj__titres = CleanDecimal(TableCell('titres'), replace_dots=True, default=0)
             obj_valuation_diff = Async('details') &  CleanDecimal('//td[contains(text(), "value latente")]/ \
                                                                   following-sibling::td[1]', replace_dots=True)
             obj__market_link = Regexp(Attr(TableCell('label'), 'onclick'), "'(.*?)'")
             obj__link_id = Async('details') & Link(u'//a[text()="Historique"]')
             obj__transfer_id = None
 
+            def obj_balance(self):
+                return Field('_especes')(self) + Field('_titres')(self)
+
+            def obj_currency(self):
+                return Currency.get_currency(CleanText(TableCell('titres'))(self))
+
             def obj_id(self):
                 return "%sbourse" % "".join(CleanText().filter((TableCell('label')(self)[0]).xpath('./div[not(b)]')).split(' - '))
 
             def obj_label(self):
                 return "%s Bourse" % CleanText().filter((TableCell('label')(self)[0]).xpath('./div[b]'))
 
+            def obj_type(self):
+                return self.page.TYPES.get(' '.join(Field('label')(self).split()[:-1]).lower(), Account.TYPE_MARKET)
+
     @method
     class iter_investment(ListElement):
-        item_xpath = '//table[@id="tableValeurs"]/tbody/tr[not(@class) and count(descendant::td) > 1]'
+        item_xpath = '//table[@id="tableValeurs"]/tbody/tr[@id and count(descendant::td) > 1]'
         class item(ItemElement):
             klass = Investment
 
@@ -494,7 +574,7 @@ class BoursePage(LoggedPage, HTMLPage):
             form = self.page.get_form(id="historyFilter")
             form['PAGE'] = int(form['PAGE']) + 1
             return requests.Request("POST", form.url, data=dict(form)) \
-                   if self.page.doc.xpath('//*[@data-page = "%s"]' % form['PAGE']) else None
+                   if self.page.doc.xpath('//*[@data-page = $page]', page=form['PAGE']) else None
 
         class item(ItemElement):
             klass = Transaction
@@ -520,9 +600,16 @@ class BoursePage(LoggedPage, HTMLPage):
 
 
 class DiscPage(LoggedPage, HTMLPage):
-    def come_back(self):
-        form = self.get_form()
-        form.submit()
+    def on_load(self):
+        try:
+            # when life insurance access is restricted, a complete lcl logout form is present, don't use it
+            # and sometimes there's just no form
+            form = self.get_form(xpath='//form[not(@id="formLogout")]')
+            form.submit()
+        except FormNotFound: # Sometime no form is present, just a redirection
+            self.logger.debug('no form on this page')
+
+        super(DiscPage, self).on_load()
 
 
 class NoPermissionPage(LoggedPage, HTMLPage):
@@ -534,9 +621,15 @@ class AVPage(LoggedPage, HTMLPage):
     class get_list(ListElement):
         item_xpath = '//table[@class]/tbody/tr'
 
-        class account(ItemElement):
+        class item(ItemElement):
             klass = Account
 
+            def condition(self):
+                if self.obj_balance(self) == 0 and not self.el.xpath('.//td/a'):
+                    self.logger.warning("ignoring an AV account because there's no link for it")
+                    return False
+                return True
+
             obj__owner = CleanText('.//td[1]') & Regexp(pattern=r' ([^ ]+)$')
             obj_label = Format(u'%s %s', CleanText('.//td/a'), obj__owner)
             obj_balance = CleanDecimal('.//td[has-class("right")]', replace_dots=True)
@@ -547,22 +640,75 @@ class AVPage(LoggedPage, HTMLPage):
             obj__transfer_id = None
 
             def obj_id(self):
+                try:
+                    _id = CleanText('.//td/a/@id')(self)
+                    if not _id:
+                        ac_details_page = self.page.browser.open(Link('.//td/a')(self)).page
+                    else:
+                        split = _id.split('-')
+                        ac_details_page = self.page.browser.open('/outil/UWVI/AssuranceVie/accesDetail?ID_CONTRAT=%s&PRODUCTEUR=%s' % (split[0], split[1])).page
+                    return CleanText('(//tr[3])/td[2]')(ac_details_page.doc)
+                except ServerError:
+                    self.logger.debug("link didn't work, trying with the form instead")
+                    # the above server error can cause the form to fail, so we may have to go back on the accounts list before submitting
+                    self.page.browser.open(self.page.url)
+                    # redirection to lifeinsurances accounts and comeback on Lcl original website
+                    page = self.obj__form().submit().page
+                    account_id = page.get_account_id()
+                    page.come_back()
+                    return account_id
+
+            def obj_currency(self):
                 _id = CleanText('.//td/a/@id')(self)
                 if not _id:
-                    _id = Regexp(CleanText('.//td/a/@href'), r'ID_CONTRAT=(\d+)')(self)
-                return Format(u'%s%s', CleanText(Field('label'), replace=[(' ', '')]), _id)(self)
+                    ac_details_page = self.page.browser.open(Link('.//td/a')(self)).page
+                else:
+                    split = _id.split('-')
+                    ac_details_page = self.page.browser.open('/outil/UWVI/AssuranceVie/accesDetail?ID_CONTRAT=%s&PRODUCTEUR=%s' % (split[0], split[1])).page
+                return Currency.get_currency(re.sub(r'[\d\,\ ]', '', CleanText('(//tr[8])/td[2]', default=NotAvailable)(ac_details_page.doc))) or NotAvailable
 
             def obj__form(self):
                 form_id = Attr('.//td/a', 'id', default=None)(self)
-                if not form_id:
-                    return
+                if form_id:
+                    id_contrat = re.search(r'^(.*?)-', form_id).group(1)
+                    producteur = re.search(r'-(.*?)$', form_id).group(1)
+                else:
+                    if len(self.xpath('.//td/a[@class="clickPopupDetail"]')):
+                        # making a form of this link sometimes makes the site return an empty response...
+                        # the link is a link to some info, not full AV website
+                        # it's probably an indication the account is restricted anyway, so avoid it
+                        self.logger.debug("account %r is probably restricted, don't try its form", Field('id')(self))
+                        return None
+
+                    # sometimes information are not in id but in href
+                    url = Attr('.//td/a', 'href', default=None)(self)
+                    parsed_url = urlparse(url)
+                    params = parse_qs(parsed_url.query)
+
+                    id_contrat = params['ID_CONTRAT'][0]
+                    producteur = params['PRODUCTEUR'][0]
+
                 form = self.page.get_form('//form[@id="formRoutage"]')
-                form['ID_CONTRAT'] = re.search(r'^(.*?)-', form_id).group(1)
-                form['PRODUCTEUR'] = re.search(r'-(.*?)$', form_id).group(1)
+                form['ID_CONTRAT'] = id_contrat
+                form['PRODUCTEUR'] = producteur
                 return form
 
 
+class Form2Page(LoggedPage, LCLBasePage):
+    def on_load(self):
+        form = self.get_form(name="formulaire")
+        cName = self.get_from_js('.cName.value  = "', '";')
+        if cName:
+            form['cName'] = cName
+            form['cValue'] = self.get_from_js('.cValue.value  = "', '";')
+            form['cMaxAge'] = '-1'
+        return form.submit()
+
+
 class AVDetailPage(LoggedPage, LCLBasePage):
+    def get_account_id(self):
+        return Regexp(CleanText('//div[@class="libelletitrepage"]/h1'), r"N° (\w+)")(self.doc)
+
     def sub(self):
         form = self.get_form(name="formulaire")
         cName = self.get_from_js('.cName.value  = "', '";')
@@ -572,6 +718,10 @@ class AVDetailPage(LoggedPage, LCLBasePage):
             form['cMaxAge'] = '-1'
         return form.submit()
 
+    def submit_simple(self):
+        form = self.get_form(name="formulaire")
+        return form.submit()
+
     def come_back(self):
         session = self.get_from_js('idSessionSag = "', '"')
         params = {}
@@ -581,7 +731,7 @@ class AVDetailPage(LoggedPage, LCLBasePage):
         params['typeaction'] = 'reroutage_retour'
         params['site'] = 'LCLI'
         params['stbzn'] = 'bnc'
-        return self.browser.location('https://assurance-vie-et-prevoyance.secure.lcl.fr/filiale/entreeBam?%s' % urlencode(params))
+        return self.browser.location('https://assurance-vie-et-prevoyance.secure.lcl.fr/filiale/entreeBam', params=params)
 
     def get_details(self, account, act=None):
         form = self.get_form(id="frm_fwk")
@@ -589,19 +739,44 @@ class AVDetailPage(LoggedPage, LCLBasePage):
         if act is not None:
             self.browser.location("entreeBam?sessionSAG=%s&act=%s" % (form['sessionSAG'], act))
 
+    def is_restricted(self):
+        msg = CleanText('//div[has-class("titre_libelle_erreur")]')(self.doc)
+        return msg in (
+            "Pour ce type d’opération, nous vous conseillons de vous rapprocher de votre conseiller afin de bénéficier du conseil personnalisé le mieux adapté à vos objectifs.",
+            "Vous n’avez pas accès à l’espace assurances de personnes.",
+        )
+
     @method
-    class iter_investment(ListElement):
-        item_xpath = '//table[@class="table"]/tbody/tr[td[6]]'
+    class iter_investment(TableElement):
+        head_xpath = '//table[@class="table"][ends-with(@id,"CD_UCT")]/thead//th'
+        item_xpath = '//table[@class="table"][ends-with(@id,"CD_UCT")]/tbody/tr'
+
+        col_label = 'Le(s) support(s) financier(s) de votre contrat'
+        col_unitvalue = 'Valeur de la part'
+        col_vdate = 'En date du :'
+        col_quantity = 'Nombre de parts'
+        col_valuation = 'Total'
+        col_portfolio_share = u'Répartition'
 
         class item(ItemElement):
             klass = Investment
 
-            obj_label = CleanText('.//td[1]/a | .//td[1]/span ')
-            obj_code = CleanText('.//td[1]/a/@id') & Regexp(pattern='^([^ ]+).*', default=NotAvailable)
-            obj_quantity = MyDecimal('.//td[4]/span')
-            obj_unitvalue = MyDecimal('.//td[2]/span')
-            obj_valuation = MyDecimal('.//td[5]/span')
-            obj_portfolio_share = Eval(lambda x: x / 100, CleanDecimal('.//td[6]/span', replace_dots=True))
+            obj_label = CleanText(TableCell('label'))
+
+            def obj_code(self):
+                td = TableCell('label')(self)[0]
+                return Attr('.//a', 'id', default=NotAvailable)(td)
+
+            obj_code_type = Investment.CODE_TYPE_ISIN
+
+            def obj_quantity(self):
+                return MyDecimal(TableCell('quantity'))(self) or NotAvailable
+
+            def obj_unitvalue(self):
+                return MyDecimal(TableCell('unitvalue'))(self) or NotAvailable
+
+            obj_valuation = MyDecimal(TableCell('valuation'))
+            obj_portfolio_share = Eval(lambda x: x / 100, CleanDecimal(TableCell('portfolio_share'), replace_dots=True))
 
     @pagination
     @method
@@ -635,6 +810,18 @@ class RibPage(LoggedPage, LCLBasePage):
         if (self.doc.xpath('//div[contains(@class, "rib_cadre")]//div[contains(@class, "rib_internat")]')):
             return CleanText().filter(self.doc.xpath('//div[contains(@class, "rib_cadre")]//div[contains(@class, "rib_internat")]//p//strong')[0].text).replace(' ','')
 
+    def check_iban_by_account(self, account_id):
+        iban_account_id = CleanText().filter(self.doc.xpath('(//td[@class[contains(., "guichet-")]]/following-sibling::*)[1]/strong'))
+        iban_guichet_id = CleanText().filter(self.doc.xpath('(//td[@class[contains(., "guichet-")]]/strong)[1]'))
+        iban_account = "%s%s" % (iban_guichet_id, iban_account_id[4:])
+
+        if account_id == iban_account:
+            return CleanText().filter(self.doc.xpath('//div[contains(@class, "rib_cadre")]//div[contains(@class, "rib_internat")]//p//strong')[0].text).replace(' ', '')
+        else:
+            return None
+
+    def has_iban_choice(self):
+        return False if self.doc.xpath('(//strong[contains(., "RELEVE D\'IDENTITE BANCAIRE")])[1]') else True
 
 class HomePage(LoggedPage, HTMLPage):
     pass
@@ -645,7 +832,7 @@ class TransferPage(LoggedPage, HTMLPage):
         # This aims to track input errors.
         script_error = CleanText(u"//script[contains(text(), 'if (\"true\"===\"true\")')]")(self.doc)
         if script_error:
-            raise TransferError(re.search(u'\.html\("(.*?)"\)', script_error).group(1))
+            raise TransferBankError(CleanText().filter(html2text(re.search(u'\.html\("(.*?)"\)', script_error).group(1))))
 
     def can_transfer(self, account_transfer_id):
         for div in self.doc.xpath('//div[input[@id="indexCompteEmetteur"]]//div[@class="infoCompte" and not(@title)]'):
@@ -654,7 +841,7 @@ class TransferPage(LoggedPage, HTMLPage):
         return False
 
     def get_account_index(self, xpath, account_id):
-        for option in self.doc.xpath('//select[@id="%s"]/option' % xpath):
+        for option in self.doc.xpath('//select[@id=$id]/option', id=xpath):
             if account_id in CleanText('.', replace=[(' ', '')])(option):
                 return option.attrib['value']
         else:
@@ -662,7 +849,7 @@ class TransferPage(LoggedPage, HTMLPage):
 
     def choose_recip(self, recipient):
         form = self.get_form(id='formulaire')
-        form['indexCompteDestinataire'] = self.get_value(recipient.id, 'recipient')
+        form['indexCompteDestinataire'] = self.get_value(recipient._transfer_id, 'recipient')
         form.submit()
 
     def transfer(self, amount, reason):
@@ -694,7 +881,8 @@ class TransferPage(LoggedPage, HTMLPage):
             klass = Recipient
             validate = lambda self, obj: self.obj_id(self) != self.env['account_transfer_id']
 
-            obj_id = CleanText('./div[@class="infoCompte" and not(@title)]', replace=[(' ', '')])
+            obj_id = CleanText('./div[@class="infoCompte" and not(@title)]', replace=[(' 0000', '')])
+            obj__transfer_id = CleanText('./div[@class="infoCompte" and not(@title)]', replace=[(' ', '')])
             obj_label = CleanText('./div[1]')
             obj_bank_name = Env('bank_name')
             obj_category = Env('category')
@@ -709,7 +897,7 @@ class TransferPage(LoggedPage, HTMLPage):
             def parse(self, el):
                 if bool(CleanText('./div[@id="soldeEurosCompte"]')(self)):
                     self.env['category'] = u'Interne'
-                    account = find_object(self.page.browser.get_accounts_list(), _transfer_id=self.obj_id(self))
+                    account = find_object(self.page.browser.get_accounts_list(), id=self.obj_id(self))
                     self.env['iban'] = account.iban if account else NotAvailable
                     self.env['bank_name'] = u'LCL'
                 else:
@@ -723,10 +911,10 @@ class TransferPage(LoggedPage, HTMLPage):
             assert reason in CleanText('//div[@class="motif"]')(self.doc)
             assert account._transfer_id in CleanText(u'//div[div[@class="libelleChoix" and contains(text(), "Compte émetteur")]] \
                                                     //div[@class="infoCompte" and not(@title)]', replace=[(' ', '')])(self.doc)
-            assert recipient.id in CleanText(u'//div[div[@class="libelleChoix" and contains(text(), "Compte destinataire")]] \
+            assert recipient._transfer_id in CleanText(u'//div[div[@class="libelleChoix" and contains(text(), "Compte destinataire")]] \
                                                     //div[@class="infoCompte" and not(@title)]', replace=[(' ', '')])(self.doc)
         except AssertionError:
-            raise TransferError('data consistency failed.')
+            raise TransferError('data consistency failed')
 
     def create_transfer(self, account, recipient, amount, reason):
         transfer = Transfer()
@@ -748,3 +936,84 @@ class TransferPage(LoggedPage, HTMLPage):
     def fill_transfer_id(self, transfer):
         transfer.id = Regexp(CleanText(u'//div[@class="alertConfirmationVirement"]//p[contains(text(), "référence")]'), u'référence (\d+)')(self.doc)
         return transfer
+
+
+class AddRecipientPage(LoggedPage, HTMLPage):
+    def validate(self, iban, label):
+        form = self.get_form(id='mainform')
+        form['PAYS_IBAN'] = iban[:2]
+        form['LIBELLE'] = label
+        form['COMPTE_IBAN'] = iban[2:]
+        form.submit()
+
+
+class CheckValuesPage(LoggedPage, HTMLPage):
+    def check_values(self, iban, label):
+        values = CleanText('//form[contains(@action, "/outil")]')(self.doc)
+        try:
+            assert iban in values
+        except AssertionError:
+            raise AddRecipientError('iban not found in values')
+        try:
+            assert label in values
+        except AssertionError:
+            raise AddRecipientError('recipient label not found in values')
+
+
+class DocumentsPage(LoggedPage, HTMLPage):
+    def do_search_request(self):
+        form = self.get_form(id="rechercherForm")
+        form['listePeriode'] = "PERIODE1"
+        form['listeFamille'] = "ALL"
+        form['debutRec'] = None
+        form['finRec'] = None
+        form['typeDocFamHidden'] = "ALL"
+        form['typeDocSFamHidden'] = None
+        form.submit()
+
+    @method
+    class get_list(TableElement):
+        head_xpath = '//table[@class="dematTab"]/thead/tr/th'
+        item_xpath = u'//table[@class="dematTab"]/tbody/tr[./td[@class="dematTab-firstCell" and contains(., "Relevés")]]'
+
+        col_label = 'Nature de document'
+        col_id = 'Type de document'
+        col_url = 'Visualiser'
+        col_date = 'Date'
+
+        class item(ItemElement):
+            klass = Document
+
+            obj_id = Slugify(Format('%s_%s', CleanText(TableCell('id')), CleanText(TableCell('date'))))
+            obj_label = Format('%s %s', CleanText(TableCell('label')), CleanText(TableCell('date')))
+            obj_date = Date(CleanText(TableCell('date')))
+            obj_format = "pdf"
+
+            def obj_url(self):
+                return Link(TableCell('url')(self)[0].xpath('./a'))(self)
+
+
+class ClientPage(LoggedPage, HTMLPage):
+    @method
+    class get_item(ItemElement):
+        klass = Subscription
+
+        obj_id = CleanText('//li[@id="nomClient"]', replace=[('M', ''), ('Mme', ''), (' ', '')])
+        obj_label = CleanText('//li[@id="nomClient"]', replace=[('M', ''), ('Mme', '')])
+        obj_subscriber = CleanText('//li[@id="nomClient"]', replace=[('M', ''), ('Mme', '')])
+
+
+class RecipConfirmPage(CheckValuesPage):
+    pass
+
+
+class RecipientPage(LoggedPage, HTMLPage):
+    pass
+
+
+class SmsPage(LoggedPage, HTMLPage):
+    pass
+
+
+class RecipRecapPage(CheckValuesPage):
+    pass
