@@ -24,7 +24,7 @@ from weboob.browser.filters.html import Attr
 from weboob.capabilities.bill import Bill, Subscription
 from weboob.tools.date import parse_french_date
 
-class HomePage(HTMLPage, LoggedPage):
+class HomePage(LoggedPage, HTMLPage):
     @method
     class get_list(ListElement):
         item_xpath = '//div[@id="divAccueilInformationClient"]//div[@id="divInformationClient"]'
@@ -36,7 +36,17 @@ class HomePage(HTMLPage, LoggedPage):
             obj_label = CleanText('.//div[@id="divlblTitleFirstNameLastName"]/span')
 
 
-class BillsPage(HTMLPage, LoggedPage):
+class LoginPage(HTMLPage):
+    def login(self, username, password):
+        form = self.get_form(xpath='//form[@id="aspnetForm"]')
+        form["ctl00$ctl00$cphMainContent$cphMainContent$txbMail"] = username
+        form["ctl00$ctl00$cphMainContent$cphMainContent$txbPassword"] = password
+        form["__EVENTTARGET"] = "ctl00$ctl00$cphMainContent$cphMainContent$butConnexion"
+        form["ctl00_ctl00_actScriptManager_HiddenField"] = ";;LIBLDLC:fr-FR:2a6faad4-8912-415f-8586-e1088a6418ed:e5e73cb5;AjaxControlToolkit, Version=3.5.40412.0, Culture=neutral, PublicKeyToken=28f01b0e84b6d53e:fr-FR:f0f17dea-2bbf-45d7-9f07-8361cd7f1424:5546a2b:475a4ef5:d2e10b12;LIBLDLC, Version=1.1.3.0, Culture=neutral, PublicKeyToken=null:fr-FR:2a6faad4-8912-415f-8586-e1088a6418ed::::70413c6f;AjaxControlToolkit, Version=3.5.40412.0, Culture=neutral, PublicKeyToken=28f01b0e84b6d53e:fr-FR:f0f17dea-2bbf-45d7-9f07-8361cd7f1424:effe2a26:751cdd15:dfad98a5:1d3ed089:497ef277:a43b07eb:3cf12cf1"
+        form.submit()
+
+
+class BillsPage(LoggedPage, HTMLPage):
     def get_range(self):
         for value in self.doc.xpath('//div[@class="commandListing content clearfix"]//select/option/@value'):
             yield value
