@@ -26,12 +26,13 @@ from weboob.browser.url import URL
 class NewspaperFigaroBrowser(AbstractBrowser):
     "NewspaperFigaroBrowser class"
     PARENT = 'genericnewspaper'
-    BASEURL = ''
+    BASEURL = 'http://lefigaro.fr'
 
     article_page = URL('http://lefigaro.fr/(.*)/(\d{4})/(\d{2})/(\d{2})/(.*$)',
                        'http://\w+.lefigaro.fr/(.*)/(\d{4})/(\d{2})/(\d{2})/(.*$)',
+                       'http://\w+.lefigaro.fr/(.*)',
                        ArticlePage)
 
-    def __init__(self, weboob, *args, **kwargs):
-        self.weboob = weboob
-        super(self.__class__, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        self.weboob = kwargs['weboob']
+        super(NewspaperFigaroBrowser, self).__init__(*args, **kwargs)
