@@ -20,12 +20,18 @@
 
 from weboob.tools.test import BackendTest
 from weboob.tools.html import html2text
+from weboob.tools.value import Value
 
 
 class LeFigaroTest(BackendTest):
     MODULE = 'lefigaro'
 
+    def setUp(self):
+        if not self.is_backend_configured():
+            self.backend.config['feed'] = Value(value='international')
+
     def test_lefigaro(self):
+        self.backend.RSS_FEED = "http://www.lefigaro.fr/rss/figaro_%s.xml" % self.backend.config['feed'].get()
         l = list(self.backend.iter_threads())
         assert len(l)
         thread = self.backend.get_thread(l[0].id)
