@@ -29,6 +29,6 @@ class NewspaperLibeBrowser(AbstractBrowser):
 
     article = URL('http://.*liberation.fr/.*', ArticlePage)
 
-    def __init__(self, weboob, *args, **kwargs):
-        self.weboob = weboob
-        super(self.__class__, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        self.weboob = kwargs['weboob']
+        super(NewspaperLibeBrowser, self).__init__(*args, **kwargs)
