@@ -29,6 +29,6 @@ class Newspaper20minutesBrowser(AbstractBrowser):
 
     article_page = URL('/.+/?.*', ArticlePage)
 
-    def __init__(self, weboob, *args, **kwargs):
-        self.weboob = weboob
-        super(self.__class__, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        self.weboob = kwargs['weboob']
+        super(Newspaper20minutesBrowser, self).__init__(*args, **kwargs)
