@@ -24,11 +24,11 @@ from weboob.browser.filters.standard import CleanDecimal, CleanText, Env, Format
 from weboob.browser.filters.html import Attr
 from weboob.browser.filters.json import Dict
 from weboob.browser.elements import ListElement, ItemElement, method, DictElement
-
+from weboob.exceptions import ActionNeeded
 
 class LoginPage(HTMLPage):
     def is_logged(self):
-        return not self.doc.xpath('//div[has-class("error")]')
+        return not self.doc.xpath('//div[has-class("error")]') and not self.doc.xpath('//form//input[contains(@placeholder, "Account ID")]')
 
     def login(self, login, password):
         form = self.get_form('//form[@class="pagination-centered"]')
@@ -38,6 +38,12 @@ class LoginPage(HTMLPage):
         form[pwd] = password
         form.submit()
 
+    def check_double_auth(self):
+        double_auth = self.doc.xpath('//input[@id="codeSMS"]')
+
+        if double_auth:
+            raise ActionNeeded(CleanText('(//div[contains(., "Two-Factor")])[5]')(self.doc))
+
 
 class ProfilePage(LoggedPage, JsonPage):
     @method
@@ -64,3 +70,4 @@ class BillsPage(LoggedPage, JsonPage):
             obj_type = u"bill"
             obj_price = CleanDecimal(Dict('priceWithTax/value'))
             obj_url = Dict('pdfUrl')
+            obj_label = Format('Facture %s', Dict('orderId'))
