@@ -31,9 +31,9 @@ class NewspaperPresseuropBrowser(AbstractBrowser):
 
     presseurop_page = URL("/.*", PresseuropPage)
 
-    def __init__(self, weboob, *args, **kwargs):
-        self.weboob = weboob
-        super(self.__class__, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        self.weboob = kwargs['weboob']
+        super(NewspaperPresseuropBrowser, self).__init__(*args, **kwargs)
 
     def get_daily_date(self, _id):
         self.location(_id)
