@@ -72,6 +72,9 @@ class RadioPage(HTMLPage):
             url = CleanText('//a[@id="player"][1]/@href')(self.doc)
         if not url:
             url = CleanText('//div[@id="audio"][1]/@data-url-live')(self.doc)
+        if not url:
+            url = CleanText('//button[1]/@data-url-live')(self.doc)
+
         if not url:
             url = Regexp(CleanText('//script'), '.*urlLive:\'(.*)\',urlTS.*', default=None)(self.doc)
         return url
@@ -176,26 +179,26 @@ class RadioPage(HTMLPage):
 
     @method
     class get_france_musique_podcast_emissions(ListElement):
-        item_xpath = '//div[@class="liste-emissions"]/ul/li'
+        item_xpath = '//article/div'
         ignore_duplicate = True
 
         class item(ItemElement):
             klass = Collection
 
             def condition(self):
-                return CleanText('./div/ul/li/a[@class="ico-rss"]/@href')(self) and\
-                    Regexp(CleanText('./div/ul/li/a[@class="ico-rss"]/@href'),
+                return CleanText('./div/div/div[has-class("rss")]/a/@href')(self) and\
+                    Regexp(CleanText('./div/div/div[has-class("rss")]/a/@href'),
                            'http://radiofrance-podcast.net/podcast09/rss_(.*).xml')(self)
 
             def obj_split_path(self):
-                _id = Regexp(CleanText('./div/ul/li/a[@class="ico-rss"]/@href'),
+                _id = Regexp(CleanText('./div/div/div[has-class("rss")]/a/@href'),
                              'http://radiofrance-podcast.net/podcast09/rss_(.*).xml')(self)
                 self.env['split_path'].append(_id)
                 return self.env['split_path']
 
-            obj_id = Regexp(CleanText('./div/ul/li/a[@class="ico-rss"]/@href'),
+            obj_id = Regexp(CleanText('./div/div/div[has-class("rss")]/a/@href'),
                             'http://radiofrance-podcast.net/podcast09/rss_(.*).xml')
-            obj_title = CleanText('./div/h3')
+            obj_title = CleanText('./header/h2')
 
     @method
     class get_france_inter_podcast_emissions(ListElement):
@@ -206,17 +209,17 @@ class RadioPage(HTMLPage):
             klass = Collection
 
             def condition(self):
-                return CleanText('./div/footer/div[has-class("rss")]/a/@href')(self) and\
-                    Regexp(CleanText('./div/footer/div[has-class("rss")]/a/@href'),
+                return CleanText('./div/div/div/div/ul/li/a[has-class("rss")]/@href')(self) and\
+                    Regexp(CleanText('./div/div/div/div/ul/li/a[has-class("rss")]/@href'),
                            'http://radiofrance-podcast.net/podcast09/rss_(.*).xml')(self)
 
             def obj_split_path(self):
-                _id = Regexp(CleanText('./div/footer/div[has-class("rss")]/a/@href'),
+                _id = Regexp(CleanText('./div/div/div/div/ul/li/a[has-class("rss")]/@href'),
                              'http://radiofrance-podcast.net/podcast09/rss_(.*).xml')(self)
                 self.env['split_path'].append(_id)
                 return self.env['split_path']
 
-            obj_id = Regexp(CleanText('./div/footer/div[has-class("rss")]/a/@href'),
+            obj_id = Regexp(CleanText('./div/div/div/div/ul/li/a[has-class("rss")]/@href'),
                             'http://radiofrance-podcast.net/podcast09/rss_(.*).xml')
 
             obj_title = CleanText('./div/div[@class="rich-section-list-item-content-show"]')
@@ -239,6 +242,8 @@ class RadioPage(HTMLPage):
 class JsonPage(JsonPage):
     @method
     class get_france_culture_podcast_emissions(DictElement):
+        ignore_duplicate = True
+
         class item(ItemElement):
             klass = Collection
 
@@ -308,10 +313,9 @@ class JsonPage(JsonPage):
 
     def get_current(self):
         if 'current' in self.doc:
-            emission_title = self.doc['current']['emission']['titre']
-            song_title = self.doc['current']['song']['titre']
-            title = u'%s: %s' % (emission_title, song_title)
-            person = self.doc['current']['song']['interpreteMorceau']
+            person = self.doc['current']['emission']['titre']
+            title = u'%s: %s' %(self.doc['current']['song']['interpreteMorceau'],
+                               self.doc['current']['song']['titre'])
             return person, title
         elif 'diffusions' in self.doc:
             now = int(time.time())
