@@ -19,12 +19,21 @@
 
 
 from weboob.tools.test import BackendTest
+from weboob.tools.value import Value
 import itertools
 
 
 class RegionsjobTest(BackendTest):
     MODULE = 'regionsjob'
 
+    def setUp(self):
+        if not self.is_backend_configured():
+            self.backend.config['website'] = Value(value='www.parisjob.com')
+            self.backend.config['experience'] = Value(value='')
+            self.backend.config['secteur'] = Value(value='')
+            self.backend.config['contract'] = Value(value='CDI')
+            self.backend.config['metier'] = Value(value='')
+
     def test_regionjob_search(self):
         l = list(itertools.islice(self.backend.search_job(u'informaticien'), 0, 20))
         assert len(l)
