@@ -35,12 +35,12 @@ class S2eModule(Module, CapBank):
     MAINTAINER = u'Edouard Lambert'
     EMAIL = 'elambert@budget-insight.com'
     LICENSE = 'AGPLv3+'
-    VERSION = '1.2'
+    VERSION = '1.3'
 
     CONFIG = BackendConfig(
              ValueBackendPassword('login',    label='Identifiant', masked=False),
-             ValueBackendPassword('password',   label='Code secret', regexp='^(\d{6}|)$'),
-             ValueBackendPassword('secret', label=u'Réponse secrète (optionnel)', default=''),
+             ValueBackendPassword('password', label='Code secret', regexp='^(\d{6})$'),
+             ValueBackendPassword('secret',   label=u'Réponse secrète (optionnel)', default=''),
              Value('website', label='Banque', default='', choices={'esalia': u'Esalia',
                                                                    'capeasi': u'Capeasi',
                                                                    'erehsbc': u'ERE HSBC',
@@ -70,3 +70,6 @@ class S2eModule(Module, CapBank):
 
     def iter_investment(self, account):
         return self.browser.iter_investment(account)
+
+    def iter_pocket(self, account):
+        return self.browser.iter_pocket(account)
