@@ -19,7 +19,7 @@
 
 
 import re, requests
-from cStringIO import StringIO
+from io import BytesIO
 from decimal import Decimal
 from lxml import objectify
 
@@ -27,10 +27,10 @@ from weboob.browser.pages import HTMLPage, XMLPage, LoggedPage, pagination
 from weboob.browser.elements import ItemElement, TableElement, SkipItem, method
 from weboob.browser.filters.standard import CleanText, Date, Regexp, Eval, CleanDecimal, Env, TableCell, Field
 from weboob.browser.filters.html import Attr
-from weboob.capabilities.bank import Account, Investment, Transaction
+from weboob.capabilities.bank import Account, Investment, Pocket, Transaction
 from weboob.capabilities.base import NotAvailable
 from weboob.tools.captcha.virtkeyboard import MappedVirtKeyboard
-from weboob.exceptions import NoAccountsException, BrowserUnavailable
+from weboob.exceptions import NoAccountsException, BrowserUnavailable, ActionNeeded
 
 
 def MyDecimal(*args, **kwargs):
@@ -61,7 +61,7 @@ class S2eVirtKeyboard(MappedVirtKeyboard):
     def __init__(self, page, vkid):
         img = page.doc.find('//img[@id="clavier_virtuel"]')
         res = page.browser.open("/portal/rest/clavier_virtuel/%s" % vkid)
-        MappedVirtKeyboard.__init__(self, StringIO(res.content), page.doc, img, self.color, convert='RGB')
+        MappedVirtKeyboard.__init__(self, BytesIO(res.content), page.doc, img, self.color, convert='RGB')
         self.check_symbols(self.symbols, None)
 
     def get_symbol_code(self, md5sum):
@@ -99,12 +99,13 @@ class LoginPage(HTMLPage):
                else cgu
         return cgu or CleanText('//div[contains(text(), "Erreur")]', default='')(self.doc)
 
-
-class AMFCodePage(XMLPage):
+# AMF codes
+class AMFHSBCPage(XMLPage):
     ENCODING = "UTF-8"
+    CODE_TYPE = Investment.CODE_TYPE_AMF
 
     def build_doc(self, content):
-        doc = super(AMFCodePage, self).build_doc(content).getroot()
+        doc = super(AMFHSBCPage, self).build_doc(content).getroot()
         # Remove namespaces
         for el in doc.getiterator():
             if not hasattr(el.tag, 'find'):
@@ -115,12 +116,51 @@ class AMFCodePage(XMLPage):
         objectify.deannotate(doc, cleanup_namespaces=True)
         return doc
 
+    def get_code(self):
+        return CleanText('//AMF_Code', default=NotAvailable)(self.doc)
+
+
+class AMFAmundiPage(HTMLPage):
+    CODE_TYPE = Investment.CODE_TYPE_AMF
+
+    def get_code(self):
+        return CleanText('//span[contains(., "(C)")]', default=NotAvailable)(self.doc)
+
+
+class AMFSGPage(HTMLPage):
+    CODE_TYPE = Investment.CODE_TYPE_AMF
+
+    def get_code(self):
+        return CleanText('//div[@id="header_code"]', default=NotAvailable)(self.doc)
+
+    def build_doc(self, data):
+        if not data.strip():
+            # sometimes the page is totally blank... prevent an XMLSyntaxError
+            data = b'<html></html>'
+        return super(AMFSGPage, self).build_doc(data)
+
+
+class LyxorfcpePage(LoggedPage, HTMLPage):
+    CODE_TYPE = Investment.CODE_TYPE_ISIN
+
+    def get_code(self):
+        return Regexp(CleanText('//span[@class="isin"]'), 'Code ISIN : (.*)')(self.doc)
+
+
+class EcofiPage(LoggedPage, HTMLPage):
+    CODE_TYPE = Investment.CODE_TYPE_ISIN
+
+    def get_code(self):
+        return CleanText('//div[has-class("field-name-CodeISIN")]/div[@class="field-items"]')(self.doc)
+
 
 class ItemInvestment(ItemElement):
     klass = Investment
 
     obj_unitvalue = Env('unitvalue')
     obj_vdate = Env('vdate')
+    obj_code = Env('code')
+    obj_code_type = Env('code_type')
 
     def obj_label(self):
         return CleanText(TableCell('label')(self)[0].xpath('.//div[contains(@style, \
@@ -129,20 +169,6 @@ class ItemInvestment(ItemElement):
     def obj_valuation(self):
         return MyDecimal(TableCell('valuation')(self)[0].xpath('.//div[not(.//div)]'))(self)
 
-    def obj_code(self):
-        link_id = Attr(u'.//a[contains(@title, "détail du fonds")]', 'id', default=None)(self)
-        inv_id = Attr('.//a[contains(@id, "linkpdf")]', 'id', default=None)(self)
-        if link_id and inv_id:
-            form = self.page.get_form('//div[@id="operation"]//form')
-            form['idFonds'] = inv_id.split('-', 1)[-1]
-            form['org.richfaces.ajax.component'] = form[link_id] = link_id
-            page = self.page.browser.open(form['javax.faces.encodedURL'], data=dict(form)).page
-            m = re.search('fundid=(\w+).+SH=(\w+)', CleanText('//complete', default="")(page.doc))
-            if m:
-                page = page.browser.open('https://www.assetmanagement.hsbc.com/feedRequest?feed_data=gfcFundData&cod=FR&client=FCPE&fId=%s&SH=%s&lId=fr' % m.groups()).page
-                return CleanText('//AMF_Code', default=NotAvailable)(page.doc)
-        return NotAvailable
-
     def parse(self, el):
         # Trying to find vdate and unitvalue
         unitvalue, vdate = None, None
@@ -155,6 +181,54 @@ class ItemInvestment(ItemElement):
         self.env['unitvalue'] = MyDecimal().filter(unitvalue) if unitvalue else NotAvailable
         self.env['vdate'] = Date(dayfirst=True).filter(vdate) if vdate else NotAvailable
 
+        page = None
+        link_id = Attr(u'.//a[contains(@title, "détail du fonds")]', 'id', default=None)(self)
+        inv_id = Attr('.//a[contains(@id, "linkpdf")]', 'id', default=None)(self)
+
+        if link_id and inv_id:
+            form = self.page.get_form('//div[@id="operation"]//form')
+            form['idFonds'] = inv_id.split('-', 1)[-1]
+            form['org.richfaces.ajax.component'] = form[link_id] = link_id
+
+            page = self.page.browser.open(form['javax.faces.encodedURL'], data=dict(form)).page
+
+            if "hsbc.fr" in self.page.browser.BASEURL: # special space for HSBC
+                m = re.search('fundid=(\w+).+SH=(\w+)', CleanText('//complete', default="")(page.doc))
+
+                if m: # had to put full url to skip redirections.
+                    page = page.browser.open('https://www.assetmanagement.hsbc.com/feedRequest?feed_data=gfcFundData&cod=FR&client=FCPE&fId=%s&SH=%s&lId=fr' % m.groups()).page
+            elif "consulteroperations" not in self.page.browser.url: # not on history
+                url = Regexp(CleanText('//complete'), r"openUrlFichesFonds\('(.*?)'\)", default=NotAvailable)(page.doc)
+                if url is NotAvailable:
+                    # redirection to a useless graphplot page with url like /portal/salarie-sg/fichefonds?idFonds=XXX&source=/portal/salarie-sg/monepargne/mesavoirs
+                    assert CleanText('//redirect/@url')(page.doc)
+                    self.env['code'] = NotAvailable
+                    self.env['code_type'] = NotAvailable
+                    return
+
+                if url.startswith('http://docfinder.is.bnpparibas-ip.com/'):
+                    # pdf... http://docfinder.is.bnpparibas-ip.com/api/files/040d05b3-1776-4991-aa49-f0cd8717dab8/1536
+                    self.env['code'] = NotAvailable
+                    self.env['code_type'] = NotAvailable
+                    return
+
+                match = re.match(r'http://www.cpr-am.fr/fr/fonds_detail.php\?isin=([A-Z0-9]+)', url)
+                match = match or re.match(r'http://www.cpr-am.fr/particuliers/product/view/([A-Z0-9]+)', url)
+                if match:
+                    self.env['code'] = match.group(1)
+                    self.env['code_type'] = Investment.CODE_TYPE_ISIN
+                    return
+
+                page = self.page.browser.open(url).page
+
+        try:
+            self.env['code'] = page.get_code()
+            self.env['code_type'] = page.CODE_TYPE
+        # Handle page is None and page has not get_code method
+        except AttributeError:
+            self.env['code'] = NotAvailable
+            self.env['code_type'] = NotAvailable
+
 
 class MultiPage(HTMLPage):
     def get_multi(self):
@@ -172,12 +246,17 @@ class MultiPage(HTMLPage):
 
 class AccountsPage(LoggedPage, MultiPage):
     def on_load(self):
-        no_accounts_message = CleanText('//span[contains(text(), "On this date, you still have no employee savings in this company.")] | \
-                        //span[contains(text(), "On this date, you do not yet have any employee savings in this company.")] | \
-                        //span[contains(text(), "On this date, you no longer have any employee savings in this company.")]')(self.doc)
+        no_accounts_message = CleanText('//span[contains(text(), "On this date, you still have no employee savings in this company.")] | '
+                        '//span[contains(text(), "On this date, you do not yet have any employee savings in this company.")] | '
+                        '//span[contains(text(), "On this date, you no longer have any employee savings in this company.")] | '
+                        '//p[contains(text(), "You no longer have any employee savings.")]')(self.doc)
         if no_accounts_message:
             raise NoAccountsException(no_accounts_message)
 
+        if CleanText('//a//span[contains(text(), "J\'ACCEPTE LES CONDITIONS GENERALES D\'UTILISATION") or'
+                     '          contains(text(), "I ACCEPT THE GENERAL CONDITIONS OF USE")]')(self.doc):
+            raise ActionNeeded("Veuillez valider les conditions générales d'utilisation")
+
     TYPES = {'PEE': Account.TYPE_PEE,
              'PEI': Account.TYPE_PEE,
              'PEEG': Account.TYPE_PEE,
@@ -188,6 +267,13 @@ class AccountsPage(LoggedPage, MultiPage):
              'SWISS': Account.TYPE_MARKET
             }
 
+    CONDITIONS = {u'disponible': Pocket.CONDITION_AVAILABLE,
+                  u'épargne':    Pocket.CONDITION_AVAILABLE,
+                  u'available':  Pocket.CONDITION_AVAILABLE,
+                  u'withdrawal': Pocket.CONDITION_RETIREMENT,
+                  u'retraite':   Pocket.CONDITION_RETIREMENT,
+                 }
+
     @method
     class iter_accounts(TableElement):
         item_xpath = '//div[contains(@id, "Dispositif")]//table/tbody/tr[td[2]]'
@@ -216,14 +302,13 @@ class AccountsPage(LoggedPage, MultiPage):
                 self.env['id'] = id
                 self.env['label'] = label
 
-    def get_investment_pages(self, accid, valuation=True):
+    def get_investment_pages(self, accid, valuation=True, pocket=False):
         form = self.get_form('//div[@id="operation"]//form')
-        div_xpath = '//div[contains(@id, "ongletDetailParSupport")]'
+        div_xpath = '//div[contains(@id, "%s")]' % ("detailParSupportEtDate" if pocket else "ongletDetailParSupport")
         input_id = Attr('//input[contains(@id, "onglets")]', 'name')(self.doc)
         select_id = Attr('%s//select' % div_xpath, 'id')(self.doc)
-        option_value = Attr('//option[contains(text(), "%s")]' % accid, 'value')(self.doc)
-        form[select_id] = option_value
-        form[input_id] = "onglet2"
+        form[select_id] = Attr('//option[contains(text(), "%s")]' % accid, 'value')(self.doc)
+        form[input_id] = "onglet4" if pocket else "onglet2"
         # Select display : amount or quantity
         radio_txt = ("En montant" if valuation else [u"Quantité", "En parts"]) if self.browser.LANG == "fr" else \
                     ("In amount" if valuation else ["Quantity", "In units"])
@@ -233,16 +318,13 @@ class AccountsPage(LoggedPage, MultiPage):
             % (div_xpath, radio_txt), 'onclick'), '"([^"]+)')(self.doc)
         form[input_id] = input_id
         form['javax.faces.source'] = input_id
-        form['valorisationMontant'] = "true" if valuation else "false"
+        if pocket:
+            form['visualisationMontant'] = "true" if valuation else "false"
+        else:
+            form['valorisationMontant'] = "true" if valuation else "false"
         data = {k: v for k, v in dict(form).iteritems() if "blocages" not in v}
         self.browser.location(form.url, data=data)
 
-    def update_quantity(self, invs):
-        for inv in invs:
-            inv.quantity = MyDecimal().filter(CleanText('//div[contains(@id, "ongletDetailParSupport")] \
-                 //tr[.//div[contains(text(), "%s")]]/td[last()]//div/text()' % inv.label)(self.doc))
-        return invs
-
     @method
     class iter_investment(TableElement):
         item_xpath = '//div[contains(@id, "ongletDetailParSupport")]//table/tbody/tr[td[4]]'
@@ -251,12 +333,67 @@ class AccountsPage(LoggedPage, MultiPage):
         col_label = [re.compile(u'My investment'), re.compile(u'Mes supports')]
         col_valuation = [re.compile(u'Gross amount'), re.compile(u'Montant brut')]
         col_portfolio_share = [u'Distribution', u'Répartition']
+        col_diff = [u'+ or - potential value', u'+ ou - value potentielle']
 
         class item(ItemInvestment):
+            def obj_id(self):
+                return
+
+            def obj_diff(self):
+                td = TableCell('diff', default=None)(self)
+                return MyDecimal('.//div[not(.//div)]')(td[0]) if td else NotAvailable
+
             def obj_portfolio_share(self):
                 return Eval(lambda x: x / 100, MyDecimal(TableCell('portfolio_share')(self)[0] \
                     .xpath('.//div[has-class("nowrap")]'))(self))(self)
 
+    def update_invs_quantity(self, invs):
+        for inv in invs:
+            inv.quantity = MyDecimal().filter(CleanText('//div[contains(@id, "ongletDetailParSupport")] \
+                 //tr[.//div[contains(text(), "%s")]]/td[last()]//div/text()' % inv.label)(self.doc))
+        return invs
+
+    @method
+    class iter_pocket(TableElement):
+        item_xpath = '//div[contains(@id, "detailParSupportEtDate")]//table/tbody[@class="rf-cst"]/tr[td[4]]'
+        head_xpath = '//div[contains(@id, "detailParSupportEtDate")]//table/thead/tr/th'
+
+        col_amount = [re.compile(u'Gross amount'), re.compile(u'Montant brut')]
+        col_availability = [u'Availability date', u'Date de disponibilité']
+
+        class item(ItemElement):
+            klass = Pocket
+
+            obj_availability_date = Env('availability_date')
+            obj_condition = Env('condition')
+            obj__matching_txt = Env('matching_txt')
+
+            def obj_amount(self):
+                return MyDecimal(TableCell('amount')(self)[0].xpath('.//div[has-class("nowrap")]'))(self)
+
+            def obj_investment(self):
+                investment = None
+                for inv in self.page.browser.cache['invs'][Env('accid')(self)]:
+                    if inv.label in CleanText('./parent::tbody/preceding-sibling::tbody[1]')(self):
+                        investment = inv
+                assert investment is not None
+                return investment
+
+            def parse(self, el):
+                txt = CleanText(TableCell('availability')(self)[0].xpath('./span'))(self)
+                self.env['availability_date'] = Date(dayfirst=True, default=NotAvailable).filter(txt)
+                self.env['condition'] = Pocket.CONDITION_DATE if self.env['availability_date'] else \
+                                        self.page.CONDITIONS.get(txt.lower().split()[0], Pocket.CONDITION_UNKNOWN)
+                self.env['matching_txt'] = txt
+
+    def update_pockets_quantity(self, pockets):
+        for pocket in pockets:
+            # not so pretty
+            pocket.quantity = MyDecimal(CleanText('//div[contains(@id, "detailParSupportEtDate")] \
+                //tbody[.//div[contains(text(), "%s")]]/following-sibling::tbody[1]//tr[.//span[contains(text(), \
+                "%s")]]/td[last()]//div/text()' % (pocket.investment.label, pocket._matching_txt)))(self.doc)
+        return pockets
+
 
 class HistoryPage(LoggedPage, MultiPage):
     XPATH_FORM = '//div[@id="operation"]//form'
@@ -347,7 +484,7 @@ class HistoryPage(LoggedPage, MultiPage):
                     page = self.page.browser.cache['details'][trid]
 
                 # Check if page is related to the account
-                if not len(page.doc.xpath('//td[contains(text(), "%s")]' % Env('accid')(self))):
+                if not len(page.doc.xpath('//td[contains(text(), $id)]', id=Env('accid')(self))):
                     raise SkipItem()
 
                 self.env['investments'] = list(page.get_investments(accid=Env('accid')(self)))
