@@ -17,10 +17,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
 
-import urllib
 import datetime
-from urlparse import parse_qs, urlparse
 from lxml.etree import XML
 from lxml.html import fromstring
 from decimal import Decimal, InvalidOperation
@@ -30,8 +29,13 @@ from weboob.capabilities.base import empty, NotAvailable
 from weboob.capabilities.bank import Account, Investment
 from weboob.capabilities.contact import Advisor
 from weboob.tools.capabilities.bank.transactions import FrenchTransaction
-from weboob.browser.filters.standard import CleanText, CleanDecimal, Regexp
-from weboob.browser.pages import LoggedPage
+from weboob.tools.compat import parse_qs, urlparse, parse_qsl, urlunparse, urlencode, unicode
+from weboob.browser.elements import DictElement, ItemElement, method
+from weboob.browser.filters.json import Dict
+from weboob.browser.filters.standard import CleanText, CleanDecimal, Regexp, RegexpError
+from weboob.browser.filters.html import Link
+from weboob.browser.pages import JsonPage, LoggedPage
+from weboob.exceptions import NoAccountsException, BrowserUnavailable
 
 from .base import BasePage
 
@@ -51,16 +55,19 @@ class AccountsList(LoggedPage, BasePage):
              u'Crédit':              Account.TYPE_LOAN,
              u'Ldd':                 Account.TYPE_SAVINGS,
              u'Livret':              Account.TYPE_SAVINGS,
-             u'PEA':                 Account.TYPE_SAVINGS,
+             u'PEA':                 Account.TYPE_PEA,
              u'PEL':                 Account.TYPE_SAVINGS,
              u'Plan Epargne':        Account.TYPE_SAVINGS,
              u'Prêt':                Account.TYPE_LOAN,
             }
 
     def get_list(self):
+        err = CleanText('//span[@class="error_msg"]', default='')(self.doc)
+        if err == 'Vous ne disposez pas de compte consultable.':
+            raise NoAccountsException()
+
         def check_valid_url(url):
             pattern = ['/restitution/cns_detailAVPAT.html',
-                       '/restitution/cns_detailPea.html',
                        '/restitution/cns_detailAlterna.html',
                       ]
 
@@ -81,7 +88,7 @@ class AccountsList(LoggedPage, BasePage):
                         break
                     account.label = CleanText('.')(a)
                     account._link_id = a.get('href', '')
-                    for pattern, actype in self.TYPES.iteritems():
+                    for pattern, actype in self.TYPES.items():
                         if account.label.startswith(pattern):
                             account.type = actype
                             break
@@ -113,7 +120,6 @@ class AccountsList(LoggedPage, BasePage):
                             account.currency = account.get_currency(balance)
                         else:
                             account.balance = NotAvailable
-
             if not account.label or empty(account.balance):
                 continue
 
@@ -172,7 +178,16 @@ class Transaction(FrenchTransaction):
 
 class AccountHistory(LoggedPage, BasePage):
     def is_here(self):
-        return not CleanText('//h1[contains(text(), "Effectuer un virement")]')(self.doc)
+        return not CleanText('//h1[contains(text(), "Effectuer un virement")]')(self.doc) and \
+            not bool(CleanText(u'//h3[contains(text(), "Ajouter un compte bénéficiaire de virement")]')(self.doc)) and \
+            not bool(CleanText(u'//h1[contains(text(), "Ajouter un compte bénéficiaire de virement")]')(self.doc)) and \
+            not bool(CleanText(u'//h3[contains(text(), "Veuillez vérifier les informations du compte à ajouter")]')(self.doc)) and \
+            not bool(Link('//a[contains(@href, "per_cptBen_ajouterFrBic")]', default=NotAvailable)(self.doc))
+
+    def on_load(self):
+        msg = CleanText('//span[@class="error_msg"]', default='')(self.doc)
+        if 'Le service est momentanément indisponible' in msg:
+            raise BrowserUnavailable()
 
     debit_date =  None
     def get_part_url(self):
@@ -193,6 +208,7 @@ class AccountHistory(LoggedPage, BasePage):
             return
 
         is_deferred_card = bool(self.doc.xpath(u'//div[contains(text(), "Différé")]'))
+        has_summary = False
         while True:
             d = XML(self.browser.open(url).content)
             el = d.xpath('//dataBody')
@@ -204,8 +220,12 @@ class AccountHistory(LoggedPage, BasePage):
             doc = fromstring(s)
 
             for tr in self._iter_transactions(doc):
+                if tr.type == Transaction.TYPE_CARD_SUMMARY:
+                    has_summary = True
                 if is_deferred_card and tr.type is Transaction.TYPE_CARD:
                     tr.type = Transaction.TYPE_DEFERRED_CARD
+                    if not has_summary:
+                        tr._coming = True
                 yield tr
 
             el = d.xpath('//dataHeader')[0]
@@ -224,7 +244,7 @@ class AccountHistory(LoggedPage, BasePage):
             args['sign'] = p['sign'][0]
             args['src'] = p['src'][0]
 
-            url = '%s?%s' % (url.path, urllib.urlencode(args))
+            url = '%s?%s' % (url.path, urlencode(args))
 
     def _iter_transactions(self, doc):
         t = None
@@ -239,8 +259,16 @@ class AccountHistory(LoggedPage, BasePage):
                 m = re.search(r'(\d+)/(\d+)', raw)
                 if not m:
                     continue
+
+                old_debit_date = self.debit_date
                 self.debit_date = t.date if t else datetime.date.today()
                 self.debit_date = self.debit_date.replace(day=int(m.group(1)), month=int(m.group(2)))
+
+                if old_debit_date is not None:
+                    while self.debit_date > old_debit_date:
+                        self.debit_date = self.debit_date.replace(year=self.debit_date.year - 1)
+                        self.logger.error('adjusting debit date to %s', self.debit_date)
+
                 if not t:
                     continue
 
@@ -257,7 +285,7 @@ class AccountHistory(LoggedPage, BasePage):
                 t.amount = -t.amount
                 date = self.debit_date
             t.rdate = t.parse_date(date)
-            t.parse(raw=raw, date=(self.debit_date or date))
+            t.parse(raw=raw, date=(self.debit_date or date), vdate=(date or None))
 
             yield t
 
@@ -290,14 +318,62 @@ class Market(LoggedPage, BasePage, Invest):
     COL_VALUATION = 3
     COL_DIFF = 4
 
+    def get_balance(self, account_type):
+        return CleanDecimal('//form[@id="listeCTForm"]/table//tr[td[5]]/td[@width="15%"][1]', replace_dots=True, default=None)(self.doc)
+
+    def get_not_rounded_valuations(self):
+        def prepare_url(url, fields):
+            components = urlparse(url)
+            query_pairs = [(f, v) for (f, v) in parse_qsl(components.query) if f not in fields]
+
+            for (field, value) in fields.items():
+                query_pairs.append((field, value))
+
+            new_query_str = urlencode(query_pairs)
+
+            new_components = (
+                components.scheme,
+                components.netloc,
+                components.path,
+                components.params,
+                new_query_str,
+                components.fragment
+            )
+
+            return urlunparse(new_components)
+
+        not_rounded_valuations = {}
+        pages = []
+
+        try:
+            for i in range(1, CleanDecimal(Regexp(CleanText(u'(//table[form[contains(@name, "detailCompteTitresForm")]]//tr[1])[1]/td[3]/text()'), r'\/(.*)'))(self.doc) + 1):
+                pages.append(self.browser.open(prepare_url(self.browser.url, {'action': '11', 'idCptSelect': '1', 'numPage': i})).page)
+        except RegexpError: # no multiple page
+            pages.append(self)
+
+        for page in pages:
+            for inv in page.doc.xpath(u'//table[contains(., "Détail du compte")]//tr[2]//table/tr[position() > 1]'):
+                if len(inv.xpath('.//td')) > 2:
+                    amt = CleanText('.//td[7]/text()')(inv)
+                    if amt == 'Indisponible':
+                        continue
+                    not_rounded_valuations[CleanText('.//td[1]/a/text()')(inv)] = CleanDecimal('.//td[7]/text()', replace_dots=True)(inv)
+
+        return not_rounded_valuations
+
     def iter_investment(self):
+        not_rounded_valuations = self.get_not_rounded_valuations()
+
         doc = self.browser.open('/brs/fisc/fisca10a.html').page.doc
         num_page = None
+
         try:
             num_page = int(CleanText('.')(doc.xpath(u'.//tr[contains(td[1], "Relevé des plus ou moins values latentes")]/td[2]')[0]).split('/')[1])
         except IndexError:
             pass
+
         docs = [doc]
+
         if num_page:
             for n in range(2, num_page + 1):
                 docs.append(self.browser.open('%s%s' % ('/brs/fisc/fisca10a.html?action=12&numPage=', str(n))).page.doc)
@@ -310,13 +386,27 @@ class Market(LoggedPage, BasePage, Invest):
                 cells = tr.findall('td')
 
                 inv = Investment()
-                inv.label = unicode(cells[self.COL_LABEL].xpath('.//span')[0].attrib['title'].split(' - ')[0])
-                inv.code = unicode(cells[self.COL_LABEL].xpath('.//span')[0].attrib['title'].split(' - ')[1])
+
+                title_split = cells[self.COL_LABEL].xpath('.//span')[0].attrib['title'].split(' - ')
+                inv.label = unicode(title_split[0])
+
+                for code in title_split[1:]:
+                    if len(code) == 12:
+                        inv.code = unicode(code)
+                        break
+                else:
+                    inv.code = NotAvailable
+
                 if is_detailed:
                     inv.quantity = MyDecimal('.')(tr.xpath('./following-sibling::tr/td[2]')[0])
                     inv.unitprice = MyDecimal('.', replace_dots=True)(tr.xpath('./following-sibling::tr/td[3]')[1])
                     inv.unitvalue = MyDecimal('.', replace_dots=True)(tr.xpath('./following-sibling::tr/td[3]')[0])
-                    inv.valuation = MyDecimal('.')(tr.xpath('./following-sibling::tr/td[4]')[0])
+
+                    try: # try to get not rounded value
+                        inv.valuation = not_rounded_valuations[inv.label]
+                    except KeyError: # ok.. take it from the page
+                        inv.valuation = MyDecimal('.')(tr.xpath('./following-sibling::tr/td[4]')[0])
+
                     inv.diff = MyDecimal('.')(tr.xpath('./following-sibling::tr/td[5]')[0])
                 else:
                     inv.quantity = MyDecimal('.')(cells[self.COL_QUANTITY])
@@ -378,7 +468,8 @@ class LifeInsuranceHistory(LifeInsurance):
             # search for 'Réalisé'
             trans._coming = 'alis' not in cells[self.COL_STATUS].text.strip()
 
-            self.set_date(trans)
+            if not self.set_date(trans):
+                continue
 
             if u'Annulé' in cells[self.COL_STATUS].text.strip():
                 continue
@@ -387,20 +478,35 @@ class LifeInsuranceHistory(LifeInsurance):
 
     def set_date(self, trans):
         """fetch date and vdate from another page"""
-        form = self.doc.xpath('//form[@id="operationForm"]')[0]
-
         # go to the page containing the dates
-        data = dict((item.name, item.value or '') for item in form.inputs)
-        data['a100_asv_action'] = 'detail'
-        data['a100_asv_indexOp'] = trans._temp_id
-        doc = self.browser.open('/asv/AVI/asvcns21c.html', data=data).page.doc
+        form = self.get_form(id='operationForm')
+        form['a100_asv_action'] = 'detail'
+        form['a100_asv_indexOp'] = trans._temp_id
+        form.url = '/asv/AVI/asvcns21c.html'
+
+        # but the page sometimes fail
+        for i in range(3, -1, -1):
+            page = form.submit().page
+            doc = page.doc
+            if not page.get_error():
+                break
+            self.logger.warning('Life insurance history error (%s), retrying %d more times', page.get_error(), i)
+        else:
+            self.logger.warning('Life insurance history error (%s), failed', page.get_error())
+            return False
 
         # process the data
         date_xpath = '//td[@class="net2g_asv_suiviOperation_element1"]/following-sibling::td'
         vdate_xpath = '//td[@class="net2g_asv_tableau_cell_date"]'
+
+        date = CleanText(date_xpath)(doc)
+        if u"Rejet d'intégration" in date:
+            return False
+
         trans.date = self.parse_date(doc, trans, date_xpath, 1)
         trans.rdate = trans.date
         trans.vdate = self.parse_date(doc, trans, vdate_xpath, 0)
+        return True
 
     @staticmethod
     def parse_date(doc, trans, xpath, index):
@@ -436,3 +542,37 @@ class AdvisorPage(BasePage):
             a.mobile = a.email = NotAvailable
             a.role = u"wealth" if "patrimoine" in CleanText('./div[1]')(div) else u"bank"
             yield a
+
+
+class LoansPage(LoggedPage, JsonPage):
+    @method
+    class iter_accounts(DictElement):
+        item_xpath = 'donnees/tabPrestations'
+
+        class item(ItemElement):
+            klass = Account
+
+            obj_id = Dict('idPrestation')
+            obj_type = Account.TYPE_LOAN
+            obj_label = Dict('libelle')
+            obj_currency = Dict('capitalRestantDu/devise', default=NotAvailable)
+            obj__link_id = None
+
+            def obj_balance(self):
+                val = Dict('capitalRestantDu/valeur', default=NotAvailable)(self)
+                if val is NotAvailable:
+                    return val
+
+                val = Decimal(val)
+                point = Decimal(Dict('capitalRestantDu/posDecimale')(self))
+                assert point >= 0
+                return val.scaleb(-point)
+
+            def validate(self, obj):
+                assert obj.id
+                assert obj.label
+                if obj.balance is NotAvailable:
+                    # ... but the account may be in the main AccountsList anyway
+                    self.logger.debug('skipping account %r %r due to missing balance', obj.id, obj.label)
+                    return False
+                return True
