@@ -19,6 +19,7 @@
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from weboob.capabilities.video import BaseVideo
+from weboob.tools.value import Value
 from weboob.tools.test import BackendTest
 import itertools
 
@@ -26,6 +27,11 @@ import itertools
 class VimeoTest(BackendTest):
     MODULE = 'vimeo'
 
+    def setUp(self):
+        if not self.is_backend_configured():
+            self.backend.config['quality'] = Value(value='2')
+            self.backend.config['method'] = Value(value='progressive')
+
     def test_search(self):
         l = list(itertools.islice(self.backend.search_videos('boobs'), 0, 20))
         self.assertTrue(len(l) > 0)
