@@ -34,7 +34,7 @@ class VirginRadioModule(Module, CapRadio, CapCollection):
     NAME = 'virginradio'
     MAINTAINER = u'Johann Broudin'
     EMAIL = 'Johann.Broudin@6-8.fr'
-    VERSION = '1.2'
+    VERSION = '1.3'
     DESCRIPTION = u'VirginRadio french radio'
     LICENSE = 'AGPLv3+'
     BROWSER = Browser
@@ -76,7 +76,7 @@ class VirginRadioModule(Module, CapRadio, CapCollection):
         stream = BaseAudioStream(0)
         current = StreamInfo(0)
 
-        r = self.browser.open(url, stream=True, headers={'Icy-Metadata':1})
+        r = self.browser.open(url, stream=True, headers={'Icy-Metadata':'1'})
 
         stream.bitrate = int(r.headers['icy-br'].split(',')[0])
 
@@ -119,7 +119,7 @@ class VirginRadioModule(Module, CapRadio, CapCollection):
         if Radio in objs:
             self._restrict_level(split_path)
 
-            for id in self._RADIOS.iterkeys():
+            for id in self._RADIOS:
                 yield self.get_radio(id)
 
     def iter_radios_search(self, pattern):
