@@ -25,17 +25,11 @@ class WeatherTest(BackendTest):
     MODULE = 'weather'
 
     def test_cities(self):
-        paris = self.backend.iter_city_search('crappything&param=;drop database')
-        self.assertTrue(len(list(paris)) == 0)
-
-        paris = self.backend.iter_city_search('paris')
+        paris = list(self.backend.iter_city_search('paris'))
         self.assertTrue(len(list(paris)) >= 1)
 
-        paris = self.backend.iter_city_search('paris france')
-        self.assertTrue(len(list(paris)) == 1)
-
         current = self.backend.get_current(paris[0].id)
         self.assertTrue(current.temp.value is float(current.temp.value))
 
         forecasts = list(self.backend.iter_forecast(paris[0].id))
-        self.assertTrue(len(forecasts) == 10)
+        self.assertTrue(len(forecasts) > 10)
