@@ -3,6 +3,8 @@
 # stop on failure
 set -e
 
+. "$(dirname $0)/common.sh"
+
 # Use C local to avoid local dates in headers
 export LANG=en_US.utf8
 
@@ -24,9 +26,9 @@ echo "file://$WEBOOB_DIR/modules" > "${WEBOOB_TMPDIR}/sources.list"
 export WEBOOB_WORKDIR="${WEBOOB_TMPDIR}"
 export WEBOOB_DATADIR="${WEBOOB_TMPDIR}"
 export PYTHONPATH="${WEBOOB_DIR}"
-"${WEBOOB_DIR}/scripts/weboob-config" update
+$PYTHON "${WEBOOB_DIR}/scripts/weboob-config" update
 
-"${WEBOOB_DIR}/tools/make_man.py"
+$PYTHON "${WEBOOB_DIR}/tools/make_man.py"
 
 # allow failing commands past this point
 STATUS=$?
