@@ -3,6 +3,8 @@
 # stop on failure
 set -e
 
+. "$(dirname $0)/common.sh"
+
 [ -z "${TMPDIR}" ] && TMPDIR="/tmp"
 
 # do not allow undefined variables anymore
@@ -18,9 +20,9 @@ echo "file://$WEBOOB_DIR/modules" > "${WEBOOB_TMPDIR}/sources.list"
 export WEBOOB_WORKDIR="${WEBOOB_TMPDIR}"
 export WEBOOB_DATADIR="${WEBOOB_TMPDIR}"
 export PYTHONPATH="${WEBOOB_DIR}"
-"${WEBOOB_DIR}/scripts/weboob-config" update
+$PYTHON "${WEBOOB_DIR}/scripts/weboob-config" update
 
-"${WEBOOB_DIR}/tools/weboob_lint.py"
+$PYTHON "${WEBOOB_DIR}/tools/weboob_lint.py"
 
 # allow failing commands past this point
 STATUS=$?
