@@ -26,7 +26,7 @@ from .main_window import MainWindow
 
 class QBooblyrics(QtApplication):
     APPNAME = 'qbooblyrics'
-    VERSION = '1.2'
+    VERSION = '1.3'
     COPYRIGHT = 'Copyright(C) 2016 Julien Veyssier'
     DESCRIPTION = "Qt application allowing to search song lyrics."
     SHORT_DESCRIPTION = "search lyrics"
@@ -40,6 +40,6 @@ class QBooblyrics(QtApplication):
         self.load_backends([CapLyrics])
         self.load_config()
 
-        self.main_window = MainWindow(self.config, self.weboob, self)
-        self.main_window.show()
+        main_window = MainWindow(self.config, self.weboob, self)
+        main_window.show()
         return self.weboob.loop()
