@@ -26,7 +26,7 @@ from .main_window import MainWindow
 
 class QBoobMsg(QtApplication):
     APPNAME = 'qboobmsg'
-    VERSION = '1.2'
+    VERSION = '1.3'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon'
     DESCRIPTION = "Qt application allowing to read messages on various websites and reply to them."
     SHORT_DESCRIPTION = "send and receive message threads"
@@ -35,6 +35,6 @@ class QBoobMsg(QtApplication):
     def main(self, argv):
         self.load_backends(CapMessages, storage=self.create_storage())
 
-        self.main_window = MainWindow(self.config, self.weboob)
-        self.main_window.show()
+        main_window = MainWindow(self.config, self.weboob)
+        main_window.show()
         return self.weboob.loop()
