@@ -26,7 +26,7 @@ from .main_window import MainWindow
 
 class QHaveDate(QtApplication):
     APPNAME = 'qhavedate'
-    VERSION = '1.2'
+    VERSION = '1.3'
     COPYRIGHT = 'Copyright(C) 2010-2014 Romain Bignon'
     DESCRIPTION = "Qt application allowing to interact with various dating websites."
     SHORT_DESCRIPTION = "interact with dating websites"
@@ -37,6 +37,6 @@ class QHaveDate(QtApplication):
         self.create_storage(self.STORAGE_FILENAME)
         self.load_backends(CapDating)
 
-        self.main_window = MainWindow(self.config, self.weboob)
-        self.main_window.show()
+        main_window = MainWindow(self.config, self.weboob)
+        main_window.show()
         return self.weboob.loop()
