@@ -19,21 +19,19 @@
 
 from __future__ import absolute_import
 
+from collections import OrderedDict
+from functools import wraps
 import warnings
 from io import BytesIO
 import codecs
 from cgi import parse_header
-try:
-    import urlparse
-except ImportError:
-    import urllib.parse as urlparse
+from functools import reduce
 
 import requests
 
 from weboob.exceptions import ParseError, ModuleInstallError
-from weboob.tools.compat import basestring
+from weboob.tools.compat import basestring, unicode, urljoin
 from weboob.tools.log import getLogger
-from weboob.tools.ordereddict import OrderedDict
 from weboob.tools.pdf import decompress_pdf
 
 
@@ -66,6 +64,8 @@ def pagination(func):
     >>> list(b.page.iter_values())
     ['One', 'Two', 'Three', 'Four']
     """
+
+    @wraps(func)
     def inner(page, *args, **kwargs):
         while True:
             try:
@@ -211,7 +211,7 @@ class Page(object):
         """
         Get an absolute URL from an a partial URL, relative to the Page URL
         """
-        return urlparse.urljoin(self.url, url)
+        return urljoin(self.url, url)
 
 
 class FormNotFound(Exception):
@@ -367,7 +367,7 @@ class CsvPage(Page):
             content = content.decode('utf-16').encode('utf-8')
             encoding = 'utf-8'
         if self.NEWLINES_HACK:
-            content = content.replace('\r\n', '\n').replace('\r', '\n')
+            content = content.replace(b'\r\n', b'\n').replace(b'\r', b'\n')
         return self.parse(BytesIO(content), encoding)
 
     def parse(self, data, encoding=None):
@@ -387,7 +387,7 @@ class CsvPage(Page):
         for i, row in enumerate(reader):
             if self.HEADER and i+1 < self.HEADER:
                 continue
-            row = map(unicode.strip, self.decode_row(row, encoding))
+            row = [c.strip() for c in self.decode_row(row, encoding)]
             if header is None and self.HEADER:
                 header = row
             else:
@@ -420,7 +420,7 @@ class JsonPage(Page):
 
     def get(self, path):
         node = self.doc
-        for name in filter(None, path.strip('.').split('.')):
+        for name in [_f for _f in path.strip('.').split('.') if _f]:
             node = node.get(name)
             if node is None:
                 break
@@ -464,12 +464,12 @@ class XLSPage(Page):
         header = None
         drows = []
         rows = []
-        for i in range(sh.nrows - 1):
+        for i in range(sh.nrows):
             if self.HEADER and i + 1 < self.HEADER:
                 continue
             row = sh.row_values(i)
             if header is None and self.HEADER:
-                header = map(lambda s: s.replace('/', ''), row)
+                header = [s.replace('/', '') for s in row]
             else:
                 rows.append(row)
                 if header:
@@ -487,7 +487,7 @@ class XMLPage(Page):
 
     def detect_encoding(self):
         import re
-        m = re.search('<\?xml version="1.0" encoding="(.*)"\?>', self.data)
+        m = re.search(b'<\?xml version="1.0" encoding="(.*)"\?>', self.data)
         if m:
             return m.group(1)
 
@@ -553,7 +553,7 @@ class HTMLPage(Page):
             m = self.browser.REFRESH_RE.match(refresh.get('content', ''))
             if not m:
                 continue
-            url = urlparse.urljoin(self.url, m.groupdict().get('url', None))
+            url = urljoin(self.url, m.groupdict().get('url', None))
             sleep = float(m.groupdict()['sleep'])
 
             if sleep <= self.REFRESH_MAX:
@@ -694,13 +694,26 @@ class HTMLPage(Page):
 
 
 class PartialHTMLPage(HTMLPage):
+    """
+    HTML page for broken pages with multiple roots.
+
+    This class should typically be used for requests which return only a part of
+    a full document, to insert in another document. Such a sub-document can have
+    multiple root tags, so this class is required in this case.
+    """
+
     def build_doc(self, content):
         import lxml.etree
-        try:
-            return super(PartialHTMLPage, self).build_doc(content)
-        except lxml.etree.XMLSyntaxError:
-            content = '<html>%s</html>' % content
-            return super(PartialHTMLPage, self).build_doc(content)
+
+        if content.strip():
+            # lxml raises a different error if content is whitespace-only
+            try:
+                return super(PartialHTMLPage, self).build_doc(content)
+            except lxml.etree.XMLSyntaxError:
+                pass
+
+        content = b'<html>%s</html>' % content
+        return super(PartialHTMLPage, self).build_doc(content)
 
 
 class GWTPage(Page):
@@ -820,9 +833,9 @@ class AbstractPage(Page):
         else:
             parent_browser = reduce(getattr, cls.BROWSER_ATTR.split('.'), parent_module)
 
-        parent = parent_browser._urls.get(cls.PARENT_URL, None)
+        parent = getattr(parent_browser, cls.PARENT_URL, None)
         if parent is None:
             raise AbstractPageError("cls.PARENT_URL is not defined in %s" % browser)
 
         cls.__bases__ = (parent.klass,)
-        return cls.__new__(cls, browser, *args, **kwargs)
+        return object.__new__(cls)
