@@ -24,6 +24,8 @@ import re
 
 from weboob.capabilities.base import empty
 from weboob.exceptions import BrowserQuestion
+from weboob.tools.capabilities.bank.iban import is_iban_valid
+from weboob.tools.compat import unicode
 
 from .base import BaseObject, Field, StringField, DecimalField, IntField, \
                   UserError, Currency, NotAvailable
@@ -33,7 +35,7 @@ from .collection import CapCollection
 
 __all__ = ['AccountNotFound', 'TransferError', 'TransferStep', 'Recipient',
            'Account', 'Transaction', 'Investment', 'Transfer', 'CapBank',
-           'RecipientNotFound']
+           'RecipientNotFound', 'AddRecipientError', 'AddRecipientStep']
 
 
 class AccountNotFound(UserError):
@@ -42,7 +44,7 @@ class AccountNotFound(UserError):
     """
 
     def __init__(self, msg='Account not found'):
-        UserError.__init__(self, msg)
+        super(AccountNotFound, self).__init__(msg)
 
 
 class RecipientNotFound(UserError):
@@ -51,7 +53,7 @@ class RecipientNotFound(UserError):
     """
 
     def __init__(self, msg='Recipient not found'):
-        UserError.__init__(self, msg)
+        super(RecipientNotFound, self).__init__(msg)
 
 
 class TransferError(UserError):
@@ -59,6 +61,90 @@ class TransferError(UserError):
     A transfer has failed.
     """
 
+    code = 'transferError'
+
+    def __init__(self, description=None, message=None):
+        """
+        :param message: error message from the bank, if any
+        """
+
+        super(TransferError, self).__init__(message or description)
+        self.message = message
+        self.description = description
+
+
+class TransferBankError(TransferError):
+    """The transfer was rejected by the bank with a message."""
+
+    code = 'bankMessage'
+
+
+class TransferInvalidLabel(TransferError):
+    """The transfer label is invalid."""
+
+    code = 'invalidLabel'
+
+
+class TransferInvalidEmitter(TransferError):
+    """The emitter account cannot be used for transfers."""
+
+    code = 'invalidEmitter'
+
+
+class TransferInvalidRecipient(TransferError):
+    """The emitter cannot transfer to this recipient."""
+
+    code = 'invalidRecipient'
+
+
+class TransferInvalidAmount(TransferError):
+    """This amount is not allowed."""
+
+    code = 'invalidAmount'
+
+
+class TransferInvalidCurrency(TransferInvalidAmount):
+    """The transfer currency is invalid."""
+
+    code = 'invalidCurrency'
+
+
+class TransferInsufficientFunds(TransferInvalidAmount):
+    """Not enough funds on emitter account."""
+
+    code = 'insufficientFunds'
+
+
+class TransferInvalidDate(TransferError):
+    """This execution date cannot be used."""
+
+    code = 'invalidDate'
+
+
+class AddRecipientError(UserError):
+    """
+    Failed trying to add a recipient.
+    """
+
+    code = 'AddRecipientError'
+
+    def __init__(self, description=None, message=None):
+        """
+        :param message: error message from the bank, if any
+        """
+
+        super(AddRecipientError, self).__init__(message or description)
+        self.message = message
+        self.description = description
+
+
+class RecipientInvalidIban(AddRecipientError):
+    code = 'invalidIban'
+
+
+class RecipientInvalidLabel(AddRecipientError):
+    code = 'invalidLabel'
+
 
 class BaseAccount(BaseObject, Currency):
     """
@@ -71,7 +157,7 @@ class BaseAccount(BaseObject, Currency):
     bank_name =      StringField('Bank Name')
 
     def __init__(self, id='0', url=None):
-        BaseObject.__init__(self, id, url)
+        super(BaseAccount, self).__init__(id, url)
 
     @property
     def currency_text(self):
@@ -148,6 +234,30 @@ class Account(BaseAccount):
         return "<Account id=%r label=%r>" % (self.id, self.label)
 
 
+class Loan(Account):
+
+    name = StringField('Person Name')
+    total_amount = DecimalField('Total Amount')
+    available_amount = DecimalField('Amount availalble')
+    used_amount = DecimalField('Amount already used')
+    subscription_date = DateField('Date of subscription of the loan')
+    maturity_date = DateField('Estimated end date of the loan')
+    next_payment_amount = DecimalField('Amount of next payment')
+    next_payment_date = DateField('Date of the next payment')
+
+    rate = DecimalField('Rate of the loan')
+    nb_payments_left = IntField('Number of payments still due')
+    nb_payments_done = IntField('Number of payments already done')
+    nb_payments_total = IntField('Number total of payments')
+
+    last_payment_amount = DecimalField('Amount of the last payment done')
+    last_payment_date = DateField('Date of the last payment done')
+
+    account_label = StringField('Label of the debited account')
+    insurance_label = StringField('Label of the insurance')
+    duration = IntField('Duration of the loan given in months')
+
+
 class Transaction(BaseObject):
     """
     Bank transaction.
@@ -204,21 +314,21 @@ class Transaction(BaseObject):
         :returns: an unique ID encoded in 8 length hexadecimal string (for example ``'a64e1bc9'``)
         :rtype: :class:`str`
         """
-        crc = crc32(str(self.date))
-        crc = crc32(str(self.amount), crc)
+        crc = crc32(unicode(self.date).encode('utf-8'))
+        crc = crc32(unicode(self.amount).encode('utf-8'), crc)
         if not empty(self.raw):
             label = self.raw
         else:
             label = self.label
 
-        crc = crc32(re.sub('[ ]+', ' ', label.encode("utf-8")), crc)
+        crc = crc32(re.sub('[ ]+', ' ', label).encode("utf-8"), crc)
 
         if account_id is not None:
-            crc = crc32(str(account_id), crc)
+            crc = crc32(unicode(account_id).encode('utf-8'), crc)
 
         if seen is not None:
             while crc in seen:
-                crc = crc32("*", crc)
+                crc = crc32(b"*", crc)
 
             seen.add(crc)
 
@@ -229,9 +339,12 @@ class Investment(BaseObject):
     """
     Investment in a financial market.
     """
+    CODE_TYPE_ISIN =     u'ISIN'
+    CODE_TYPE_AMF =      u'AMF'
 
     label =              StringField('Label of stocks')
-    code =               StringField('Identifier of the stock (ISIN code)')
+    code =               StringField('Identifier of the stock')
+    code_type =          StringField('Type of stock code (ISIN or AMF)')
     description =        StringField('Short description of the stock')
     quantity =           DecimalField('Quantity of stocks')
     unitprice =          DecimalField('Buy price of one stock')
@@ -249,6 +362,37 @@ class Investment(BaseObject):
     original_unitprice = DecimalField('Original unitprice (in another currency)')
     original_diff = DecimalField('Original diff (in another currency)')
 
+    def __repr__(self):
+        return '<Investment label=%r code=%r valuation=%r>' % (self.label, self.code, self.valuation)
+
+
+class Pocket(BaseObject):
+    """
+    Pocket
+    """
+    CONDITION_UNKNOWN                    = 0
+    CONDITION_DATE                       = 1
+    CONDITION_AVAILABLE                  = 2
+    CONDITION_RETIREMENT                 = 3
+    CONDITION_WEDDING                    = 4
+    CONDITION_DEATH                      = 5
+    CONDITION_INDEBTEDNESS               = 6
+    CONDITION_DIVORCE                    = 7
+    CONDITION_DISABILITY                 = 8
+    CONDITION_BUSINESS_CREATION          = 9
+    CONDITION_BREACH_EMPLOYMENT_CONTRACT = 10
+    CONDITION_UNLOCKING_EXCEPTIONAL      = 11
+    CONDITION_THIRD_CHILD                = 12
+    CONDITION_EXPIRATION_UNEMPLOYMENT    = 13
+    CONDITION_PURCHASE_APARTMENT         = 14
+
+    label =             StringField('Label of pocket')
+    amount =            DecimalField('Amount of the pocket')
+    quantity =          DecimalField('Quantity of stocks')
+    availability_date = DateField('Availability date of the pocket')
+    condition =         IntField('Withdrawal condition of the pocket', default=CONDITION_UNKNOWN)
+    investment =        Field('Reference to the investment of the pocket', Investment)
+
 
 class TransferStep(BrowserQuestion):
     def __init__(self, transfer, *values):
@@ -256,6 +400,12 @@ class TransferStep(BrowserQuestion):
         self.transfer = transfer
 
 
+class AddRecipientStep(BrowserQuestion):
+    def __init__(self, recipient, *values):
+        super(AddRecipientStep, self).__init__(*values)
+        self.recipient = recipient
+
+
 class Transfer(BaseObject, Currency):
     """
     Transfer from an account to a recipient.
@@ -354,12 +504,24 @@ class CapBank(CapCollection):
         """
         raise NotImplementedError()
 
+    def iter_pocket(self, account):
+        """
+        Iter pocket
+
+        :param account: account to get pockets
+        :type account: :class:`Account`
+        :rtype: iter[:class:`Pocket`]
+        :raises: :class:`AccountNotFound`
+        """
+        raise NotImplementedError()
+
 
 class CapCgp(CapBank):
     """
     Capability of cgp website to see accounts and transactions.
     """
 
+
 class CapBankTransfer(CapBank):
     def iter_transfer_recipients(self, account):
         """
@@ -400,6 +562,10 @@ class CapBankTransfer(CapBank):
         :rtype: :class:`Transfer`
         :raises: :class:`TransferError`
         """
+
+        if not transfer.amount or transfer.amount <= 0:
+            raise TransferInvalidAmount('amount must be strictly positive')
+
         t = self.init_transfer(transfer, **params)
         for key, value in t.iter_fields():
             if hasattr(transfer, key) and key != 'id':
@@ -412,3 +578,26 @@ class CapBankTransfer(CapBank):
                 except AssertionError:
                     raise TransferError('%s changed during transfer processing (from %s to %s)' % (key, transfer_val, value))
         return self.execute_transfer(t, **params)
+
+
+class CapBankTransferAddRecipient(CapBankTransfer):
+    def new_recipient(self, recipient, **params):
+        raise NotImplementedError()
+
+    def add_recipient(self, recipient, **params):
+        """
+        Add a recipient to the connection.
+
+        :param iban: iban of the new recipient.
+        :type iban: :class:`str`
+        :param label: label of the new recipient.
+        :type label: :class`str`
+        :raises: :class:`BrowserQuestion`
+        :raises: :class:`AddRecipientError`
+        :rtype: :class:`Recipient`
+        """
+        if not is_iban_valid(recipient.iban):
+            raise RecipientInvalidIban('Iban is not valid.')
+        if not recipient.label:
+            raise RecipientInvalidLabel('Recipient label is mandatory.')
+        return self.new_recipient(recipient, **params)
