@@ -20,7 +20,7 @@
 from prettytable import PrettyTable
 
 from weboob.capabilities.base import empty
-from weboob.tools.misc import guess_encoding
+from weboob.tools.compat import range
 
 from .iformatter import IFormatter
 
@@ -32,7 +32,7 @@ class TableFormatter(IFormatter):
     HTML = False
 
     def __init__(self):
-        IFormatter.__init__(self)
+        super(TableFormatter, self).__init__()
         self.queue = []
         self.keys = None
         self.header = None
@@ -40,17 +40,17 @@ class TableFormatter(IFormatter):
     def flush(self):
         s = self.get_formatted_table()
         if s is not None:
-            self.output(s.encode(guess_encoding(self.outfile), 'replace'))
+            self.output(s)
 
     def get_formatted_table(self):
         if len(self.queue) == 0:
             return
 
-        queue = [() for i in xrange(len(self.queue))]
+        queue = [() for i in range(len(self.queue))]
         column_headers = []
         # Do not display columns when all values are NotLoaded or NotAvailable
         maxrow = 0
-        for i in xrange(len(self.keys)):
+        for i in range(len(self.keys)):
             available = False
             for line in self.queue:
                 if len(line)> i and not empty(line[i]):
@@ -59,7 +59,7 @@ class TableFormatter(IFormatter):
                     break
             if available:
                 column_headers.append(self.keys[i].capitalize().replace('_', ' '))
-                for j in xrange(len(self.queue)):
+                for j in range(len(self.queue)):
                     if len(self.queue[j]) > i:
                         queue[j] += (self.queue[j][i],)
 
@@ -95,8 +95,8 @@ class TableFormatter(IFormatter):
 
     def format_dict(self, item):
         if self.keys is None:
-            self.keys = item.keys()
-        self.queue.append(item.values())
+            self.keys = list(item.keys())
+        self.queue.append(list(item.values()))
 
     def set_header(self, string):
         self.header = string
