@@ -21,6 +21,7 @@ from __future__ import print_function
 
 import atexit
 from cmd import Cmd
+from collections import OrderedDict
 import logging
 import re
 from optparse import OptionGroup, OptionParser, IndentedHelpFormatter
@@ -30,9 +31,9 @@ import os
 from weboob.capabilities.base import FieldNotFound, BaseObject, UserError
 from weboob.core import CallErrors
 from weboob.tools.application.formatters.iformatter import MandatoryFieldsNotFound
+from weboob.tools.compat import range, basestring, unicode
 from weboob.tools.misc import to_unicode
 from weboob.tools.path import WorkingPath
-from weboob.tools.ordereddict import OrderedDict
 from weboob.capabilities.collection import Collection, BaseCollection, CapCollection, CollectionNotFound
 
 from .console import BackendNotGiven, ConsoleApplication
@@ -59,7 +60,7 @@ class ReplOptionParser(OptionParser):
 class ReplOptionFormatter(IndentedHelpFormatter):
     def format_commands(self, commands):
         s = u''
-        for section, cmds in commands.iteritems():
+        for section, cmds in commands.items():
             if len(cmds) == 0:
                 continue
             if len(s) > 0:
@@ -91,7 +92,12 @@ def defaultcount(default_count=10):
     return deco
 
 
-class ReplApplication(Cmd, ConsoleApplication):
+class MyCmd(Cmd, object):
+    # Hack for Python 2, because Cmd doesn't inherit object, so its __init__ was not called when using super only
+    pass
+
+
+class ReplApplication(ConsoleApplication, MyCmd):
     """
     Base application class for Repl applications.
     """
@@ -111,10 +117,9 @@ class ReplApplication(Cmd, ConsoleApplication):
     hidden_commands = set(['EOF'])
 
     def __init__(self):
-        Cmd.__init__(self)
-        ConsoleApplication.__init__(self, ReplOptionParser(self.SYNOPSIS, version=self._get_optparse_version()))
+        super(ReplApplication, self).__init__(ReplOptionParser(self.SYNOPSIS, version=self._get_optparse_version()))
 
-        copyright = self.COPYRIGHT.replace('YEAR', '%d' % datetime.today().year).encode(self.encoding)
+        copyright = self.COPYRIGHT.replace('YEAR', '%d' % datetime.today().year)
         self.intro = '\n'.join(('Welcome to %s%s%s v%s' % (self.BOLD, self.APPNAME, self.NC, self.VERSION),
                                 '',
                                 copyright,
@@ -127,7 +132,7 @@ class ReplApplication(Cmd, ConsoleApplication):
                                 '',
                                ))
         self.formatters_loader = FormattersLoader()
-        for key, klass in self.EXTRA_FORMATTERS.iteritems():
+        for key, klass in self.EXTRA_FORMATTERS.items():
             self.formatters_loader.register_formatter(key, klass)
         self.formatter = None
         self.commands_formatters = self.COMMANDS_FORMATTERS.copy()
@@ -170,7 +175,7 @@ class ReplApplication(Cmd, ConsoleApplication):
         #    of the same line instead of new line.
         #self.prompt = self.BOLD + '%s> ' % self.APPNAME + self.NC
         if len(self.working_path.get()):
-            wp_enc = unicode(self.working_path).encode(self.encoding)
+            wp_enc = unicode(self.working_path)
             self.prompt = '%s:%s> ' % (self.APPNAME, wp_enc)
         else:
             self.prompt = '%s> ' % (self.APPNAME)
@@ -383,7 +388,7 @@ class ReplApplication(Cmd, ConsoleApplication):
             raise NotEnoughArguments('Command needs %d arguments' % req_n)
 
         if len(args) < nb:
-            args += tuple(None for i in xrange(nb - len(args)))
+            args += tuple(None for i in range(nb - len(args)))
         return args
 
     # -- cmd.Cmd methods ---------
@@ -531,9 +536,9 @@ class ReplApplication(Cmd, ConsoleApplication):
 
         if self.options.count is not None:
             self._is_default_count = False
-        if self.options.count <= 0:
-            # infinite search
-            self.options.count = None
+            if self.options.count <= 0:
+                # infinite search
+                self.options.count = None
 
         if self.options.condition:
             self.condition = ResultsCondition(self.options.condition)
@@ -633,7 +638,7 @@ class ReplApplication(Cmd, ConsoleApplication):
             elif args[1] == 'disable':
                 choices = sorted(enabled_backends_names)
             elif args[1] in ('add', 'register') and len(args) == 3:
-                for name, module in sorted(self.weboob.repositories.get_all_modules_info(self.CAPS).iteritems()):
+                for name, module in sorted(self.weboob.repositories.get_all_modules_info(self.CAPS).items()):
                     choices.append(name)
             elif args[1] == 'edit':
                 choices = sorted(available_backends_names)
@@ -724,7 +729,7 @@ class ReplApplication(Cmd, ConsoleApplication):
                 enabled = backend in self.enabled_backends
                 self.unload_backends(names=[backend.name])
                 self.edit_backend(backend.name)
-                for newb in self.load_backends(names=[backend.name]).itervalues():
+                for newb in self.load_backends(names=[backend.name]).values():
                     if not enabled:
                         self.enabled_backends.remove(newb)
         elif action == 'remove':
@@ -734,7 +739,7 @@ class ReplApplication(Cmd, ConsoleApplication):
         elif action == 'list-modules':
             modules = []
             print('Modules list:')
-            for name, info in sorted(self.weboob.repositories.get_all_modules_info().iteritems()):
+            for name, info in sorted(self.weboob.repositories.get_all_modules_info().items()):
                 if not self.is_module_loadable(info):
                     continue
                 modules.append(name)
@@ -796,7 +801,7 @@ class ReplApplication(Cmd, ConsoleApplication):
             level = levels[args[0]]
         except KeyError:
             print('Level "%s" does not exist.' % args[0], file=self.stderr)
-            print('Availables: %s' % ' '.join(levels.iterkeys()), file=self.stderr)
+            print('Availables: %s' % ' '.join(levels), file=self.stderr)
             return 2
         else:
             logging.root.setLevel(level)
@@ -932,7 +937,7 @@ class ReplApplication(Cmd, ConsoleApplication):
                     return 1
         else:
             print('Default formatter: %s' % self.DEFAULT_FORMATTER)
-            for key, klass in self.commands_formatters.iteritems():
+            for key, klass in self.commands_formatters.items():
                 print('Command "%s": %s' % (key, klass))
 
     def do_select(self, line):
@@ -954,19 +959,8 @@ class ReplApplication(Cmd, ConsoleApplication):
 
     # First sort in alphabetical of backend
     # Second, sort with ID
-    def comp_object(self, obj1, obj2):
-        if obj1.backend == obj2.backend:
-            if obj1.id == obj2.id:
-                return 0
-            elif obj1.id > obj2.id:
-                return 1
-            else:
-                return -1
-        elif obj1.backend > obj2.backend:
-            return 1
-
-        return -1
-
+    def comp_key(self, obj):
+        return (obj.backend, obj.id)
 
     @defaultcount(40)
     def do_ls(self, line):
@@ -1017,9 +1011,9 @@ class ReplApplication(Cmd, ConsoleApplication):
                     self._format_obj(res, only)
 
         if sort:
-            objects.sort(cmp=self.comp_object)
+            objects.sort(key=self.comp_key)
             collections = self._merge_collections_with_same_path(collections)
-            collections.sort(cmp=self.comp_object)
+            collections.sort(key=self.comp_key)
             for collection in collections:
                 self.formatter.format_collection(collection, only)
             for obj in objects:
@@ -1157,7 +1151,7 @@ class ReplApplication(Cmd, ConsoleApplication):
 
         collections = self.all_collections()
         for collection in collections:
-            directories.add(collection.basename.encode(self.encoding))
+            directories.add(collection.basename)
 
         return [s[offs:] for s in directories if s.startswith(mline)]
 
